#
# spec file for package patterns-openSUSE
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with betatest

Name:           patterns-openSUSE
Version:        20150918
Release:        27.1
Summary:        Patterns for Installation (full ftp tree)
License:        MIT
Group:          Metapackages
Url:            https://github.com/openSUSE/patterns
Source0:        %{name}-rpmlintrc
Source1:        create_macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl(URI::Escape)

%description
This is an internal package that is used to create the patterns as part
of the installation source setup.  Installation of this package does
not make sense.

%{expand:%(perl %{S:1})}

#BEGIN1
%package 32bit
%pattern_basetechnologies
Summary:        32-Bit Runtime Environment
Group:          Metapackages
Provides:       pattern() = 32bit
Provides:       pattern-icon() = yast-misc
Provides:       pattern-order() = 1140

%description 32bit
This pattern installs the 32-bit variant of all selected patterns, allowing you to execute 32-bit software.

%files 32bit
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/32bit.txt

%package 64bit
%pattern_basetechnologies
Summary:        64-Bit Runtime Environment
Group:          Metapackages
Provides:       pattern() = 64bit
Provides:       pattern-icon() = yast-misc
Provides:       pattern-order() = 1160
Provides:       pattern-visible()

%description 64bit
This pattern installs the 64-bit variant of all selected patterns, allowing you to execute 64-bit software.

%files 64bit
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/64bit.txt

%package apparmor
%pattern_basetechnologies
Summary:        AppArmor
Group:          Metapackages
Provides:       pattern() = apparmor
Provides:       pattern-icon() = pattern-apparmor
Provides:       pattern-order() = 1100
Provides:       pattern-visible()
Requires:       pattern() = basesystem
Recommends:     pattern() = apparmor_opt
# from data/APPARMOR
Requires:       apparmor-abstractions
Requires:       apparmor-parser
Requires:       apparmor-profiles
Requires:       audit
Recommends:     yast2-apparmor
Recommends:     apparmor-utils
Suggests:       pam_apparmor

%description apparmor
AppArmor is an application security framework that provides mandatory access control for programs. It protects from exploitation of software flaws and compromised systems. It offers an advanced tool set that automates the development of per-program application security without requiring additional knowledge.

%files apparmor
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/apparmor.txt

%package apparmor_opt
%pattern_basetechnologies
Summary:        AppArmor
Group:          Metapackages
Provides:       pattern() = apparmor_opt
Provides:       pattern-extends() = apparmor
Provides:       pattern-icon() = apparmor%2Fapp_armor.png
Provides:       pattern-order() = 1080
Requires:       pattern() = basesystem
# from data/APPARMOR-OPT
Requires:       apparmor-docs

%description apparmor_opt
AppArmor is an application security framework that provides mandatory access control for programs. It protects from exploitation of software flaws and compromised systems. It offers an advanced tool set that automates the development of per-program application security without requiring additional knowledge.

%files apparmor_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/apparmor_opt.txt

%package base
%pattern_basetechnologies
Summary:        Base System
Group:          Metapackages
Provides:       pattern() = base
Provides:       pattern() = basesystem
Provides:       pattern-icon() = pattern-basis
Provides:       pattern-order() = 1020
Provides:       pattern-visible()
# from data/BASIS
Requires:       aaa_base
Requires:       hwinfo
Requires:       kbd
# omit kernel here. Not needed for containers and YaST will add the
# right one anyways for real installs.
#Requires:       kernel
#Requires:       mkinitrd
Requires:       klogd
Requires:       netcfg
Requires:       openSUSE-build-key
Requires:       openSUSE-release
Requires:       openssh
Requires:       procps
Requires:       pwdutils
Requires:       rpm
Requires:       sysconfig
# enable NFS installation for minimal
Requires:       polkit
Requires:       polkit-default-privs
Requires:       rpcbind
Requires:       sbin_init
Requires:       util-linux
# which, time, adjtimex have been part of util-linux upto 12.3
# needs to be installed or packages fixed first
#Requires:       adjtimex # who needs adjtimex anymore?
Requires:       time
Requires:       which
# having root certifcates can be very useful
Recommends:     ca-certificates-mozilla
%ifarch ppc
Recommends:     libbspe
Recommends:     spu-tools
# #739878 - install pdisk by default
Recommends:     pdisk
%endif
# provides init script to load cpufreq modules
Recommends:     pm-utils
# default init
Recommends:     systemd-sysvinit
# get it branded
Recommends:     branding-openSUSE
%ifarch %ix86 x86_64
Recommends:     grub2
%endif
%ifarch %ix86
Recommends:     grub2-i386-efi
%endif
%ifarch x86_64
Recommends:     grub2-x86_64-efi
Recommends:     shim
%endif
%ifarch ppc ppc64 ppc64le
Recommends:     grub2-powerpc-ieee1275
%endif
%ifarch aarch64
Recommends:     grub2-arm64-efi
%endif
Suggests:       grub
Suggests:       systemd-logger

%description base
This is the base runtime system.  It contains only a minimal multiuser booting system. For running on real hardware, you need to add additional packages and pattern to make this pattern useful on its own.

%files base
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/base.txt

%package books
%pattern_documentation
Summary:        Documentation
Group:          Metapackages
Provides:       pattern() = books
Provides:       pattern-icon() = pattern-documentation
Provides:       pattern-order() = 5200
Provides:       pattern-visible()
# from data/BOOKS
Recommends:     opensuse-manuals_en
Recommends:     opensuse-startup_en-pdf
Suggests:       ImageMagick-doc
Suggests:       amavisd-new-docs
Suggests:       apache2-doc
Suggests:       apparmor-docs
Suggests:       bash-doc
Suggests:       bind-doc
Suggests:       digikam-doc
Suggests:       dhcp-doc
Suggests:       docbook-tdg
Suggests:       gcc-info
Suggests:       gcc46-info
Suggests:       gnome-devel-docs
Suggests:       gnome-user-docs
Suggests:       kernel-docs
Suggests:       kiwi-doc
Suggests:       man-pages
Suggests:       man-pages-fr
Suggests:       man-pages-it
Suggests:       man-pages-ja
Suggests:       man-pages-ko
Suggests:       man-pages-posix
Suggests:       man-pages-ru
Suggests:       nfs-doc
Suggests:       ntp-doc
Suggests:       perl-doc
Suggests:       php-doc
Suggests:       postfix-doc
Suggests:       postgresql-docs
Suggests:       python-doc
Suggests:       python3-doc
Suggests:       python-doc-pdf
Suggests:       python3-doc-pdf
Suggests:       samba-doc
Suggests:       selinux-doc
Suggests:       subversion-doc
Suggests:       texlive-doc
Suggests:       texlive-latex-doc
Suggests:       xorg-x11-doc
Suggests:       yast2-devel-doc
Suggests:       opensuse-manuals_de
Suggests:       opensuse-manuals_hu
Suggests:       opensuse-manuals_ru
Suggests:       opensuse-startup_de-pdf
Suggests:       opensuse-startup_ru-pdf

%description books
Help and Documentation, various books

%files books
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/books.txt

%package console
%pattern_basetechnologies
Summary:        Console Tools
Group:          Metapackages
Provides:       pattern() = console
Provides:       pattern-icon() = yast-system
Provides:       pattern-order() = 1120
Provides:       pattern-visible()
# from data/CONSOLE
Requires:       mc
Requires:       w3m
Recommends:     emacs-nox
Recommends:     mtools
Recommends:     sox
Recommends:     vorbis-tools
Suggests:       bsd-games
Suggests:       grepmail
Suggests:       irssi
Suggests:       links
Suggests:       nano
Suggests:       ncftp
Suggests:       minicom
Suggests:       mlocate
Suggests:       mutt
Suggests:       slrn
Suggests:       pinfo
Suggests:       vlock
Suggests:       alpine
Suggests:       pico
Suggests:       convert
Suggests:       ding
Suggests:       units
Suggests:       gcal
Suggests:       lftp
Suggests:       dar
Suggests:       par
Suggests:       makedev
# #378747
Suggests:       cryptconfig
Suggests:       cnetworkmanager

%description console
Applications useful for those using the console and no graphical desktop environment.

%files console
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/console.txt

%package devel_basis
%pattern_development
Summary:        Base Development
Group:          Metapackages
Provides:       pattern() = devel_basis
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3140
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/DEVEL-BASIS
Requires:       autoconf
Requires:       automake
Requires:       binutils
Requires:       bison
Requires:       cpp
Requires:       cvs
Requires:       flex
Requires:       gcc
Requires:       gdbm-devel
Requires:       gettext-tools
Requires:       glibc-devel
Requires:       libtool
Requires:       m4
Requires:       make
Requires:       makeinfo
Requires:       ncurses-devel
Requires:       patch
Requires:       zlib-devel
Recommends:     bin86
Recommends:     db-devel
Recommends:     gcc-c++
Recommends:     gcc-info
Recommends:     glibc-info
Recommends:     gmp-devel
Recommends:     gperf
Recommends:     libaio-devel
Recommends:     libgcj-devel
Recommends:     libstdc++-devel
Recommends:     openldap2-devel
Recommends:     pam-devel
Recommends:     pkg-config
Recommends:     subversion
%ifarch ppc
Recommends:     itrace
%endif
# most of our packages use this tool
Recommends:     fdupes
# applying patches
Recommends:     patch
Recommends:     binutils-devel
Recommends:     e2fsprogs-devel
Recommends:     libapparmor-devel
Recommends:     libosip2-devel
Suggests:       build
# bnc#804006
Suggests:       osc
Suggests:       gcc-fortran
Suggests:       gcc-objc
# Matz thinks people want that
Suggests:       mpfr-devel
Suggests:       ccache
Suggests:       icecream
Suggests:       subversion-doc
Suggests:       wiggle
Suggests:       oprofile
Suggests:       libgssglue-devel
Suggests:       audit-devel
Suggests:       nasm

%description devel_basis
Minimal set of tools for compiling and linking applications.

%files devel_basis
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_basis.txt

%package devel_C_C++
%pattern_development
Summary:        C/C++ Development
Group:          Metapackages
Provides:       pattern() = devel_C_C++
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3240
Provides:       pattern-visible()
Requires:       pattern() = devel_basis
# from data/DEVEL-C-C++
Recommends:     glibc-info
Recommends:     boost-devel
Recommends:     boost-jam
Recommends:     posix_cc
Recommends:     swig
Recommends:     valgrind
Recommends:     ltrace
Suggests:       ddd
# 403368
Suggests:       dejagnu
Suggests:       expect

%description devel_C_C++
Tools and libraries for software development using C/C++ and other derivative of the C programming language.

%files devel_C_C++
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_C_C++.txt

%package devel_gnome
%pattern_development
Summary:        GNOME Development
Group:          Metapackages
Provides:       pattern() = devel_gnome
Provides:       pattern-icon() = pattern-gnome-devel
Provides:       pattern-order() = 3160
Provides:       pattern-visible()
Requires:       pattern() = devel_C_C++
Requires:       pattern() = gnome_basis
# from data/DEVEL-GNOME
Recommends:     cairo-devel
Recommends:     clutter-devel
Recommends:     clutter-gst-devel
Recommends:     clutter-gtk-devel
Recommends:     evolution-data-server-devel
Recommends:     gdk-pixbuf-devel
Recommends:     glib2-devel
Recommends:     libgnome-desktop-3-devel
Recommends:     gnome-menus-devel
Recommends:     gnome-online-accounts-devel
Recommends:     gtk2-devel
Recommends:     gtk3-devel
Recommends:     gtksourceview-devel
Recommends:     gucharmap-devel
Recommends:     json-glib-devel
Recommends:     libcanberra-devel
Recommends:     libgdata-devel
Recommends:     libgnome-keyring-devel
Recommends:     libgsf-devel
Recommends:     libgtop-devel
Recommends:     libgweather-devel
Recommends:     libnotify-devel
Recommends:     librsvg-devel
Recommends:     libsoup-devel
Recommends:     libwebkitgtk-devel
Recommends:     libwnck-devel
Recommends:     pango-devel
Recommends:     tracker-devel
Recommends:     vte-devel
# Build tools
Recommends:     gnome-common
Recommends:     gnome-doc-utils-devel
Recommends:     gobject-introspection-devel
Recommends:     gtk-doc
Recommends:     intltool
Recommends:     itstool
Recommends:     vala
Recommends:     yelp-tools
Suggests:       python-gobject-devel

%description devel_gnome
GNOME development packages.

%files devel_gnome
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_gnome.txt

%package devel_ide
%pattern_development
Summary:        Integrated Development Environments
Group:          Metapackages
Provides:       pattern() = devel_ide
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3260
Provides:       pattern-visible()
Requires:       pattern() = devel_basis
# from data/DEVEL-IDE
Recommends:     monodevelop
Suggests:       anjuta

%description devel_ide
Integrated Development Environments.

%files devel_ide
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_ide.txt

%package devel_java
%pattern_development
Summary:        Java Development
Group:          Metapackages
Provides:       pattern() = devel_java
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3300
Provides:       pattern-visible()
# from data/DEVEL-Java
Recommends:     ant
Recommends:     ant-antlr
Recommends:     ant-apache-bcel
Recommends:     ant-apache-bsf
Recommends:     ant-apache-log4j
Recommends:     ant-apache-oro
Recommends:     ant-apache-regexp
Recommends:     ant-apache-resolver
Recommends:     ant-commons-logging
Recommends:     ant-javadoc
Recommends:     ant-javamail
Recommends:     ant-jdepend
Recommends:     ant-jmf
Recommends:     ant-junit
Recommends:     ant-manual
Recommends:     ant
Recommends:     ant-scripts
Recommends:     ant-swing
Recommends:     ant
Recommends:     log4j
Recommends:     xalan-j2
Recommends:     xerces-j2
Recommends:     xml-commons-apis
Recommends:     xml-commons-resolver
Recommends:     xml-commons-which10
Recommends:     java-1_8_0-openjdk
%ifarch %ix86
Recommends:     icedtea-web
%endif
Recommends:     java-1_5_0-gcj-compat-devel
Suggests:       gnu-jaf
Suggests:       jakarta-commons-beanutils
Suggests:       jakarta-commons-codec
Suggests:       jakarta-commons-collections
Suggests:       jakarta-commons-daemon
Suggests:       jakarta-commons-dbcp
Suggests:       jakarta-commons-digester
Suggests:       jakarta-commons-discovery
Suggests:       jakarta-commons-el
Suggests:       jakarta-commons-fileupload
Suggests:       jakarta-commons-httpclient3
Suggests:       jakarta-commons-lang
Suggests:       jakarta-commons-launcher
Suggests:       jakarta-commons-logging
Suggests:       jakarta-commons-modeler
Suggests:       jakarta-commons-pool
Suggests:       jakarta-commons-validator
Suggests:       javacc
Suggests:       jdepend
Suggests:       mysql-connector-java
# just an editor
Suggests:       jedit
Suggests:       java-1_8_0-openjdk-devel
Suggests:       mx4j
Suggests:       ant-javamail
Suggests:       geronimo-j2ee-1_4-apis

%description devel_java
Tools and libraries for software development using the Java programming language.

%files devel_java
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_java.txt

%package devel_kde_frameworks
%pattern_development
Summary:        KDE Frameworks Development
Group:          Metapackages
Provides:       pattern() = devel_kde_frameworks
Provides:       pattern-icon() = pattern-kde-devel
Provides:       pattern-order() = 3180
Provides:       pattern-visible()
Requires:       pattern() = devel_C_C++
Recommends:     pattern() = devel_qt5
Recommends:     cmake
Recommends:     extra-cmake-modules
Recommends:     appstream-qt5-devel
Recommends:     attica-qt5-devel
Recommends:     frameworkintegration-devel
Recommends:     kactivities5-devel
Recommends:     karchive-devel
Recommends:     kauth-devel
Recommends:     kbookmarks-devel
Recommends:     kcmutils-devel
Recommends:     kcodecs-devel
Recommends:     kcompletion-devel
Recommends:     kconfig-devel
Recommends:     kconfigwidgets-devel
Recommends:     kcoreaddons-devel
Recommends:     kcrash-devel
Recommends:     kdbusaddons-devel
Recommends:     kdeclarative-devel
Recommends:     kded-devel
Recommends:     kdelibs4support-devel
Recommends:     kdesignerplugin-devel
Recommends:     kdesu-devel
Recommends:     kdewebkit-devel
Recommends:     kdnssd-framework-devel
Recommends:     kdoctools-devel
Recommends:     kemoticons-devel
Recommends:     kglobalaccel-devel
Recommends:     kguiaddons-devel
Recommends:     khtml-devel
Recommends:     ki18n-devel
Recommends:     kiconthemes-devel
Recommends:     kidletime-devel
Recommends:     kinit-devel
Recommends:     kio-devel
Recommends:     kitemmodels-devel
Recommends:     kitemviews-devel
Recommends:     kjobwidgets-devel
Recommends:     kjs-devel
Recommends:     kjsembed-devel
Recommends:     kmediaplayer-devel
Recommends:     knewstuff-devel
Recommends:     knotifications-devel
Recommends:     knotifyconfig-devel
Recommends:     kpackage-devel
Recommends:     kparts-devel
Recommends:     kpeople5-devel
Recommends:     kplotting-devel
Recommends:     kpty-devel
Recommends:     kross-devel
Recommends:     krunner-devel
Recommends:     kservice-devel
Recommends:     ktexteditor-devel
Recommends:     ktextwidgets-devel
Recommends:     kunitconversion-devel
Recommends:     kwallet-devel
Recommends:     kwidgetsaddons-devel
Recommends:     kwindowsystem-devel
Recommends:     kxmlgui-devel
Recommends:     kxmlrpcclient5-devel
Recommends:     libKF5ModemManagerQt-devel
Recommends:     libKF5NetworkManagerQt-devel
Recommends:     libpolkit-qt5-1-devel
Recommends:     phonon4qt5-devel
Recommends:     plasma-framework-devel
Recommends:     solid-devel
Recommends:     sonnet-devel
Recommends:     threadweaver-devel
Recommends:     alsa-devel
Recommends:     aspell-devel
Recommends:     avahi-compat-mDNSResponder-devel
Recommends:     cups-devel
Recommends:     cyrus-sasl-devel
Recommends:     doxygen
Recommends:     giflib-devel
Recommends:     icecream
Recommends:     ImageMagick-devel
Recommends:     krb5-devel
Recommends:     libao-devel
Recommends:     libattr-devel
Recommends:     libcurl-devel
Recommends:     libgpgme-devel
Recommends:     libidn-devel
Recommends:     libjpeg62-devel
Recommends:     libmal-devel
Recommends:     libopenssl-devel
Recommends:     libpisock-devel
Recommends:     libpng15-devel
Recommends:     libpng15-compat-devel
Recommends:     libpoppler-devel
Recommends:     libqimageblitz-devel
Recommends:     libsmbclient-devel
Recommends:     libtiff-devel
Recommends:     libusb-compat-devel
Recommends:     libxklavier-devel
Recommends:     libxml2-devel
Recommends:     libxslt-devel
Recommends:     NetworkManager-devel
Recommends:     pcre-devel
Recommends:     libSDL-devel
Recommends:     sqlite3-devel
Recommends:     wv2-devel
Recommends:     libbz2-devel
Recommends:     ggz-client-libs-devel
Recommends:     libqca2-qt5-devel
Recommends:     libavahi-devel
Recommends:     libavahi-qt4-devel
Recommends:     libopenexr-devel
Recommends:     enchant-devel
Recommends:     libjasper-devel
Recommends:     clucene-core-devel
Recommends:     libpulse-devel
Recommends:     libraw1394-devel
Recommends:     python-devel
Recommends:     libical-devel
Recommends:     libmysqlclient-devel
Recommends:     openldap2-devel
Recommends:     gettext-tools
Recommends:     libgpod-devel
Recommends:     libmtp-devel
Recommends:     loudmouth-devel
Recommends:     libdvdread-devel
Recommends:     libgphoto2-devel
Recommends:     gstreamer-devel
Recommends:     libxine-devel
Recommends:     bluez-devel
Recommends:     libpoppler-qt5-devel

%description devel_kde_frameworks
KDE Frameworks development packages.

%files devel_kde_frameworks
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_kde_frameworks.txt

%package devel_kde
%pattern_development
Summary:        KDE Development
Group:          Metapackages
Provides:       pattern() = devel_kde
Provides:       pattern-icon() = pattern-kde-devel
Provides:       pattern-order() = 3180
Provides:       pattern-visible()
Requires:       pattern() = devel_C_C++
Requires:       pattern() = devel_kde_frameworks
# from data/DEVEL-KDE
Recommends:     libkexiv2-devel
Recommends:     giflib-devel
Recommends:     baloo5-devel
Recommends:     bluez-qt-devel
Recommends:     kfilemetadata5-devel
Recommends:     khotkeys5-devel
Recommends:     kwayland-devel
Recommends:     kwin5-devel
Recommends:     libbluedevil5-devel
Recommends:     libkdecoration2-devel
Recommends:     libkscreen2-devel
Recommends:     libksysguard5-devel
Recommends:     oxygen5-devel
Recommends:     plasma5-workspace-devel
Recommends:     systemsettings5-devel
Suggests:       libkdcraw-devel
Suggests:       libkipi-devel
Suggests:       freeglut-devel
Suggests:       graphviz
Suggests:       icecream-monitor
Suggests:       libkdepimlibs-devel
Suggests:       libkdegames-devel
Suggests:       libkmahjongg-devel
Suggests:       libvisual-devel
Suggests:       meanwhile-devel
Suggests:       net-snmp-devel
Suggests:       mono-kde4
Suggests:       ruby-kde4
Suggests:       python-kdebase4
Suggests:       libkonq-devel
Suggests:       antlr-devel
Suggests:       aqbanking-devel
Suggests:       audiofile-devel
Suggests:       avogadro-devel
Suggests:       cdparanoia-devel
Suggests:       chmlib-devel
Suggests:       cln-devel
Suggests:       commoncpp2-devel
Suggests:       fftw3-devel
Suggests:       file-devel
Suggests:       flac-devel
Suggests:       fribidi-devel
Suggests:       getdata-devel
Suggests:       ghostscript-devel
Suggests:       glew-devel
Suggests:       gpsd-devel
Suggests:       grantlee-devel
Suggests:       GraphicsMagick-devel
Suggests:       gsl-devel
Suggests:       gwenhywfar-devel
Suggests:       help2man
Suggests:       htmldoc
Suggests:       hunspell-devel
Suggests:       hwinfo-devel
Suggests:       kate-devel
Suggests:       kdesdk4-scripts
Suggests:       kdevelop4-devel
Suggests:       kdevelop4-pg-qt-devel
Suggests:       lensfun-devel
Suggests:       libalkimia-devel
Suggests:       libarchive-devel
Suggests:       libassuan-devel
Suggests:       libbluedevil-devel
Suggests:       libbonoboui-devel
Suggests:       libcap-ng-devel
Suggests:       libcdio-devel
Suggests:       libcfitsio-devel
Suggests:       libcppunit-devel
Suggests:       libdbusmenu-qt-devel
Suggests:       libdjvulibre-devel
Suggests:       libdmtx-devel
Suggests:       libeigen2-devel
Suggests:       libepub-devel
Suggests:       libesd-devel
Suggests:       libexempi-devel
Suggests:       libeXosip2-devel
Suggests:       libfli-devel
Suggests:       libgadu-devel
Suggests:       libgcal-devel
Suggests:       libgmm++-devel
Suggests:       libgnomecanvas-devel
Suggests:       libgnome-devel
Suggests:       libgudev-1_0-devel
Suggests:       libicu-devel
Suggests:       libindi-devel
Suggests:       libiodbc-devel
Suggests:       libiw-devel
Suggests:       libjack-devel
Suggests:       libkcddb4-devel
Suggests:       libkcompactdisc4-devel
Suggests:       libkdeedu4-devel
Suggests:       libkdevplatform-devel
Suggests:       libkface-devel
Suggests:       libkgeomap-devel
Suggests:       libksane-devel
Suggests:       libktoblzcheck1-devel
Suggests:       libktorrent-devel
Suggests:       liblastfm-devel
Suggests:       liblazy-devel
Suggests:       liblcms2-devel
Suggests:       liblqr-devel
Suggests:       libmediawiki1
Suggests:       libmediawiki-devel
Suggests:       libmms-devel
Suggests:       libmono-2_0-devel
Suggests:       libmpcdec-devel
Suggests:       libmsn-devel
Suggests:       libmusicbrainz3-devel
Suggests:       libmusicbrainz-devel
Suggests:       libmygpo-qt-devel
Suggests:       libnetcdf-devel
Suggests:       libnetpbm-devel
Suggests:       libnl-1_1-devel
Suggests:       libnova-devel
Suggests:       libofx-devel
Suggests:       libogg-devel
Suggests:       liboil-devel
Suggests:       libopenbabel-devel
Suggests:       libotr-devel
Suggests:       libpackagekit-qt2-devel
Suggests:       libpackagekit-qt-devel
Suggests:       libpng12-devel
Suggests:       libpodofo-devel
Suggests:       libpqxx-devel
Suggests:       libpth-devel
Suggests:       libqalculate-devel
Suggests:       libqjson-devel
Suggests:       libqscintilla-devel
Suggests:       libraw-devel
Suggests:       librcps-devel
Suggests:       libsamplerate-devel
Suggests:       libselinux-devel
Suggests:       libsepol-devel
Suggests:       libsigc++2-devel
Suggests:       libsmokegen-devel
Suggests:       libsmokekde-devel
Suggests:       libsmokeqt-devel
Suggests:       libsndfile-devel
Suggests:       libspectre-devel
Suggests:       libspeechd-devel
Suggests:       libssh-devel
Suggests:       libtag-devel
Suggests:       libtheora-devel
Suggests:       libtidy-0_99-0-devel
Suggests:       libtunepimp-devel
Suggests:       libunicap-devel
Suggests:       libusbmuxd-devel
Suggests:       libv4l-devel
Suggests:       LibVNCServer-devel
Suggests:       libvorbis-devel
Suggests:       libwbxml2-devel
Suggests:       libwpd-devel
Suggests:       libwpg-devel
Suggests:       libxml++-devel
Suggests:       libyaz-devel
Suggests:       libzip-devel
Suggests:       linphone-devel
Suggests:       lirc-devel
Suggests:       lua-devel
Suggests:       marble-devel
Suggests:       mhash-devel
Suggests:       mono-qt4-devel
Suggests:       ocaml
Suggests:       ocaml-facile
Suggests:       okteta-devel
Suggests:       openconnect-devel
Suggests:       opencv-devel
Suggests:       openslp-devel
Suggests:       opensp-devel
Suggests:       pciutils-devel
Suggests:       perl-qt4-devel
Suggests:       postgresql-devel
Suggests:       python-kde4-devel
Suggests:       python-sip-devel
Suggests:       qhull-devel
Suggests:       qoauth-devel
Suggests:       qrencode-devel
Suggests:       QtZeitgeist-devel
Suggests:       qwt-devel
Suggests:       ruby-qt4-devel
Suggests:       sane-backends-devel
Suggests:       scons
Suggests:       speex-devel
Suggests:       subversion-devel
Suggests:       taglib-extras-devel
Suggests:       utempter-devel
Suggests:       xz-devel

%description devel_kde
KDE development packages.

%files devel_kde
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_kde.txt

%package devel_kernel
%pattern_development
Summary:        Linux Kernel Development
Group:          Metapackages
Provides:       pattern() = devel_kernel
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3320
Provides:       pattern-visible()
Requires:       pattern() = devel_basis
# from data/DEVEL-Kernel
Recommends:     kernel-source
# bnc#582415
Recommends:     ctags
Recommends:     diffstat
Recommends:     git-core
Recommends:     indent
Recommends:     patchutils
Recommends:     quilt
Recommends:     gitk
Recommends:     git-email
Recommends:     kernel-syms
Suggests:       kernel-debug
Suggests:       gitk
Suggests:       kernel-docs
Suggests:       cscope

%description devel_kernel
Tools for Linux kernel development.

%files devel_kernel
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_kernel.txt

%package devel_mono
%pattern_development
Summary:        .NET Development
Group:          Metapackages
Provides:       pattern() = devel_mono
Provides:       pattern-icon() = pattern-mono
Provides:       pattern-order() = 3220
Provides:       pattern-visible()
# from data/DEVEL-Mono
Recommends:     mono-core
Recommends:     mono-devel
Recommends:     monodevelop
Recommends:     apache2-mod_mono
Recommends:     boo
Recommends:     dbus-1-mono
Recommends:     gsf-sharp
Recommends:     gtk-sharp2-complete
Recommends:     gtk-sharp2-doc
Recommends:     gtk-sharp2-gapi
Recommends:     gtksourceview-sharp2
Recommends:     ikvm
Recommends:     mono-basic
Recommends:     mono-data
Recommends:     mono-data-oracle
Recommends:     mono-data-postgresql
Recommends:     mono-data-sqlite
Recommends:     monodoc-core
Recommends:     mono-extras
Recommends:     mono-locale-extras
Recommends:     mono-nunit
Recommends:     mono-tools
Recommends:     mono-web
Recommends:     mono-winforms
Suggests:       mono-debugger
Suggests:       rsvg2-sharp
Suggests:       vte016-sharp

%description devel_mono
Tools and libraries for .NET development using Mono.

%files devel_mono
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_mono.txt

%package devel_perl
%pattern_development
Summary:        Perl Development
Group:          Metapackages
Provides:       pattern() = devel_perl
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3340
Provides:       pattern-visible()
# from data/DEVEL-Perl
Recommends:     perlref
Recommends:     perl-doc
Suggests:       perl-Algorithm-Diff
Suggests:       perl-AppConfig
Suggests:       perl-Authen-SASL
Suggests:       perl-Authen-SASL-Cyrus
Suggests:       perl-BIND-Conf_Parser
Suggests:       perl-BSD-Resource
Suggests:       perl-CDDB_get
Suggests:       perl-CGI-Application
Suggests:       perl-Carp-Assert
Suggests:       perl-Class-Accessor
Suggests:       perl-Class-Data-Inheritable
Suggests:       perl-Class-Date
Suggests:       perl-Class-MethodMaker
Suggests:       perl-Class-Multimethods
Suggests:       perl-Class-WhiteHole
Suggests:       perl-Config-General
Suggests:       perl-Config-IniFiles
Suggests:       perl-Convert-TNEF
Suggests:       perl-Convert-UUlib
Suggests:       perl-Crypt-Blowfish
Suggests:       perl-Crypt-CBC
Suggests:       perl-Crypt-SSLeay
Suggests:       perl-DBD-CSV
Suggests:       perl-DBD-ODBC
Suggests:       perl-DBD-Pg
Suggests:       perl-DBD-SQLite
Suggests:       perl-DBD-XBase
Suggests:       perl-DBD-mysql
Suggests:       perl-Devel-CoreStack
Suggests:       perl-Devel-Symdump
Suggests:       perl-Encode-HanExtra
Suggests:       perl-Encode-JIS2K
Suggests:       perl-ExtUtils-F77
Suggests:       perl-File-MMagic
Suggests:       perl-File-Tail
Suggests:       perl-Font-AFM
Suggests:       perl-GD
Suggests:       perl-GD-Graph3d
Suggests:       perl-GDGraph
Suggests:       perl-GDTextUtil
Suggests:       perl-Getopt-Mixed
Suggests:       perl-Gtk2
Suggests:       perl-HTML-Clean
Suggests:       perl-HTML-FillInForm
Suggests:       perl-HTML-Format
Suggests:       perl-HTML-SimpleParse
Suggests:       perl-HTML-Template
Suggests:       perl-HTML-Template-Expr
Suggests:       perl-HTML-Template-JIT
Suggests:       perl-HTML-Tree
Suggests:       perl-HTTP-DAV
Suggests:       perl-HTTPS-Daemon
Suggests:       perl-IPC-Run
Suggests:       perl-Image-Size
Suggests:       perl-Inline
Suggests:       perl-Inline-C
Suggests:       perl-Log-Dispatch
Suggests:       perl-Log-Log4perl
Suggests:       perl-MIME-Lite
Suggests:       perl-MLDBM
Suggests:       perl-MLDBM-Sync
Suggests:       perl-Mcrypt
Suggests:       perl-Module-Info
Suggests:       perl-Net-DNS
Suggests:       perl-Net-Daemon
Suggests:       perl-Net-IP
Suggests:       perl-Net-Jabber
Suggests:       perl-Net-Netmask
Suggests:       perl-Net-Server
Suggests:       perl-Net-Telnet
Suggests:       perl-PDL
Suggests:       perl-Params-Validate
Suggests:       perl-Parse-Yapp
Suggests:       perl-PerlMagick
Suggests:       perl-Pod-HtmlPsPdf
Suggests:       perl-PostScript-Simple
Suggests:       perl-Quantum-Superpositions
Suggests:       perl-RPC-XML
Suggests:       perl-SGMLS
Suggests:       perl-SOAP-Lite
Suggests:       perl-SQL-Statement
Suggests:       perl-Set-Crontab
Suggests:       perl-Set-Object
Suggests:       perl-Set-Scalar
Suggests:       perl-Socket6
Suggests:       perl-Template-Toolkit
Suggests:       perl-Text-CSV_XS
Suggests:       perl-Text-DelimMatch
Suggests:       perl-Text-Iconv
Suggests:       perl-Tie-Cache
Suggests:       perl-Time-modules
Suggests:       perl-Unicode-Map8
Suggests:       perl-Unicode-String
Suggests:       perl-XML-LibXML
Suggests:       perl-XML-Simple
Suggests:       perl-XML-Stream
Suggests:       perl-XML-XSLT
Suggests:       perl-YAML
Suggests:       perl-libxml-perl
Suggests:       perl-Apache-AuthCookie
Suggests:       perl-Apache-AuthNetLDAP
Suggests:       perl-Apache-DBI
Suggests:       perl-Apache-Session
Suggests:       perl-Apache-SessionX
Suggests:       perl-Cairo
Suggests:       perl-Chart
Suggests:       perl-Convert-ASN1
Suggests:       perl-ExtUtils-Depends
Suggests:       perl-ExtUtils-PkgConfig
Suggests:       perl-FileHandle-Unget
Suggests:       perl-File-Type
Suggests:       perl-IO-String
Suggests:       perl-IO-Stty
Suggests:       perl-ldap
Suggests:       perl-ldap-ssl
Suggests:       perl-libconfigfile
Suggests:       perl-Mail-Mbox-MessageParser
Suggests:       perl-MIME-Types
Suggests:       perl-NetAddr-IP
Suggests:       perl-Net-IPv4Addr
Suggests:       perl-Net-SNMP
Suggests:       perl-NKF
Suggests:       perl-PDA-Pilot
Suggests:       perl-SNMP
Suggests:       perl-SVN-Simple
Suggests:       perl-Text-ChaSen
Suggests:       perl-Text-Kakasi
Suggests:       perl-Time-Duration
Suggests:       perl-Time-Period
Suggests:       perl-WeakRef
Suggests:       perl-XML-LibXSLT

%description devel_perl
Tools and libraries for software development using the Perl programming language.

%files devel_perl
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_perl.txt

%package devel_python
%pattern_development
Summary:        Python Development
Group:          Metapackages
Provides:       pattern() = devel_python
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3360
Provides:       pattern-visible()
# from data/DEVEL-Python
Recommends:     pychecker
Recommends:     python
Recommends:     python-devel
Suggests:       eric
Suggests:       libxml2-python
Suggests:       libxslt-python
Suggests:       python-cairo-devel
Suggests:       python-gnome-devel
Suggests:       python-gobject2-devel
Suggests:       python-gtk-devel
Suggests:       python-ldap
Suggests:       python-qt4
Suggests:       python-wxWidgets
Suggests:       python-xml
Suggests:       treeline
Suggests:       python-dateutil
Suggests:       python-fcgi
Suggests:       python-gdbm
Suggests:       python-httplib2
Suggests:       python-pyOpenSSL
Suggests:       python-opensync
Suggests:       python-pam
Suggests:       python-pygame
Suggests:       python-pyserial
Suggests:       python-Twisted
Suggests:       python-zope.interface

%description devel_python
Tools and libraries for software development using the Python programming language.

%files devel_python
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_python.txt

%package devel_python3
%pattern_development
Summary:        Python3 Developement
Group:          Metapackages
Provides:       pattern() = devel_python3
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3359
Provides:       pattern-visible()
# from data/DEVEL-Python3
Recommends:     python3
Recommends:     python3-devel
Suggests:       python3-lxml
Suggests:       python3-pip
Suggests:       python3-Cython
Suggests:       python3-setuptools
Suggests:       python3-requests
Suggests:       python3-pyOpenSSL
Suggests:       python3-pycrypto
Suggests:       python3-simplejson
Suggests:       python3-Sphinx
Suggests:       python3-docutils
Suggests:       python3-Jinja2
Suggests:       python3-coverage
Suggests:       python3-nose

%description devel_python3

%files devel_python3
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_python3.txt

%package devel_qt4
%pattern_development
Summary:        Qt 4 Development
Group:          Metapackages
Provides:       pattern() = devel_qt4
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3380
Provides:       pattern-visible()
# from data/DEVEL-QT4
Recommends:     libqt4-devel
Recommends:     libqt4-devel-doc
Recommends:     libqt4-sql-sqlite
Recommends:     libQtWebKit-devel
Suggests:       libqt4-sql-mysql
Suggests:       libqt4-sql-postgresql
Suggests:       libqt4-sql-unixODBC
# bnc#515160
Suggests:       qt-creator

%description devel_qt4
Tools and libraries for software development using Qt 4, the latest version of the Qt toolkit.

%files devel_qt4
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_qt4.txt

%package devel_qt5
%pattern_development
Summary:        Qt 5 Development
Group:          Metapackages
Provides:       pattern() = devel_qt5
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3381
Provides:       pattern-visible()
Recommends:     libqt5-qtbase-devel
Recommends:     libqt5-qtdeclarative-devel
# QPA headers are technicaly private, but one will most likely need them on Linux
Recommends:     libQt5Gui-private-headers-devel
Recommends:     libqt5-qtsvg-devel
Recommends:     libqt5-qttools-devel
Recommends:     libqt5-qtx11extras-devel
Recommends:     libqt5-qtxmlpatterns-devel
Suggests:       libqt5-qtimageformats-devel
Suggests:       libqt5-qtlocation-devel
Suggests:       libqt5-qtmultimedia-devel
Suggests:       libqt5-qtquick1-devel
Suggests:       libqt5-qtscript-devel
Suggests:       libqt5-qtsensors-devel
Suggests:       libqt5-qtserialport-devel
Suggests:       libqt5-qtwebsockets-devel
Suggests:       libQt5WebKit5-devel
Suggests:       libqt5-creator

%description devel_qt5
Tools and libraries for software development using Qt 5, the latest version of the Qt toolkit.

%files devel_qt5
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_qt5.txt

%package devel_rpm_build
%pattern_development
Summary:        RPM Build Environment
Group:          Metapackages
Provides:       pattern() = devel_rpm_build
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3280
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/DEVEL-RPM-Build-Environment
Requires:       man
Requires:       netcfg
Requires:       rpm-build
Recommends:     libtool
Suggests:       build
Suggests:       inst-source-utils
Suggests:       libsolv-devel

%description devel_rpm_build
Minimal set of tools and libraries for building packages using the RPM package manager.

%files devel_rpm_build
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_rpm_build.txt

%package devel_ruby
%pattern_development
Summary:        Ruby Development
Group:          Metapackages
Provides:       pattern() = devel_ruby
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3420
Provides:       pattern-visible()
# from data/DEVEL-Ruby
Requires:       ruby
Requires:       rubygems
Suggests:       ruby-devel
Suggests:       ruby-doc-html
Suggests:       ruby-doc-ri
Suggests:       ruby-examples
Suggests:       ruby-fcgi
Suggests:       rubygem-mysql
Suggests:       rubygem-racc
Suggests:       ruby-test-suite
Suggests:       ruby-tk

%description devel_ruby
Tools and libraries for software development using the Ruby programming language.

%files devel_ruby
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_ruby.txt

%package devel_tcl
%pattern_development
Summary:        Tcl/Tk Development
Group:          Metapackages
Provides:       pattern() = devel_tcl
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3480
Provides:       pattern-visible()
# from data/DEVEL-Tcl
Recommends:     tcl
Recommends:     tcl-devel
Recommends:     tk
Recommends:     tk-devel
Recommends:     bwidget
Recommends:     expect
Recommends:     frink
Recommends:     itcl
Recommends:     iwidgets
Recommends:     snack
Recommends:     tcllib
Recommends:     tcludp
Recommends:     tclx
Recommends:     tdom
Recommends:     tix
Recommends:     tkcon
Recommends:     tkimg
Recommends:     tktable
Recommends:     tls
# #387771
Recommends:     itcl-devel
Recommends:     itk
Recommends:     expect-devel
# #387771
Recommends:     tclplug
Suggests:       PgTcl
Suggests:       scotty
Suggests:       sqlite3-tcl
Suggests:       vtcl

%description devel_tcl
Tools and libraries for development using Tcl and Tk.

%files devel_tcl
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_tcl.txt

%package devel_web
%pattern_development
Summary:        Web Development
Group:          Metapackages
Provides:       pattern() = devel_web
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3440
Provides:       pattern-visible()
Requires:       pattern() = lamp_server
# from data/DEVEL-Web
Recommends:     apache2-devel
Suggests:       html-dtd
Suggests:       iso_ent
Suggests:       latex2html
Suggests:       perl-CGI-Application
Suggests:       perl-HTML-Clean
Suggests:       perl-HTML-FillInForm
Suggests:       perl-HTML-Format
Suggests:       perl-HTML-SimpleParse
Suggests:       perl-HTML-Tagset
Suggests:       perl-HTML-Template
Suggests:       perl-HTML-Template-Expr
Suggests:       perl-HTML-Template-JIT
Suggests:       perl-HTML-Tree
Suggests:       perl-HTTP-DAV
Suggests:       perl-HTTPS-Daemon
Suggests:       perl-Pod-HtmlPsPdf
Suggests:       php5
Suggests:       php5-bcmath
Suggests:       php5-bz2
Suggests:       php5-calendar
Suggests:       php5-ctype
Suggests:       php5-curl
Suggests:       php5-dba
Suggests:       php5-devel
Suggests:       php5-dom
Suggests:       php5-exif
Suggests:       php5-fastcgi
Suggests:       php5-ftp
Suggests:       php5-gd
Suggests:       php5-gettext
Suggests:       php5-gmp
Suggests:       php5-iconv
Suggests:       php5-imap
Suggests:       php5-ldap
Suggests:       php5-mbstring
Suggests:       php5-mcrypt
Suggests:       php5-mysql
Suggests:       php5-odbc
Suggests:       php5-openssl
Suggests:       php5-pear
Suggests:       php5-pgsql
Suggests:       php5-shmop
Suggests:       php5-snmp
Suggests:       php5-sockets
Suggests:       php5-sysvsem
Suggests:       php5-sysvshm
Suggests:       php5-tidy
Suggests:       php5-wddx
Suggests:       php5-xsl
Suggests:       php5-zlib
Suggests:       tidy
Suggests:       xhtml-dtd
Suggests:       xmlcharent
Suggests:       apache2-worker
Suggests:       apache2-mod_tidy
Suggests:       kfilereplace
Suggests:       kimagemapeditor
Suggests:       klinkstatus
Suggests:       kde3-quanta
Suggests:       kompozer
Suggests:       tomcat
Suggests:       tomcat-admin-webapps
Suggests:       tomcat-webapps
Suggests:       html2text

%description devel_web
Tools and libraries for Web application development.

%files devel_web
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_web.txt

%package devel_yast
%pattern_development
Summary:        YaST Development
Group:          Metapackages
Provides:       pattern() = devel_yast
Provides:       pattern-icon() = pattern-basis-devel
Provides:       pattern-order() = 3460
Provides:       pattern-visible()
# from data/DEVEL-YaST
Recommends:     yast2-devtools
Recommends:     yast2-testsuite
# Bug 304645 gives the list below:
Recommends:     yast2-pkg-bindings-devel-doc
Recommends:     yast2-core-devel
Recommends:     yast2-devel-doc
Recommends:     yast2-installation-devel-doc
Recommends:     yast2-network-devel-doc
Recommends:     yast2-nis-server-devel-doc
Recommends:     yast2-printer-devel-doc
Recommends:     yast2-storage-devel
Recommends:     yast2-perl-bindings
Recommends:     yast2-python-bindings
Recommends:     yast2-ruby-bindings
Recommends:     git
Recommends:     libzypp-devel
Recommends:     yast2-libyui-devel
Recommends:     yast2-ycp-ui-bindings-devel
Recommends:     libyui-qt-devel
Recommends:     libyui-ncurses-devel
Suggests:       inst-source-utils
Suggests:       createrepo

%description devel_yast
Tools and libraries for developing YaST modules, the setup and configuration tool for openSUSE.

%files devel_yast
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/devel_yast.txt

%package dhcp_dns_server
%pattern_serverfunctions
Summary:        DHCP and DNS Server
Group:          Metapackages
Provides:       pattern() = dhcp_dns_server
Provides:       pattern-icon() = yast-dns-server
Provides:       pattern-order() = 3040
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/DHCP_DNS
Recommends:     bind
Recommends:     dhcp-relay
Recommends:     dhcp-server
Recommends:     dhcp-tools
Recommends:     yast2-dhcp-server
Recommends:     yast2-dns-server
Recommends:     bind-doc

%description dhcp_dns_server
Software to set up a server for the Dynamic Host Configuration Protocol (DHCP) and the Domain Name System (DNS) services. DHCP provides configuration parameters to client computers to integrate them into a network, whereas DNS delivers information associated with domain names, in particular, the IP address.

%files dhcp_dns_server
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/dhcp_dns_server.txt

%package directory_server
%pattern_serverfunctions
Summary:        Directory Server (LDAP)
Group:          Metapackages
Provides:       pattern() = directory_server
Provides:       pattern-icon() = yast-ldap-server
Provides:       pattern-order() = 3060
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/LDAP_SERVER
Recommends:     nss_ldap
Recommends:     openldap2
Recommends:     pam_ldap
Recommends:     yast2-ldap-server
%ifarch x86_64
Recommends:     nss_ldap-32bit
Recommends:     pam_ldap-32bit
%endif

%description directory_server
Software to set up a directory server with OpenLDAP. The Lightweight Directory Access Protocol (LDAP) is used to access online directory services.

%files directory_server
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/directory_server.txt

%package enlightenment
%pattern_graphicalenvironments
Summary:        Enlightment
Group:          Metapackages
Provides:       pattern() = enlightenment
Provides:       pattern-icon() = pattern-enlightenment
Provides:       pattern-order() = 1500
Provides:       pattern-visible()
Obsoletes:      %{name}-e17
Requires:       pattern() = x11
Recommends:     pattern() = multimedia
Recommends:     pattern() = imaging
Requires:       enlightenment
Requires:       lightdm
Recommends:     terminology
Recommends:     desktop-branding

# from data/COMMON-DESKTOP
Recommends:     droid-fonts
Recommends:     MozillaFirefox
Recommends:     desktop-data-openSUSE
# bnc#508120
Recommends:     xdg-user-dirs

# from data/COMMON-DESKTOP-OPT
# packages a GTK application
Recommends:     gutenprint
# MAYBE later lsb-graphics
Recommends:     icedtea-web
# give net shares
Recommends:     samba
# needs python-qt4, see#649280#14
Suggests:       hplip

# Add some Common useful programs that don't require another DE
Recommends:     clementine
Recommends:     rage
Recommends:     leafpad
Recommends:     lekha

%description enlightenment
Enlightment Window Manager and applications

%files enlightenment
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/enlightenment.txt

%package enhanced_base
%pattern_basetechnologies
Summary:        Enhanced Base System
Group:          Metapackages
Provides:       pattern() = enhanced_base
Provides:       pattern-icon() = pattern-basis
Provides:       pattern-order() = 1060
Provides:       pattern-visible()
Requires:       pattern() = basesystem
Recommends:     pattern() = apparmor
Recommends:     pattern() = yast2_basis
Recommends:     pattern() = enhanced_base_opt
Recommends:     pattern() = sw_management
# from data/ENHANCED-BASIS
# having a ftp command line client is good for moving log files
Recommends:     lukemftp
# needed for detecting software raid - required by yast2-storage too
Recommends:     mdadm
# #303857
Recommends:     kpartx
Recommends:     dmraid
# man by default (#304687)
Recommends:     man
# fuser (psmisc) by default (#304694)
Recommends:     psmisc
# firewall by default
Recommends:     SuSEfirewall2
# getfacl and setfacl
Recommends:     acl
# getattr and setattr
Recommends:     attr
# compressor is interesting
Recommends:     bzip2
# printing considered cool
Recommends:     cups-client
Recommends:     curl
Recommends:     cyrus-sasl-gssapi
Recommends:     cyrus-sasl-crammd5
Recommends:     cyrus-sasl-digestmd5
Recommends:     cyrus-sasl-plain
# bnc#430895
# cyrus-sasl-saslauthd
Recommends:     db-utils
Recommends:     diffutils
Recommends:     ethtool
Recommends:     e2fsprogs
Recommends:     eject
Recommends:     file
Recommends:     fillup
Recommends:     findutils
# /bin/ip considered useful
Recommends:     iproute2
# ping is required for network tests
Recommends:     iputils
# pager
Recommends:     less
# make it bunt
Recommends:     gfxboot
Recommends:     parted
Recommends:     mailx
Recommends:     genisoimage
# we want a ssh server to be available
Recommends:     openssh
Recommends:     perl-base
# we rely on cron for daily/hourly
Recommends:     cronie
# create log file tars
Recommends:     tar
Recommends:     wget
# split out of ncurses
Recommends:     ncurses-utils
# we want a branded boot
Recommends:     plymouth-branding-openSUSE
# we want a branded grub2 too #757683
Recommends:     grub2-branding-openSUSE
# #302569
Recommends:     alsa-plugins
# useful for debugging
Recommends:     strace
Recommends:     lsof
# mount NTFS rw
Recommends:     ntfs-3g
# cups server for remote printing queues
Recommends:     cups
# delta rpms are considered cool for updates
Recommends:     deltarpm
Recommends:     autofs
Recommends:     bind-utils
# Make plymouth the new default bootsplash
Recommends:     plymouth
Recommends:     cyrus-sasl
Recommends:     dosfstools
Recommends:     gawk
Recommends:     gettext-runtime
Recommends:     glibc-locale
Recommends:     gpart
Recommends:     gpg2
Recommends:     gpm
Recommends:     hdparm
Recommends:     ifplugd
Recommends:     info
Recommends:     libatm1
Recommends:     master-boot-code
Recommends:     syslinux
Recommends:     netcat-openbsd
Recommends:     nfs-client
Recommends:     nfsidmap
Recommends:     nscd
Recommends:     ntfsprogs
Recommends:     openldap2-client
Recommends:     openslp
Recommends:     pciutils
%ifarch %ix86 x86_64
Recommends:     dmidecode
Recommends:     acpica
%endif
%ifarch %ix86 x86_64
Recommends:     ucode-intel
Recommends:     ucode-amd
%endif
Recommends:     pm-utils
Recommends:     postfix
Recommends:     tuned
Recommends:     ppp
Recommends:     pptp
Recommends:     recode
Recommends:     release-notes-openSUSE
Recommends:     smp_utils
Recommends:     sg3_utils
Recommends:     lsscsi
Recommends:     sudo
Recommends:     timezone
Recommends:     udev
Recommends:     utempter
Recommends:     wireless-tools
# Our editor of choice
Recommends:     vim
Recommends:     xinetd
Recommends:     ntp
Recommends:     yp-tools
Recommends:     ypbind
%ifarch ppc
Recommends:     lilo
Recommends:     pdisk
Recommends:     powerpc32
# #303737
Recommends:     mouseemu
%endif
%ifarch x86_64
Recommends:     glibc-32bit
Recommends:     glibc-locale-32bit
Recommends:     numactl
%endif
# #375103
Recommends:     cifs-utils
# lsusb is good for debugging USB devices - #401593
Recommends:     usbutils
Recommends:     cryptsetup
# Bug 424707 - Feature "Command not found" for openSUSE by default
Recommends:     scout
Recommends:     command-not-found
Recommends:     lsb-release
# autoconfig new printers - bnc#808014
Recommends:     udev-configure-printer
Suggests:       reiserfs
# #594778
Suggests:       tmpwatch

%description enhanced_base
This is the enhanced base runtime system with lots of convenience packages.

%files enhanced_base
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/enhanced_base.txt

%package enhanced_base_opt
%pattern_basetechnologies
Summary:        Enhanced Base System
Group:          Metapackages
Provides:       pattern() = enhanced_base_opt
Provides:       pattern-extends() = enhanced_base
Provides:       pattern-icon() = yast-software
Provides:       pattern-order() = 1040
# from data/ENHANCED-BASIS-OPT
Recommends:     at
Recommends:     bc
Recommends:     cracklib-dict-full
Recommends:     OpenPrintingPPDs
Recommends:     dos2unix
Recommends:     ed
Recommends:     finger
# 304995
# fbset
Recommends:     groff
Recommends:     initviocons
%ifarch ppc
Recommends:     hfsutils
%endif
# Current systems suffer from entropy starvation
%ifarch %ix86 x86_64 ppc64 ppc64le
Recommends:     haveged
%endif
Recommends:     irqbalance
Recommends:     joe
Recommends:     ksh
Recommends:     ksymoops
Recommends:     man-pages
Recommends:     man-pages-posix
Recommends:     manufacturer-PPDs
%ifarch x86_64
Recommends:     mcelog
%endif
Recommends:     mpt-status
Recommends:     pax
Recommends:     perl-TermReadLine-Gnu
Recommends:     prctl
Recommends:     procinfo
Recommends:     procmail
Recommends:     providers
Recommends:     rsync
Recommends:     sash
Recommends:     screen
Recommends:     setserial
Recommends:     sharutils
Recommends:     smartmontools
Recommends:     strace
Recommends:     tcpdump
Recommends:     tcsh
Recommends:     telnet
Recommends:     terminfo
Recommends:     vlan
Recommends:     w3m
Recommends:     wol
Recommends:     zisofs-tools
Recommends:     zsh
Suggests:       acpid
Suggests:       xz
Suggests:       zip
Suggests:       unzip
Suggests:       cpupower
Suggests:       delayacct-utils
Suggests:       hfsutils
Suggests:       jfsutils
Suggests:       ocfs2-tools
Suggests:       xfsprogs
Suggests:       lynx
Suggests:       w3m-el
Suggests:       pwgen
# delta apply
Suggests:       xdelta
# needed as soon as you want to do kerberos authentication
Suggests:       cyrus-sasl-gssapi
# tool for xfs
Suggests:       xfsdump
# #393589
Suggests:       open-iscsi
# #437252
Suggests:       pam_ssh
# for old installs
Suggests:       lilo
# used by yast2-iscsi-server
Suggests:       tgt
# DELL computers mainly #403270, but #441079
Suggests:       biosdevname
# bnc#388570
Suggests:       kerneloops
# #754959
%ifarch %ix86 x86_64
Suggests:       hyper-v
%endif
# alternative boot loaders
Suggests:       elilo
Suggests:       efibootmgr
# debugging boot
Suggests:       systemd-analyze

%description enhanced_base_opt
This is the enhanced base runtime system with lots of convenience packages.

%files enhanced_base_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/enhanced_base_opt.txt

%package file_server
%pattern_serverfunctions
Summary:        File Server
Group:          Metapackages
Provides:       pattern() = file_server
Provides:       pattern-icon() = yast-nfs_server
Provides:       pattern-order() = 2900
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/FILE-SERVER
Recommends:     nfsidmap
Recommends:     nfs-kernel-server
Recommends:     samba
Recommends:     yast2-nfs-server
Recommends:     yast2-samba-server
Recommends:     vsftpd
Recommends:     samba-client
Recommends:     samba-winbind
Recommends:     tftp
Recommends:     yast2-ftp-server
Recommends:     yast2-tftp-server
Suggests:       atftp

%description file_server
File services to host files so that they may be accessed or retrieved by other computers on the same network. This includes the FTP, SMB, and NFS protocols.

%files file_server
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/file_server.txt

%package fonts
%pattern_graphicalenvironments
Summary:        Fonts
Group:          Metapackages
Provides:       pattern() = fonts
Provides:       pattern-icon() = yast-x11
Provides:       pattern-order() = 1700
Provides:       pattern-visible()
Recommends:     pattern() = fonts_opt
# from data/FONTS
Recommends:     ghostscript-fonts-std
Recommends:     xorg-x11-fonts-core
Recommends:     google-roboto-fonts
Recommends:     dejavu-fonts
Recommends:     ifnteuro
Recommends:     liberation-fonts
# needed for instsys
Suggests:       IPAGothic
Suggests:       IPAMincho
Suggests:       IPAPGothic
Suggests:       IPAPMincho
#IPAUIGothic
Suggests:       bitstream-vera

%description fonts
Base fonts and font configuration.

%files fonts
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/fonts.txt

%package fonts_opt
%pattern_graphicalenvironments
Summary:        Fonts
Group:          Metapackages
Provides:       pattern() = fonts_opt
Provides:       pattern-extends() = fonts
Provides:       pattern-icon() = yast-x11
Provides:       pattern-order() = 1720
# from data/FONTS-OPT
Recommends:     efont-unicode
Recommends:     ghostscript-fonts-other
Recommends:     intlfnts
Recommends:     xorg-x11-fonts
Recommends:     droid-fonts
Recommends:     noto-sans
Recommends:     adobe-sourcecodepro-fonts
Recommends:     adobe-sourcesanspro-fonts
Recommends:     adobe-sourceserifpro-fonts
Recommends:     stix-fonts
Recommends:     ctan-latinmodern-fonts

%description fonts_opt
Base fonts and font configuration.

%files fonts_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/fonts_opt.txt

%package games
%pattern_desktopfunctions
Summary:        Games
Group:          Metapackages
Provides:       pattern() = games
Provides:       pattern-icon() = yast-joystick
Provides:       pattern-order() = 1900
Provides:       pattern-visible()
Requires:       pattern() = x11
# from data/GAMES
Suggests:       frozen-bubble
Suggests:       armagetron
Suggests:       circuslinux
Suggests:       csmash
Suggests:       solarwolf

%description games
A collection of games.

%files games
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/games.txt

%package gateway_server
%pattern_serverfunctions
Summary:        Internet Gateway
Group:          Metapackages
Provides:       pattern() = gateway_server
Provides:       pattern-icon() = yast-dsl
Provides:       pattern-order() = 3020
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/GATEWAY
Recommends:     wireshark
Recommends:     ddclient
Recommends:     fetchmail
Recommends:     ipsec-tools
Recommends:     quagga
Recommends:     radvd
Recommends:     rarpd
Recommends:     squid3
Recommends:     squidGuard
Suggests:       wwwoffle
Suggests:       mirror

%description gateway_server
Software to set up a proxy, firewall, and gateway server, including a virtual private network (VPN) gateway.

%files gateway_server
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gateway_server.txt

%package generic_server
%pattern_serverfunctions
Summary:        Generic Server
Group:          Metapackages
Provides:       pattern() = generic_server
Provides:       pattern-icon() = yast-ssh-server
Provides:       pattern-order() = 1130
Provides:       pattern-visible()
Requires:       openssh
Requires:       pattern() = basesystem
Requires:       pattern() = minimal_base
Recommends:     pattern() = yast2_basis
Recommends:     ntp
Recommends:     vim
Recommends:     screen
Recommends:     tmux
Recommends:     mosh
Recommends:     rsync
Recommends:     sensors
Recommends:     libyui-ncurses-pkg
Recommends:     libyui-ncurses
Recommends:     command-not-found

%description generic_server
Software that is useful to run on a server.

%files generic_server
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/generic_server.txt

%package gnome
%pattern_graphicalenvironments
Summary:        GNOME Desktop Environment
Group:          Metapackages
Provides:       pattern() = gnome
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 1010
Provides:       pattern-visible()
Requires:       pattern() = gnome_basis
Recommends:     pattern() = games
Recommends:     pattern() = imaging
Recommends:     pattern() = non_oss
Recommends:     pattern() = gnome_admin
Recommends:     pattern() = gnome_internet
Recommends:     pattern() = multimedia
Recommends:     pattern() = office
Recommends:     pattern() = gnome_utilities
# from data/GNOME-DESKTOP
#
# Official upstream
#
Recommends:     baobab
Recommends:     bijiben
# #302492
Recommends:     brasero
# bnc#366894
Recommends:     caribou
Recommends:     cheese
# #594593
Recommends:     empathy
Recommends:     eog
Recommends:     evince
Recommends:     evolution
Recommends:     file-roller
Recommends:     gcr-viewer
Recommends:     gedit
Recommends:     gnome-bluetooth
Recommends:     gnome-calculator
Recommends:     gnome-contacts
Recommends:     gnome-calculator
Recommends:     gnome-dictionary
Recommends:     gnome-documents
# #554954
Recommends:     gnome-disk-utility
Recommends:     gnome-font-viewer
Recommends:     gnome-maps
Recommends:     gnome-nettool
Recommends:     gnome-screenshot
Recommends:     gnome-system-monitor
# #447627
Recommends:     gnome-user-share
Recommends:     gucharmap
# #399801
Recommends:     mousetweaks
Recommends:     nautilus-sendto
Recommends:     orca
# #545263
Recommends:     seahorse
Recommends:     sushi
Recommends:     totem
Recommends:     totem-browser-plugin
Recommends:     vino
Recommends:     zenity
# Add an update notification icon
# GNOME per default relies on GNOME Software and
# the integration between PK and systemd, but there
# are strong opponents of this method for openSUSE.
Recommends:     pk-update-icon
#
# Packages that really make sense
#
Recommends:     deja-dup
# Tool for advanced configuration of printers
Recommends:     system-config-printer-applet
Recommends:     system-config-printer
# #608156
Recommends:     tracker
Recommends:     tracker-gui
Recommends:     tracker-miner-evolution
#
# Telepathy connection managers
#
Recommends:     telepathy-gabble
Recommends:     telepathy-haze
Recommends:     telepathy-idle
Recommends:     telepathy-salut
Recommends:     telepathy-sofiasip
# on Leap include the classic shell for similarity with SLE
Recommends:     gnome-shell-classic
Suggests:       dasher
Suggests:       gconf-editor
Suggests:       gnome-backgrounds
# bnc#698250
Suggests:       gnome-color-manager

%description gnome
The GNOME desktop environment is an intuitive and attractive desktop for users.

%files gnome
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome.txt

%package gnome_admin
%pattern_gnomedesktop
Summary:        GNOME Administration Tools
Group:          Metapackages
Provides:       pattern() = gnome_admin
Provides:       pattern-extends() = gnome
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 2040
Requires:       pattern() = basesystem
Requires:       pattern() = x11
# from data/GNOME-ADMIN
Recommends:     alacarte
# bnc#372207
Recommends:     vinagre

%description gnome_admin
Administration Tools e.g. for desktop lockdown

%files gnome_admin
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_admin.txt

%package gnome_basis
%pattern_graphicalenvironments
Summary:        GNOME Base System
Group:          Metapackages
Provides:       pattern() = gnome_basis
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 1000
Provides:       pattern-visible()
Requires:       pattern() = basesystem
Requires:       pattern() = x11
Recommends:     pattern() = gnome_basis_opt
# from data/GNOME-BASIS
Requires:       gdm
Requires:       gnome-session
#
# Default sessions
# - Put in Recommends for now, to make sure the livecd will always build; but
#   ideally, should be in Requires
# - We also we explicitly put the packages required by those sessions, in case
#   gnome-session-*-session is not installable, to make sure the livecd is
#   somehow a bit usable
#
Recommends:     gnome-session-default-session
Recommends:     gnome-session-fallback-session
# default
Recommends:     gnome-settings-daemon
Recommends:     gnome-shell
#
# Low-level parts that we need
#
# bnc#430161
Recommends:     NetworkManager
Recommends:     dbus-1-x11
Recommends:     desktop-file-utils
# we want useful bug reports
Recommends:     gdb
Recommends:     gpg2
Recommends:     gpgme
Recommends:     input-utils
Recommends:     polkit-default-privs
Recommends:     samba
Recommends:     susehelp
#
# Branding
#
# #591535
Recommends:     gconf2-branding-openSUSE
Recommends:     gdm-branding-openSUSE
Recommends:     gio-branding-openSUSE
Recommends:     gnome-control-center-branding-openSUSE
Recommends:     gnome-menus-branding-openSUSE
Recommends:     gnome-panel-branding-openSUSE
Recommends:     gtk2-branding-openSUSE
Recommends:     gtk3-branding-openSUSE
Recommends:     hicolor-icon-theme-branding-openSUSE
Recommends:     libsocialweb-branding-openSUSE
Recommends:     desktop-branding
#
# Now the real packages
#
# #332596
Recommends:     gnome-keyring-pam
Recommends:     at-spi2-core
Recommends:     canberra-gtk-play
Recommends:     gnome-control-center
Recommends:     gnome-user-docs
Recommends:     gnome-keyring
Recommends:     gnome-menus
Recommends:     gnome-power-manager
Recommends:     gnome-screensaver
Recommends:     gnome-terminal
Recommends:     nautilus
Recommends:     NetworkManager-gnome
Recommends:     shared-mime-info
Recommends:     tango-icon-theme
Recommends:     xkeyboard-config
Recommends:     yelp
# Pulseaudio is the default sound server
Recommends:     pulseaudio-module-bluetooth
Recommends:     pulseaudio-module-gconf
Recommends:     pulseaudio-module-lirc
Recommends:     pulseaudio-module-x11
Recommends:     pulseaudio-module-zeroconf
Recommends:     pulseaudio-utils
# #509829
Recommends:     xdg-user-dirs-gtk
# we need something for xdg-su
Recommends:     libgnomesu

# from data/COMMON-DESKTOP
Recommends:     droid-fonts
Recommends:     MozillaFirefox
Recommends:     desktop-data-openSUSE
Recommends:     avahi
# bnc#508120
Recommends:     xdg-user-dirs
# bnc#598884
Suggests:       moonlight-plugin
# metalink downloader
Suggests:       aria2

%description gnome_basis
Base packages for the GNOME desktop environment.

%files gnome_basis
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_basis.txt

%package gnome_basis_opt
%pattern_graphicalenvironments
Summary:        GNOME Base System
Group:          Metapackages
Provides:       pattern() = gnome_basis_opt
Provides:       pattern-extends() = gnome_basis
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 1420
Requires:       pattern() = basesystem
Requires:       pattern() = x11
# from data/GNOME-BASIS-OPT
# #394406
Recommends:     dynamic-wallpaper-branding-openSUSE

# from data/COMMON-DESKTOP-OPT
# packages a GTK application
Recommends:     gutenprint
# MAYBE later lsb-graphics
Recommends:     icedtea-web
# give net shares
Recommends:     samba
# needs python-qt4, see#649280#14
Suggests:       hplip

%description gnome_basis_opt
Base packages for the GNOME desktop environment.

%files gnome_basis_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_basis_opt.txt

%package gnome_games
%pattern_gnomedesktop
Summary:        GNOME Games
Group:          Metapackages
Provides:       pattern() = gnome_games
Provides:       pattern-extends() = games
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 2100
Supplements:    packageand(patterns-openSUSE-gnome:patterns-openSUSE-games)
# from data/GNOME-Games
Recommends:     aisleriot
Recommends:     gnome-games-recommended
Recommends:     gnuchess
Suggests:       gnome-games-extra-data
Suggests:       phalanx

%description gnome_games
GNOME Games

%files gnome_games
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_games.txt

%package gnome_ide
%pattern_gnomedesktop
Summary:        GNOME Integrated Development Environment
Group:          Metapackages
Provides:       pattern() = gnome_ide
Provides:       pattern-extends() = devel_ide
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 2060
Supplements:    packageand(patterns-openSUSE-gnome:patterns-openSUSE-devel_ide)
# from data/GNOME-IDE
Recommends:     anjuta
Recommends:     devhelp
Recommends:     glade
Suggests:       accerciser
Suggests:       anjuta-extras
Suggests:       ghex
Suggests:       giggle
Suggests:       gitg
Suggests:       gnome-devel-docs
Suggests:       meld
Suggests:       nemiver

%description gnome_ide
Development under GNOME

%files gnome_ide
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_ide.txt

%package gnome_imaging
%pattern_gnomedesktop
Summary:        GNOME Graphics
Group:          Metapackages
Provides:       pattern() = gnome_imaging
Provides:       pattern-extends() = imaging
Provides:       pattern-icon() = package_graphics
Provides:       pattern-order() = 2140
Supplements:    packageand(patterns-openSUSE-gnome:patterns-openSUSE-imaging)
Requires:       pattern() = gnome_basis
Recommends:     pattern() = gnome_imaging_opt
# from data/GNOME-IMAGE
#
# Official upstream
#
Recommends:     eog
#
# Packages that really make sense
#
Recommends:     shotwell
Recommends:     simple-scan
Suggests:       f-spot
Suggests:       gnome-photos

%description gnome_imaging
Handling of digital photos and graphics

%files gnome_imaging
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_imaging.txt

%package gnome_imaging_opt
%pattern_gnomedesktop
Summary:        GNOME Graphics
Group:          Metapackages
Provides:       pattern() = gnome_imaging_opt
Provides:       pattern-extends() = imaging
Provides:       pattern-icon() = package_graphics
Provides:       pattern-order() = 2120
Supplements:    packageand(patterns-openSUSE-gnome:patterns-openSUSE-imaging)
Requires:       pattern() = gnome_basis
# from data/GNOME-IMAGE-OPT
Recommends:     inkscape
Suggests:       dia
Suggests:       gthumb
Suggests:       xsane

%description gnome_imaging_opt
Handling of digital photos and graphics

%files gnome_imaging_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_imaging_opt.txt

%package gnome_internet
%pattern_gnomedesktop
Summary:        GNOME Internet
Group:          Metapackages
Provides:       pattern() = gnome_internet
Provides:       pattern-extends() = gnome
Provides:       pattern-icon() = package_network
Provides:       pattern-order() = 2420
# from data/GNOME-Internet
#
# Official upstream
#
Recommends:     empathy
Recommends:     evolution
Recommends:     gnome-nettool
#
# Packages that really make sense
#
Recommends:     liferea
# bnc#533580
Recommends:     NetworkManager-openvpn-gnome
Recommends:     NetworkManager-pptp-gnome
Recommends:     NetworkManager-vpnc-gnome
Recommends:     NetworkManager-openconnect-gnome
# bnc#530416
Recommends:     transmission-gtk
Recommends:     polari
#
# Official upstream
#
# bnc#366894
Suggests:       ekiga
Suggests:       epiphany
#
# Packages that can make sense
#
Suggests:       frogr
Suggests:       gftp
Suggests:       gwibber
Suggests:       pan
Suggests:       pidgin
Suggests:       smuxi

%description gnome_internet
GNOME Internet Applications

%files gnome_internet
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_internet.txt

%package gnome_laptop
%pattern_gnomedesktop
Summary:        GNOME Laptop
Group:          Metapackages
Provides:       pattern() = gnome_laptop
Provides:       pattern-extends() = laptop
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 2160
Supplements:    packageand(patterns-openSUSE-gnome:patterns-openSUSE-laptop)
Requires:       pattern() = gnome_basis
# from data/GNOME-LAPTOP
Recommends:     gnome-bluetooth
Suggests:       xournal

%description gnome_laptop
GNOME Tools designed specifically for use with laptop computers.

%files gnome_laptop
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_laptop.txt

%package gnome_multimedia
%pattern_gnomedesktop
Summary:        GNOME Multimedia
Group:          Metapackages
Provides:       pattern() = gnome_multimedia
Provides:       pattern-extends() = multimedia
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 2200
Supplements:    packageand(patterns-openSUSE-gnome:patterns-openSUSE-multimedia)
Recommends:     pattern() = gnome_multimedia_opt
# from data/GNOME-Multimedia
#
# GStreamer magic
#
# software.openSUSE.org/codecs
Recommends:     gstreamer-plugins-base
Recommends:     gstreamer-plugins-bad
Recommends:     gstreamer-plugins-good
Recommends:     gstreamer-plugins-ugly
# bnc#445314
Recommends:     gstreamer-utils
#
# Official upstream
#
Recommends:     totem
Recommends:     totem-browser-plugin
#
# Packages that really make sense
#
Recommends:     gnome-music
#
# Packages that really make sense
#
Suggests:       paprefs
Suggests:       pavucontrol
Suggests:       pitivi
Suggests:       sound-juicer

%description gnome_multimedia
GNOME Multimedia

%files gnome_multimedia
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_multimedia.txt

%package gnome_multimedia_opt
%pattern_gnomedesktop
Summary:        GNOME Multimedia
Group:          Metapackages
Provides:       pattern() = gnome_multimedia_opt
Provides:       pattern-extends() = multimedia
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 2180
Supplements:    packageand(patterns-openSUSE-gnome:patterns-openSUSE-multimedia)
# from data/GNOME-Multimedia-OPT

%description gnome_multimedia_opt
GNOME Multimedia

%files gnome_multimedia_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_multimedia_opt.txt

%package gnome_office
%pattern_gnomedesktop
Summary:        GNOME Office
Group:          Metapackages
Provides:       pattern() = gnome_office
Provides:       pattern-extends() = office
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 2240
Supplements:    packageand(patterns-openSUSE-gnome:patterns-openSUSE-office)
Requires:       pattern() = gnome_basis
Recommends:     pattern() = gnome_office_opt
# from data/GNOME-Office
#
# Official upstream
#
Recommends:     evolution
#
# Packages that really make sense
#
Recommends:     libreoffice-gnome
Recommends:     libreoffice-icon-theme-tango
Suggests:       abiword
Suggests:       evolution-ews
Suggests:       glabels
Suggests:       gnumeric
Suggests:       pinpoint
Suggests:       planner

%description gnome_office
GNOME Office

%files gnome_office
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_office.txt

%package gnome_office_opt
%pattern_gnomedesktop
Summary:        GNOME Office
Group:          Metapackages
Provides:       pattern() = gnome_office_opt
Provides:       pattern-extends() = office
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 2220
Supplements:    packageand(patterns-openSUSE-gnome:patterns-openSUSE-office)
Requires:       pattern() = gnome_basis
Suggests:       grisbi

%description gnome_office_opt
GNOME Office

%files gnome_office_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_office_opt.txt

%package gnome_utilities
%pattern_gnomedesktop
Summary:        GNOME Utilities
Group:          Metapackages
Provides:       pattern() = gnome_utilities
Provides:       pattern-extends() = gnome
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 2280
Requires:       pattern() = gnome_basis
# from data/GNOME-Utilities
#
# Official upstream
#
Recommends:     baobab
Recommends:     cheese
Recommends:     file-roller
Recommends:     gedit
Recommends:     gnome-calculator
Recommends:     gnome-dictionary
Recommends:     gnome-font-viewer
Recommends:     gnome-screenshot
Recommends:     gucharmap
Recommends:     nautilus-extension-seahorse
Recommends:     nautilus-sendto
Recommends:     seahorse
Recommends:     bijiben
#
# Packages that really make sense
#
Recommends:     gnome-tweak-tool
# thumbnailing in nautilus
Recommends:     gnome-web-photo
Recommends:     gsf-office-thumbnailer
Recommends:     gnome-weather
#
# Official upstream
#
Suggests:       dasher
Suggests:       eog-plugins
Suggests:       gedit-plugins
#
# Packages that can make sense
#
Suggests:       conduit
Suggests:       deja-dup
Suggests:       gtg
# #388570
Suggests:       kerneloops-applet
Suggests:       nautilus-share
Suggests:       pdfmod
Suggests:       synapse
Suggests:       tasque
Suggests:       the-board

%description gnome_utilities
GNOME Utilities

%files gnome_utilities
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_utilities.txt

%package gnome_yast
%pattern_basetechnologies
Summary:        YaST GNOME User Interfaces
Group:          Metapackages
Provides:       pattern() = gnome_yast
Provides:       pattern-extends() = yast2_basis
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 1260
Supplements:    packageand(patterns-openSUSE-gnome:patterns-openSUSE-yast2_basis)
# from data/GNOME-YaST
# Use libyui-qt-pkg since libyui-gtk-pkg seems to be unmaintained
Requires:       libyui-qt-pkg
Requires:       yast2-control-center-qt
# yast modules for the desktop
Recommends:     yast2-scanner
Recommends:     yast2-tv

%description gnome_yast
Graphical YaST user interfaces for the GNOME desktop.

%files gnome_yast
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/gnome_yast.txt

%package haskell_platform
%pattern_development
Summary:        Haskell Platform
Group:          Metapackages
Provides:       pattern() = haskell_platform
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 3400
Provides:       pattern-visible()
Requires:       alex
Requires:       cabal-install
Requires:       ghc
Requires:       ghc-Cabal-devel
Requires:       ghc-GLURaw-devel
Requires:       ghc-GLUT-devel
Requires:       ghc-HTTP-devel
Requires:       ghc-HUnit-devel
Requires:       ghc-ObjectName-devel
Requires:       ghc-OpenGL-devel
Requires:       ghc-OpenGLRaw-devel
Requires:       ghc-QuickCheck-devel
Requires:       ghc-StateVar-devel
Requires:       ghc-array-devel
Requires:       ghc-async-devel
Requires:       ghc-attoparsec-devel
Requires:       ghc-base-devel
Requires:       ghc-case-insensitive-devel
Requires:       ghc-cgi-devel
Requires:       ghc-containers-devel
Requires:       ghc-deepseq-devel
Requires:       ghc-directory-devel
Requires:       ghc-exceptions-devel
Requires:       ghc-fgl-devel
Requires:       ghc-filepath-devel
Requires:       ghc-hashable-devel
Requires:       ghc-haskell-src-devel
Requires:       ghc-hpc-devel
Requires:       ghc-html-devel
Requires:       ghc-mtl-devel
Requires:       ghc-multipart-devel
Requires:       ghc-network-devel
Requires:       ghc-network-uri-devel
Requires:       ghc-old-locale-devel
Requires:       ghc-old-time-devel
Requires:       ghc-parallel-devel
Requires:       ghc-parsec-devel
Requires:       ghc-pretty-devel
Requires:       ghc-primitive-devel
Requires:       ghc-process-devel
Requires:       ghc-random-devel
Requires:       ghc-regex-base-devel
Requires:       ghc-regex-compat-devel
Requires:       ghc-regex-posix-devel
Requires:       ghc-scientific-devel
Requires:       ghc-split-devel
Requires:       ghc-stm-devel
Requires:       ghc-syb-devel
Requires:       ghc-template-haskell-devel
Requires:       ghc-text-devel
Requires:       ghc-tf-random-devel
Requires:       ghc-time-devel
Requires:       ghc-transformers-compat-devel
Requires:       ghc-transformers-devel
Requires:       ghc-unix-devel
Requires:       ghc-unordered-containers-devel
Requires:       ghc-vector-devel
Requires:       ghc-xhtml-devel
Requires:       ghc-zlib-devel
Requires:       happy
Requires:       hscolour
Recommends:     ghc-mod
Recommends:     hlint
Suggests:       pointfree
Suggests:       pointful

%description haskell_platform
The Haskell Platform is the easiest way to get started with programming Haskell.
It comes with all you need to get up and running. 
Think of it as "Haskell: batteries included."

%files haskell_platform
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/haskell_platform.txt

%package imaging
%pattern_desktopfunctions
Summary:        Graphics
Group:          Metapackages
Provides:       pattern() = imaging
Provides:       pattern-icon() = yast-x11
Provides:       pattern-order() = 1860
Provides:       pattern-visible()
Requires:       pattern() = x11
Recommends:     pattern() = imaging_opt
# from data/IMAGE
Recommends:     gimp
Suggests:       exiftool

%description imaging
Handling of digital photos and graphics.

%files imaging
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/imaging.txt

%package imaging_opt
%pattern_desktopfunctions
Summary:        Graphics
Group:          Metapackages
Provides:       pattern() = imaging_opt
Provides:       pattern-extends() = imaging
Provides:       pattern-icon() = package_graphics
Provides:       pattern-order() = 1840
Requires:       pattern() = x11
# from data/IMAGE-OPT
Recommends:     AdobeICCProfiles
Recommends:     gimp-help
Suggests:       ufraw
Suggests:       gimp-ufraw
Suggests:       pfstools
Suggests:       pfstmo
Suggests:       pfscalibration
Suggests:       calibre

%description imaging_opt
Handling of digital photos and graphics.

%files imaging_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/imaging_opt.txt

%package kde
%pattern_graphicalenvironments
Summary:        KDE Desktop Environment
Group:          Metapackages
Provides:       patterns-openSUSE-kde4 = %{version}
Provides:       pattern() = kde
Provides:       pattern-icon() = pattern-kde4
Provides:       pattern-order() = 1110
Provides:       pattern-visible()
Obsoletes:      patterns-openSUSE-kde4 < %{version}
Requires:       pattern() = kde_plasma
Recommends:     pattern() = kde_internet
Recommends:     pattern() = multimedia
Recommends:     pattern() = office
Recommends:     pattern() = kde_utilities
Recommends:     pattern() = imaging
Recommends:     pattern() = games
Recommends:     pattern() = non_oss
# from data/KDE4-DESKTOP
Recommends:     ark
Recommends:     kcalc
Recommends:     kgpg
Recommends:     spectacle
Recommends:     kwalletmanager5
Recommends:     mozilla-kde4-integration
Recommends:     kio_mtp
Recommends:     kde-print-manager
Recommends:     akregator5
Recommends:     kaddressbook5
Recommends:     kmail5
Recommends:     kontact5
Recommends:     korganizer5
Recommends:     knotes5
Suggests:       marble
Suggests:       kiosktool
Suggests:       kalarm5
Suggests:       krename
Suggests:       vym

%description kde
KDE is a powerful free software graphical desktop environment for Linux workstations. It combines ease of use, contemporary functionality, and outstanding graphical design with the technology of the Linux operating system.

%files kde
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kde.txt

%package kde_plasma
%pattern_graphicalenvironments
Summary:        Plasma 5 Desktop
Group:          Metapackages
Provides:       patterns-openSUSE-kde4_basis = %{version}
Provides:       pattern() = kde_plasma
Provides:       pattern-icon() = pattern-kde4
Provides:       pattern-order() = 1100
Provides:       pattern-visible()
Obsoletes:      patterns-openSUSE-kde4_admin < %{version}
Obsoletes:      patterns-openSUSE-kde4_basis < %{version}
Obsoletes:      patterns-openSUSE-kde4_laptop < %{version}
Obsoletes:      patterns-openSUSE-kde4_pure < %{version}
Obsoletes:      patterns-openSUSE-plasma5_basis < %{version}
Provides:       patterns-openSUSE-plasma5_basis = %{version}
# Obsolete the kdebase4-workspace-devel package specifically to prevent upgrade issues
Obsoletes:      kdebase4-workspace-devel
Requires:       pattern() = basesystem
Requires:       pattern() = x11
# Obsolete the KDE bindings which have not been ported yet
Obsoletes:      mono-kde4
Obsoletes:      perl-kde4
Obsoletes:      python3-kde4
Obsoletes:      ruby-kde4
# from data/KDE4-BASIS
Requires:       breeze
Requires:       breeze5-cursors
Requires:       breeze5-decoration
Requires:       breeze5-icons
Requires:       breeze5-style
Requires:       breeze5-wallpapers
Requires:       dolphin
Requires:       kwin5
Requires:       kwrite
Requires:       plasma5-desktop
Requires:       plasma5-session
Requires:       plasma5-workspace
# bnc#541820
Recommends:     susehelp
Recommends:     baloo5-file
Recommends:     baloo5-kioslaves
Recommends:     baloo5-tools
Recommends:     plasma-nm5
Recommends:     plasma5-pa
Recommends:     plasma5-pk-updates
Recommends:     plasma5-addons
# Make sure that qt4/kde4 applications use the breeze widget style too
Recommends:     kdebase4-workspace-libs
Recommends:     keditbookmarks
Recommends:     konqueror
Recommends:     konsole
Recommends:     kdenetwork4-filesharing
Recommends:     pinentry-qt4
Recommends:     kde-gtk-config5
Recommends:     yast2-control-center-qt
# we want useful bug reports
Recommends:     gdb
Recommends:     sddm
Recommends:     kio-extras
# bnc#430161
Recommends:     polkit-default-privs
# pulseaudio
Recommends:     pulseaudio
Recommends:     pulseaudio-module-bluetooth
Recommends:     pulseaudio-module-jack
Recommends:     pulseaudio-module-lirc
Recommends:     pulseaudio-module-x11
Recommends:     pulseaudio-module-zeroconf
Recommends:     pulseaudio-utils
Recommends:     alsa-plugins-pulse
Recommends:     kdepasswd
# bnc#605509
Recommends:     skanlite
Recommends:     desktop-branding
# KDEPIM suite. 
Recommends:     akregator5
Recommends:     kaddressbook5
Recommends:     kmail5
Recommends:     kontact5
Recommends:     korganizer5
Recommends:     knotes5
##
Recommends:     kdeconnect-kde
Suggests:       qtcurve-gtk2
Suggests:       qtcurve-qt5
# bnc#521177
Suggests:       yakuake
Suggests:       kcron
Suggests:       ksystemlog

# from data/COMMON-DESKTOP
Recommends:     kde-oxygen-fonts
Recommends:     droid-fonts
Recommends:     MozillaFirefox
Recommends:     desktop-data-openSUSE
Recommends:     avahi
# bnc#508120
Recommends:     xdg-user-dirs
# we want a video player
Requires:       dragonplayer
# bnc#598884
Suggests:       moonlight-plugin
# metalink downloader
Suggests:       aria2

%description kde_plasma
Base packages for the Plasma5  desktop environment.

%files kde_plasma
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kde_plasma.txt

%package kde_edutainment
%pattern_kdedesktop
Summary:        KDE Education
Group:          Metapackages
Provides:       patterns-openSUSE-kde4_edutainment = %{version}
Provides:       pattern() = kde_edutainment
Provides:       pattern-icon() = package_edutainment
Provides:       pattern-order() = 2360
Obsoletes:      patterns-openSUSE-kde4_edutainment < %{version}
Recommends:     blinken
Recommends:     marble
Recommends:     kalzium
Recommends:     kanagram
Recommends:     kbruch
Recommends:     kalgebra
Recommends:     kgeography
Recommends:     khangman
Recommends:     kig
Recommends:     kiten
Recommends:     klettres
Recommends:     kmplot
Recommends:     ktouch
Recommends:     parley
Recommends:     kwordquiz
Recommends:     step
Suggests:       kturtle

%description kde_edutainment
KDE Applications - Tools to teach kids with computers

%files kde_edutainment
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kde_edutainment.txt

%package kde_games
%pattern_kdedesktop
Summary:        KDE Games
Group:          Metapackages
Provides:       patterns-openSUSE-kde4_games = %{version}
Provides:       pattern() = kde_games
Provides:       pattern-extends() = games
Provides:       pattern-icon() = package_games
Provides:       pattern-order() = 2400
Obsoletes:      patterns-openSUSE-kde4_games < %{version}
Supplements:    packageand(patterns-openSUSE-kde:patterns-openSUSE-games)
# from data/KDE4-Games
Recommends:     kpat
Recommends:     kmahjongg
Recommends:     kmines
Recommends:     kreversi
Recommends:     ksudoku
Suggests:       kblocks
Suggests:       katomic
Suggests:       bovo
Suggests:       knavalbattle
Suggests:       kblackbox
Suggests:       kbounce
Suggests:       kbreakout
Suggests:       kdiamond
Suggests:       kgoldrunner
Suggests:       kiriki
Suggests:       kjumpingcube
Suggests:       kollision
Suggests:       kolorlines
Suggests:       knetwalk
Suggests:       kolf
Suggests:       konquest
Suggests:       kshisen
Suggests:       ksirk
Suggests:       kspaceduel
Suggests:       ksquares
Suggests:       ktuberling
Suggests:       kubrick
Suggests:       lskat

%description kde_games
KDE Applications - Games

%files kde_games
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kde_games.txt

%package kde_ide
%pattern_kdedesktop
Summary:        KDE Integrated Development Environment
Group:          Metapackages
Provides:       patterns-openSUSE-kde4_ide = %{version}
Provides:       pattern() = kde_ide
Provides:       pattern-extends() = devel_ide
Provides:       pattern-icon() = package_utilities
Provides:       pattern-order() = 2820
Obsoletes:      patterns-openSUSE-kde4_ide < %{version}
Supplements:    packageand(patterns-openSUSE-kde:patterns-openSUSE-devel_ide)
# from data/KDE4-IDE
Recommends:     kate
Recommends:     kdbg
Recommends:     kdevelop4
Recommends:     kapptemplate
Recommends:     lokalize
Recommends:     kde4-l10n-devel
Recommends:     cervisia
Recommends:     kcachegrind
Recommends:     kio_svn
Recommends:     kompare
Recommends:     umbrello
Suggests:       kdevelop4-plugins-php

%description kde_ide
Development environment for the Plasma Desktop

%files kde_ide
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kde_ide.txt

%package kde_imaging
%pattern_kdedesktop
Summary:        KDE Graphics
Group:          Metapackages
Provides:       patterns-openSUSE-kde4_imaging = %{version}
Provides:       pattern() = kde_imaging
Provides:       pattern-extends() = imaging
Provides:       pattern-icon() = package_graphics
Provides:       pattern-order() = 2540
Obsoletes:      patterns-openSUSE-kde4_imaging < %{version}
Supplements:    packageand(patterns-openSUSE-kde:patterns-openSUSE-imaging)
Requires:       pattern() = kde_plasma
# from data/KDE4-IMAGE
Recommends:     gwenview5
Recommends:     digikam
Recommends:     kipi-plugins
Recommends:     libjpeg-turbo
Recommends:     okular
Recommends:     kio_kamera
Recommends:     kcolorchooser
Recommends:     kgamma
Recommends:     skanlite
Recommends:     kruler
Suggests:       calligra-stage
Suggests:       calligra-krita
Suggests:       kolourpaint

%description kde_imaging
KDE Applicatons - Handling of digital photos and graphics

%files kde_imaging
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kde_imaging.txt

%package kde_internet
%pattern_kdedesktop
Summary:        KDE Internet
Group:          Metapackages
Provides:       patterns-openSUSE-kde4_internet = %{version}
Provides:       pattern() = kde_internet
Provides:       pattern-extends() = kde4
Provides:       pattern-icon() = package_network
Provides:       pattern-order() = 2560
Obsoletes:      patterns-openSUSE-kde4_internet < %{version}
# from data/KDE4-Internet
Recommends:     kdnssd
Recommends:     kget
Recommends:     kopete
# 297684 for these 2
Recommends:     konversation
# bnc#533580
Recommends:     plasma-nm5-openvpn
Recommends:     plasma-nm5-vpnc
Recommends:     plasma-nm5-pptp
Suggests:       kppp
Suggests:       rekonq

%description kde_internet
KDE Internet Applications

%files kde_internet
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kde_internet.txt

%package kde_telepathy
%pattern_kdedesktop
Summary:        KDE Telepathy
Group:          Metapackages
Provides:       pattern() = kde_telepathy
Provides:       pattern-extends() = kde4
Provides:       pattern-icon() = package_network
Provides:       pattern-order() = 2560
Requires:       ktp-accounts-kcm
Requires:       ktp-auth-handler
Requires:       ktp-common-internals
Requires:       ktp-icons
Requires:       ktp-kded-module
Requires:       signon-kwallet-extension
Requires:       signon-plugin-oauth2
Requires:       signon-plugins
Requires:       signon-ui
Requires:       signond
Recommends:     ktp-approver
Recommends:     ktp-contact-list
Recommends:     ktp-desktop-applets
Recommends:     ktp-text-ui
Suggests:       ktp-contact-runner
Suggests:       ktp-filetransfer-handler
Suggests:       ktp-send-file

%description kde_telepathy
KDE Applications - Telepathy

%files kde_telepathy
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kde_telepathy.txt

%package kde_multimedia
%pattern_kdedesktop
Summary:        KDE Multimedia
Group:          Metapackages
Provides:       patterns-openSUSE-kde4_multimedia = %{version}
Provides:       pattern() = kde_multimedia
Provides:       pattern-extends() = multimedia
Provides:       pattern-icon() = package_multimedia
Provides:       pattern-order() = 2620
Obsoletes:      patterns-openSUSE-kde4_multimedia < %{version}
Supplements:    packageand(patterns-openSUSE-kde:patterns-openSUSE-multimedia)
# from data/KDE4-Multimedia
Recommends:     amarok
Recommends:     k3b
Recommends:     plasma5-pa
Recommends:     kscd
Recommends:     kio_audiocd
Recommends:     PackageKit-gstreamer-plugin
Recommends:     phonon4qt5-backend-gstreamer
Recommends:     gstreamer-plugins-good
Suggests:       dragonplayer
Suggests:       juk

%description kde_multimedia
KDE Applications - Multimedia

%files kde_multimedia
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kde_multimedia.txt

%package kde_office
%pattern_kdedesktop
Summary:        KDE Office
Group:          Metapackages
Provides:       patterns-openSUSE-kde4_office = %{version}
Provides:       pattern() = kde_office
Provides:       pattern-extends() = office
Provides:       pattern-icon() = package_wordprocessing
Provides:       pattern-order() = 2700
Obsoletes:      patterns-openSUSE-kde4_office < %{version}
Supplements:    packageand(patterns-openSUSE-kde:patterns-openSUSE-office)
# from data/KDE4-Office
Recommends:     libreoffice-kde4
Recommends:     libreoffice-icon-theme-oxygen
Suggests:       scribus

%description kde_office
KDE Office

%files kde_office
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kde_office.txt

%package kde_utilities
%pattern_kdedesktop
Summary:        KDE Utilities
Group:          Metapackages
Provides:       patterns-openSUSE-kde4_utilities = %{version}
Provides:       pattern() = kde_utilities
Provides:       pattern-extends() = kde
Provides:       pattern-icon() = package_utilities
Provides:       pattern-order() = 2860
Obsoletes:      patterns-openSUSE-kde4_utilities < %{version}
Recommends:     pattern() = kde_utilities_opt
# from data/KDE4-Utilities
Recommends:     bluedevil
Recommends:     sweeper
Recommends:     kmag
Recommends:     kmousetool
Recommends:     kcharselect
Recommends:     kompare
Suggests:       okteta
Suggests:       kteatime
Suggests:       ktux
Suggests:       amor
Suggests:       kdirstat

%description kde_utilities
KDE Applications - Utilities

%files kde_utilities
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kde_utilities.txt

%package kde_utilities_opt
%pattern_kdedesktop
Summary:        KDE Utilities
Group:          Metapackages
Provides:       patterns-openSUSE-kde4_utilities_opt = %{version}
Provides:       pattern() = kde_utilities_opt
Provides:       pattern-extends() = kde
Provides:       pattern-icon() = package_utilities
Provides:       pattern-order() = 2840
Obsoletes:      patterns-openSUSE-kde4_utilities_opt < %{version}
# from data/KDE4-UTILITIES-OPT
Recommends:     konqueror-plugins
Suggests:       rsibreak
Suggests:       speedcrunch
Suggests:       kchmviewer
Suggests:       kmouth
Suggests:       kremotecontrol
Suggests:       kdf
Suggests:       ktimer
Suggests:       kwikdisk
Suggests:       krusader
Suggests:       smb4k

# from data/COMMON-DESKTOP-OPT
# packages a GTK application
Recommends:     gutenprint
# MAYBE later lsb-graphics
Recommends:     icedtea-web
# give net shares
Recommends:     samba
# needs python-qt4, see#649280#14
Suggests:       hplip

%description kde_utilities_opt
KDE Application - Additional Utilities

%files kde_utilities_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kde_utilities_opt.txt

%package kde_yast
%pattern_basetechnologies
Summary:        YaST KDE User Interfaces
Group:          Metapackages
Provides:       patterns-openSUSE-kde4_yast = %{version}
Provides:       pattern() = kde_yast
Provides:       pattern-extends() = yast2_basis
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 1300
Obsoletes:      patterns-openSUSE-kde4_yast < %{version}
Supplements:    packageand(patterns-openSUSE-kde:patterns-openSUSE-yast2_basis)
# from data/KDE4-YaST
Requires:       libyui-qt-pkg
Requires:       yast2-control-center-qt
Requires:       yast2-theme-openSUSE-Oxygen
# yast modules for the desktop
Recommends:     yast2-scanner
Recommends:     yast2-tv

%description kde_yast
Graphical YaST user interfaces for the KDE desktop.

%files kde_yast
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kde_yast.txt

%package kvm_server
%pattern_serverfunctions
Summary:        KVM Host Server
Group:          Metapackages
Provides:       pattern() = kvm_server
Provides:       pattern-icon() = yast-uml
Provides:       pattern-order() = 3099
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/KVM
Recommends:     kvm
Recommends:     vm-install
Recommends:     tigervnc
Recommends:     fontconfig
Recommends:     fonts-config
Recommends:     xorg-x11-fonts-core
Recommends:     efont-unicode
Recommends:     xorg-x11-xauth
Recommends:     bridge-utils
Recommends:     tftp
Recommends:     agfa-fonts
Recommends:     efont-unicode
Recommends:     xorg-x11-fonts
Recommends:     virt-viewer
Recommends:     virt-manager
Recommends:     libvirt-daemon-qemu
Suggests:       libvirt
Suggests:       libvirt-daemon-lxc

%description kvm_server
Software to set up a server for configuring, managing, and monitoring virtual machines on a single physical machine.

%files kvm_server
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/kvm_server.txt

%package lamp_server
%pattern_serverfunctions
Summary:        Web and LAMP Server
Group:          Metapackages
Provides:       pattern() = lamp_server
Provides:       pattern-icon() = yast-http-server
Provides:       pattern-order() = 3000
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/LAMP
Recommends:     apache2
Recommends:     yast2-http-server
Recommends:     apache2-doc
Recommends:     apache2-example-pages
Recommends:     apache2-mod_perl
Recommends:     apache2-mod_php5
Recommends:     apache2-mod_python
Recommends:     apache2-prefork
Recommends:     mariadb
Recommends:     php5-ctype
Recommends:     php5-dom
Recommends:     php5-iconv
Recommends:     php5-mysql
Suggests:       php5-gd
Suggests:       php5-mbstring
Suggests:       php5-zlib
Suggests:       php5-zip
# slightly out of place I admit
Suggests:       postgresql
Suggests:       postgresql-contrib
Suggests:       postgresql-server

%description lamp_server
Software to set up a Web server that is able to serve static, dynamic, and interactive content (like a Web shop). This includes Apache HTTP Server, the database management system MySQL, and scripting languages such as PHP, Python, Ruby on Rails, or Perl.

%files lamp_server
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/lamp_server.txt

%package laptop
%pattern_basetechnologies
Summary:        Laptop
Group:          Metapackages
Provides:       pattern() = laptop
Provides:       pattern-icon() = yast-bluetooth
Provides:       pattern-order() = 1200
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/LAPTOP
Recommends:     pcmciautils
Recommends:     wpa_supplicant
# bnc#480879
Recommends:     crda
Recommends:     wireless-regdb
Recommends:     iw
Suggests:       irda
Suggests:       smbios-utils-python
Suggests:       powertop
# fate#303035
Suggests:       laptop-mode-tools

%description laptop
Tools designed specifically for laptop computers.

%files laptop
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/laptop.txt

%package leechcraft
%pattern_desktopfunctions
Summary:        leechcraft
Group:          Metapackages
Provides:       pattern() = leechcraft
Provides:       pattern-icon() = package_internet_webbrowser
Provides:       pattern-order() = 1248
Requires:       pattern() = basesystem
Requires:       pattern() = x11
Recommends:     pattern() = leechcraft_browser
Recommends:     pattern() = leechcraft_media
Recommends:     pattern() = leechcraft_messenger
Recommends:     pattern() = leechcraft_office
Recommends:     pattern() = leechcraft_utilities
Recommends:     pattern() = leechcraft_netutils
# from data/LC
Requires:       leechcraft-cstp

%description leechcraft

%files leechcraft
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/leechcraft.txt

%package leechcraft_browser
%pattern_desktopfunctions
Summary:        leechcraft_browser
Group:          Metapackages
Provides:       pattern() = leechcraft_browser
Provides:       pattern-icon() = package_internet_webbrowser
Provides:       pattern-order() = 1246
Requires:       pattern() = basesystem
Requires:       pattern() = x11
Recommends:     pattern() = leechcraft_utilities
# from data/LC-Browser
Requires:       leechcraft-cstp
Requires:       leechcraft-poshuku
Recommends:     leechcraft-xproxy
Recommends:     leechcraft-anhero
Recommends:     leechcraft-advancednotifications
Recommends:     leechcraft-dbusmanager
Recommends:     leechcraft-dolozhee
Recommends:     leechcraft-knowhow
Recommends:     leechcraft-lackman
Recommends:     leechcraft-newlife
Recommends:     leechcraft-pintab
Recommends:     leechcraft-pogooglue
Recommends:     leechcraft-poshuku-autosearch
Recommends:     leechcraft-poshuku-cleanweb
Recommends:     leechcraft-poshuku-dcac
Recommends:     leechcraft-poshuku-fatape
Recommends:     leechcraft-poshuku-filescheme
Recommends:     leechcraft-poshuku-fua
Recommends:     leechcraft-poshuku-keywords
Recommends:     leechcraft-poshuku-onlinebookmarks-delicious
Recommends:     leechcraft-poshuku-onlinebookmarks-readitlater
Recommends:     leechcraft-poshuku-qrd
Recommends:     leechcraft-poshuku-speeddial
Recommends:     leechcraft-seekthru
Recommends:     leechcraft-summary
Recommends:     leechcraft-tabsessionmanager

%description leechcraft_browser

%files leechcraft_browser
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/leechcraft_browser.txt

%package leechcraft_media
%pattern_desktopfunctions
Summary:        leechcraft_media
Group:          Metapackages
Provides:       pattern() = leechcraft_media
Provides:       pattern-icon() = package_internet_webbrowser
Provides:       pattern-order() = 1252
Requires:       pattern() = basesystem
Requires:       pattern() = x11
Recommends:     pattern() = leechcraft_utilities
# from data/LC-Media
Requires:       leechcraft-lmp
Recommends:     leechcraft-advancednotifications
Recommends:     leechcraft-cstp
Recommends:     leechcraft-dbusmanager
Recommends:     leechcraft-deadlyrics
Recommends:     leechcraft-dolozhee
Recommends:     leechcraft-gacts
Recommends:     leechcraft-hotstreams
Recommends:     leechcraft-knowhow
Recommends:     leechcraft-lastfmscrobble
Recommends:     leechcraft-lmp-brainslugz
Recommends:     leechcraft-lmp-dumbsync
Recommends:     leechcraft-lmp-fradj
Recommends:     leechcraft-lmp-graffiti
Recommends:     leechcraft-lmp-httstream
Recommends:     leechcraft-lmp-mp3tunes
Recommends:     leechcraft-lmp-mtpsync
Recommends:     leechcraft-musiczombie
Recommends:     leechcraft-vgrabber
Recommends:     leechcraft-vtyulc
Recommends:     leechcraft-xproxy
Suggests:       leechcraft-anhero
Suggests:       leechcraft-kinotify
Suggests:       leechcraft-summary

%description leechcraft_media

%files leechcraft_media
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/leechcraft_media.txt

%package leechcraft_messenger
%pattern_desktopfunctions
Summary:        leechcraft_messenger
Group:          Metapackages
Provides:       pattern() = leechcraft_messenger
Provides:       pattern-icon() = package_internet_webbrowser
Provides:       pattern-order() = 1256
Requires:       pattern() = basesystem
Requires:       pattern() = x11
Recommends:     pattern() = leechcraft_utilities
# from data/LC-Messenger
Requires:       leechcraft-azoth
Recommends:     leechcraft-xproxy
Recommends:     leechcraft-anhero
Recommends:     leechcraft-advancednotifications
Recommends:     leechcraft-azoth-acetamide
Recommends:     leechcraft-azoth-astrality
Recommends:     leechcraft-azoth-adiumstyles
Recommends:     leechcraft-azoth-autoidler
Recommends:     leechcraft-azoth-autopaste
Recommends:     leechcraft-azoth-birthdaynotifier
Recommends:     leechcraft-azoth-chathistory
Recommends:     leechcraft-azoth-depester
Recommends:     leechcraft-azoth-embedmedia
Recommends:     leechcraft-azoth-herbicide
Recommends:     leechcraft-azoth-hili
Recommends:     leechcraft-azoth-isterique
Recommends:     leechcraft-azoth-juick
Recommends:     leechcraft-azoth-keeso
Recommends:     leechcraft-azoth-lastseen
Recommends:     leechcraft-azoth-metacontacts
Recommends:     leechcraft-azoth-modnok
Recommends:     leechcraft-azoth-mucommands
Recommends:     leechcraft-azoth-murm
Recommends:     leechcraft-azoth-nativeemoticons
Recommends:     leechcraft-azoth-rosenthal
Recommends:     leechcraft-azoth-shx
Recommends:     leechcraft-azoth-standardstyles
Recommends:     leechcraft-azoth-vader
Recommends:     leechcraft-azoth-velvetbird
Recommends:     leechcraft-azoth-woodpecker
Recommends:     leechcraft-azoth-xoox
Recommends:     leechcraft-azoth-xtazy
Recommends:     leechcraft-azoth-zheet
Recommends:     leechcraft-cstp
Recommends:     leechcraft-dbusmanager
Recommends:     leechcraft-dolozhee
Recommends:     leechcraft-dumbeep
Recommends:     leechcraft-gacts
Recommends:     leechcraft-kinotify
Recommends:     leechcraft-knowhow
Recommends:     leechcraft-lackman
Recommends:     leechcraft-newlife
Recommends:     leechcraft-netstoremanager-googledrive
Recommends:     leechcraft-pintab
Recommends:     leechcraft-pogooglue
Recommends:     leechcraft-secman-simplestorage
Recommends:     leechcraft-seekthru
Recommends:     leechcraft-summary
Recommends:     leechcraft-tabsessionmanager

%description leechcraft_messenger

%files leechcraft_messenger
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/leechcraft_messenger.txt

%package leechcraft_netutils
%pattern_desktopfunctions
Summary:        leechcraft_netutils
Group:          Metapackages
Provides:       pattern() = leechcraft_netutils
Provides:       pattern-icon() = package_internet_webbrowser
Provides:       pattern-order() = 1254
Requires:       pattern() = basesystem
Requires:       pattern() = x11
Recommends:     pattern() = leechcraft_utilities
# from data/LC-NetUtils
Requires:       leechcraft-cstp
Recommends:     leechcraft-xproxy
Recommends:     leechcraft-advancednotifications
Recommends:     leechcraft-aggregator-bodyfetch
Recommends:     leechcraft-aggregator-webaccess
Recommends:     leechcraft-anhero
Recommends:     leechcraft-bittorrent
Recommends:     leechcraft-blasq
Recommends:     leechcraft-blasq-spegnersi
Recommends:     leechcraft-blasq-deathnote
Recommends:     leechcraft-blasq-rappor
Recommends:     leechcraft-blasq-vangog
Recommends:     leechcraft-blogique-metida
Recommends:     leechcraft-certmgr
Recommends:     leechcraft-dbusmanager
Recommends:     leechcraft-dolozhee
Recommends:     leechcraft-htthare
Recommends:     leechcraft-imgaste
Recommends:     leechcraft-knowhow
Recommends:     leechcraft-netstoremanager-googledrive
Recommends:     leechcraft-newlife
Recommends:     leechcraft-pogooglue
Recommends:     leechcraft-seekthru
Recommends:     leechcraft-summary
Recommends:     leechcraft-xtazy

%description leechcraft_netutils

%files leechcraft_netutils
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/leechcraft_netutils.txt

%package leechcraft_office
%pattern_desktopfunctions
Summary:        leechcraft_office
Group:          Metapackages
Provides:       pattern() = leechcraft_office
Provides:       pattern-icon() = package_internet_webbrowser
Provides:       pattern-order() = 1250
Requires:       pattern() = basesystem
Requires:       pattern() = x11
Recommends:     pattern() = leechcraft_utilities
# from data/LC-Office
Requires:       leechcraft
Recommends:     leechcraft-advancednotifications
Recommends:     leechcraft-anhero
Recommends:     leechcraft-blogique-hestia
Recommends:     leechcraft-dbusmanager
Recommends:     leechcraft-dolozhee
Recommends:     leechcraft-knowhow
Recommends:     leechcraft-monocle-dik
Recommends:     leechcraft-monocle-fxb
Recommends:     leechcraft-monocle-pdf
Recommends:     leechcraft-monocle-postrus
Recommends:     leechcraft-monocle-seen
Recommends:     leechcraft-otlozhu
Recommends:     leechcraft-popishu
Recommends:     leechcraft-summary

%description leechcraft_office

%files leechcraft_office
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/leechcraft_office.txt

%package leechcraft_utilities
%pattern_desktopfunctions
Summary:        leechcraft_utilities
Group:          Metapackages
Provides:       pattern() = leechcraft_utilities
Provides:       pattern-icon() = package_internet_webbrowser
Provides:       pattern-order() = 1244
Requires:       pattern() = basesystem
Requires:       pattern() = x11
# from data/LC-Utilities
Requires:       leechcraft
Recommends:     leechcraft-advancednotifications
Recommends:     leechcraft-anhero
Recommends:     leechcraft-auscrie
Recommends:     leechcraft-cstp
Recommends:     leechcraft-devmon
Recommends:     leechcraft-dbusmanager
Recommends:     leechcraft-dolozhee
Recommends:     leechcraft-dumbeep
Recommends:     leechcraft-eleeminator
Recommends:     leechcraft-gacts
Recommends:     leechcraft-glance
Recommends:     leechcraft-harbinger
Recommends:     leechcraft-historyholder
Recommends:     leechcraft-kinotify
Recommends:     leechcraft-knowhow
Recommends:     leechcraft-lackman
Recommends:     leechcraft-networkmonitor
Recommends:     leechcraft-newlife
Recommends:     leechcraft-pintab
Recommends:     leechcraft-pogooglue
Recommends:     leechcraft-rosenthal
Recommends:     leechcraft-secman-simplestorage
Recommends:     leechcraft-seekthru
Recommends:     leechcraft-summary
Recommends:     leechcraft-tabsessionmanager
Recommends:     leechcraft-tabslist
Recommends:     leechcraft-xproxy

%description leechcraft_utilities

%files leechcraft_utilities
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/leechcraft_utilities.txt

%package lxde
%pattern_graphicalenvironments
Summary:        LXDE Desktop Environment
Group:          Metapackages
Provides:       pattern() = lxde
Provides:       pattern-icon() = pattern-lxde
Provides:       pattern-order() = 1410
Provides:       pattern-visible()
Requires:       pattern() = x11
Recommends:     pattern() = lxde_office
Recommends:     pattern() = multimedia

Recommends:     pattern() = remote_desktop
# from data/LXDE
# Move to lightdm instead of lxdm - the latter still depends on ConsoleKit
# See mail thread: https://lists.opensuse.org/opensuse-factory/2016-07/msg00417.html
Recommends:     lightdm
Recommends:     lxappearance
Recommends:     lxde-common
Recommends:     lxde-common-branding-openSUSE
Recommends:     lxinput
Recommends:     lxmenu-data
Recommends:     lxmusic
Recommends:     lxpanel
Recommends:     lxrandr
Recommends:     lxsession
Recommends:     lxtask
Recommends:     lxterminal
Recommends:     lxcc
Recommends:     menu-cache
Recommends:     nuoveXT2-icon-theme
Recommends:     openbox
Recommends:     obconf
Recommends:     pcmanfm
Recommends:     viewnior
Recommends:     leafpad
Recommends:     geany
Recommends:     xarchiver
Recommends:     galculator
Recommends:     gmixer
Recommends:     parcellite
Recommends:     xscreensaver
Recommends:     pidgin
Recommends:     hexchat
Recommends:     claws-mail
Recommends:     uget
Recommends:     xdg-user-dirs-gtk
Recommends:     xfce4-power-manager
Recommends:     xfce4-screenshooter
Recommends:     gconf2-branding-openSUSE
#xfburn, community asks for brasero
Recommends:     brasero
Recommends:     mtpaint
Recommends:     gcolor2
Recommends:     cheese
# #540627
Recommends:     xdg-utils
# #393956 + 450220 + 481468(xdm)
Recommends:     xorg-x11-essentials
Recommends:     xdm
# bnc#537362
Recommends:     gnome-packagekit
Recommends:     pk-update-icon
# #404447
Recommends:     gtk2-engine-murrine
# #440285
Recommends:     pinentry-gtk2
Recommends:     avahi
# #537365
# use gnomesu as su wrapper
Recommends:     libgnomesu
# we need a GPG GUI
Recommends:     seahorse
# We need a printer configuration util
Recommends:     system-config-printer
# And scanner one
Recommends:     simple-scan
# Video player and codecs
# do we need an LXDE_MULTIMEDIA pattern??
Recommends:     totem
Recommends:     totem-browser-plugin
# Use Qt UI for YaST
Recommends:     libyui-qt-pkg
Recommends:     yast2-control-center-qt
# Use NM by default
Recommends:     NetworkManager
Recommends:     NetworkManager-gnome
Recommends:     desktop-branding
Suggests:       lxlauncher

# from data/COMMON-DESKTOP
Recommends:     droid-fonts
Recommends:     MozillaFirefox
Recommends:     desktop-data-openSUSE
Recommends:     avahi
# bnc#508120
Recommends:     xdg-user-dirs

# from data/COMMON-DESKTOP-OPT
# packages a GTK application
Recommends:     gutenprint
# MAYBE later lsb-graphics
Recommends:     icedtea-web
# give net shares
Recommends:     samba
# needs python-qt4, see#649280#14
Suggests:       hplip

%description lxde
LXDE is a lightweight X11 desktop environment similiar to XFCE in its nature.

%files lxde
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/lxde.txt

%package lxde_laptop
%pattern_lxdedesktop
Summary:        LXDE Laptop
Group:          Metapackages
Provides:       pattern() = lxde_laptop
Provides:       pattern-extends() = laptop
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 5160
Supplements:    packageand(patterns-openSUSE-lxde:patterns-openSUSE-laptop)
Requires:       pattern() = lxde
# from data/LXDE-LAPTOP
Recommends:     gnome-bluetooth

%description lxde_laptop
LXDE Tools designed specifically for use with laptop computers.

%files lxde_laptop
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/lxde_laptop.txt

%package lxde_office
%pattern_graphicalenvironments
Summary:        LXDE Office
Group:          Metapackages
Provides:       pattern() = lxde_office
Provides:       pattern-extends() = office
Provides:       pattern-icon() = pattern-lxde
Provides:       pattern-order() = 1880
Supplements:    packageand(patterns-openSUSE-lxde:patterns-openSUSE-office)
Requires:       pattern() = lxde
# from data/LXDE-Office
Recommends:     abiword
Recommends:     atril
Recommends:     gnumeric
Recommends:     goffice

%description lxde_office
LXDE Office

%files lxde_office
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/lxde_office.txt

%package lxqt
%pattern_graphicalenvironments
Summary:        LXQt Desktop Environment
Group:          Metapackages
Provides:       pattern() = lxqt
Provides:       pattern-order() = 1460
Provides:       pattern-visible()
Requires:       lxqt-about
Requires:       lxqt-common
Requires:       lxqt-config
Requires:       lxqt-globalkeys
Requires:       lxqt-l10n
Requires:       lxqt-notificationd
Requires:       lxqt-openssh-askpass
Requires:       lxqt-panel
Requires:       lxqt-policykit
Requires:       lxqt-powermanagement
Requires:       lxqt-qtplugin
Requires:       lxqt-runner
Requires:       lxqt-session
Requires:       lxqt-sudo
Requires:       pattern() = x11
Recommends:     pattern() = multimedia
Recommends:     pattern() = remote_desktop
# non core packages belonging to LXQt organization
Recommends:     pcmanfm-qt
Recommends:     pavucontrol-qt
Recommends:     qterminal
Recommends:     obconf-qt
Recommends:     lximage-qt

# Pulseaudio is the default sound server
Recommends:     pulseaudio-module-bluetooth
Recommends:     pulseaudio-module-gconf
Recommends:     pulseaudio-module-lirc
Recommends:     pulseaudio-module-x11
Recommends:     pulseaudio-module-zeroconf
Recommends:     pulseaudio-utils
#
Recommends:     openbox
Recommends:     obconf
Recommends:     qupzilla
Recommends:     xdg-utils
Recommends:     xscreensaver
Recommends:     xorg-x11-essentials
Recommends:     lightdm

Recommends:     ark
Recommends:     claws-mail
Recommends:     xfce4-power-manager
Recommends:     xfce4-screenshooter

Recommends:     pk-update-icon
Recommends:     apper

Recommends:     avahi
Recommends:     kdesu
Recommends:     system-config-printer
Recommends:     simple-scan
Recommends:     libyui-qt-pkg
Recommends:     yast2-control-center-qt
Recommends:     NetworkManager
Recommends:     NetworkManager-gnome
Recommends:     droid-fonts
Recommends:     desktop-data-openSUSE
Recommends:     samba
Suggests:       hplip

%description lxqt
LXQt is a lightweight desktop environment based on Qt.

%files lxqt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/lxqt.txt

%package mail_server
%pattern_serverfunctions
Summary:        Mail and News Server
Group:          Metapackages
Provides:       pattern() = mail_server
Provides:       pattern-icon() = yast-mail-server
Provides:       pattern-order() = 2980
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/MAIL_SERVER
Recommends:     cyrus-imapd
Recommends:     amavisd-new
Recommends:     mailman
Recommends:     clamav
Recommends:     fetchmail
Recommends:     postfix
Recommends:     procmail
Recommends:     spamassassin
Recommends:     inn
Recommends:     vacation
Suggests:       dovecot12
Suggests:       mlmmj
Suggests:       sendmail
Suggests:       bogofilter
# this duplicates the recommend, but works around a problem with the solver
# as everything is weak required, it needs one more hint for postfix
Suggests:       postfix

%description mail_server
Software to set up electronic mail and message services to handle e-mail, mailing, and news lists, including a virus scanner to scan messages at the server level.

%files mail_server
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/mail_server.txt

%package mate
%pattern_graphicalenvironments
Summary:        MATE Desktop Environment
Group:          Metapackages
Provides:       pattern() = mate
Provides:       pattern-icon() = pattern-mate
Provides:       pattern-order() = 1610
Provides:       pattern-visible()
Requires:       pattern() = mate_basis
Recommends:     pattern() = games
Recommends:     pattern() = imaging
Recommends:     pattern() = non_oss
Recommends:     pattern() = mate_admin
Recommends:     pattern() = mate_internet
Recommends:     pattern() = multimedia
Recommends:     pattern() = office
Recommends:     pattern() = mate_utilities
#
# Official upstream
# As MATE is the continuation of GNOME 2.x, patterns are based on GNOME ones
# and some GNOME's are required
#
Recommends:     atril
# For instance, recommending blueberry, will recommend blueman once it's approved
Recommends:     blueberry
Recommends:     brasero
Recommends:     caja-sendto
Recommends:     caribou
Recommends:     cheese
Recommends:     engrampa
Recommends:     eom
Recommends:     galculator
Recommends:     gcr-viewer
# Support of gnome-contacts will be added in MATE 1.12
#Recommends:     gnome-contacts
Recommends:     gnome-font-viewer
Recommends:     gnome-nettool
Recommends:     gparted
Recommends:     gucharmap
Recommends:     mate-dictionary
Recommends:     mate-disk-usage-analyzer
Recommends:     mate-screenshot
Recommends:     mate-system-log
Recommends:     mate-system-monitor
Recommends:     mate-user-share
Recommends:     mousetweaks
Recommends:     MozillaThunderbird
Recommends:     mozo
Recommends:     orca
Recommends:     pidgin
Recommends:     pluma
Recommends:     seahorse
Recommends:     totem
Recommends:     totem-browser-plugin
Recommends:     zenity
#
# Packages that in fact make sense
#
Recommends:     deja-dup
# Tool for advanced configuration of printers
Recommends:     system-config-printer-applet
Recommends:     system-config-printer
# Tracker is not well integrated for instance with Mate apps
Recommends:     mate-search-tool
#Recommends:     tracker
#Recommends:     tracker-gui
#Recommends:     tracker-miner-evolution
Suggests:       dasher
Suggests:       dconf-editor
Suggests:       mate-backgrounds

%description mate
The MATE desktop environment is a desktop environment using traditional metaphors 

%files mate
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/mate.txt

%package mate_admin
%pattern_matedesktop
Summary:        MATE Administration Tools
Group:          Metapackages
Provides:       pattern() = mate_admin
Provides:       pattern-extends() = mate
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 2050
Requires:       pattern() = basesystem
Requires:       pattern() = x11
Recommends:     mozo
Recommends:     vinagre

%description mate_admin
Administration Tools e.g. for desktop lockdown

%files mate_admin
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/mate_admin.txt

%package mate_basis
%pattern_graphicalenvironments
Summary:        MATE Base System
Group:          Metapackages
Provides:       pattern() = mate_basis
Provides:       pattern-icon() = pattern-mate
Provides:       pattern-order() = 1600
Provides:       pattern-visible()
Requires:       pattern() = basesystem
Requires:       pattern() = x11
Recommends:     pattern() = gnome_basis_opt
Requires:       lightdm
Requires:       mate-session-manager
# default
Recommends:     mate-settings-daemon
#
# Low-level parts that we need
#
Recommends:     NetworkManager
Recommends:     dbus-1-x11
Recommends:     desktop-file-utils
# We want useful bug reports
Recommends:     gdb
Recommends:     gpg2
Recommends:     gpgme
Recommends:     input-utils
Recommends:     polkit-default-privs
Recommends:     samba
Recommends:     susehelp
#
# Branding
#
Recommends:     mate-control-center-branding-openSUSE
Recommends:     mate-menus-branding-openSUSE
Recommends:     mate-panel-branding-openSUSE
Recommends:     mate-session-manager-branding-openSUSE
Recommends:     hicolor-icon-theme-branding-openSUSE
Recommends:     libsocialweb-branding-openSUSE
Recommends:     desktop-branding
#
# Now the real packages
#
Recommends:     gnome-keyring-pam
Recommends:     at-spi2-core
Recommends:     canberra-gtk-play
Recommends:     mate-control-center
Recommends:     mate-themes
Recommends:     mate-icon-theme
Recommends:     mate-icon-theme-faenza
Recommends:     gnome-keyring
Recommends:     mate-menu
Recommends:     marco
Recommends:     mate-applets
Recommends:     mate-media
Recommends:     mate-menus
# boo#905679
Recommends:     mate-polkit
Recommends:     mate-power-manager
Recommends:     mate-screensaver
Recommends:     mate-terminal
Recommends:     caja
Recommends:     NetworkManager-gnome
Recommends:     shared-mime-info
Recommends:     tango-icon-theme
Recommends:     xkeyboard-config
Recommends:     yelp
# Pulseaudio is the default sound server
Recommends:     pulseaudio-module-bluetooth
Recommends:     pulseaudio-module-gconf
Recommends:     pulseaudio-module-lirc
Recommends:     pulseaudio-module-x11
Recommends:     pulseaudio-module-zeroconf
Recommends:     pulseaudio-utils
Recommends:     xdg-user-dirs-gtk
# we need something for xdg-su
Recommends:     libgnomesu

Recommends:     droid-fonts
Recommends:     MozillaFirefox
Recommends:     desktop-data-openSUSE
Recommends:     avahi
Recommends:     xdg-user-dirs
# metalink downloader
Suggests:       aria2

%description mate_basis
Base packages for the MATE desktop environment.

%files mate_basis
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/mate_basis.txt

%package mate_internet
%pattern_matedesktop
Summary:        MATE Internet
Group:          Metapackages
Provides:       pattern() = mate_internet
Provides:       pattern-extends() = mate
Provides:       pattern-icon() = package_network
Provides:       pattern-order() = 2421
Recommends:     pidgin
Recommends:     MozillaThunderbird
Recommends:     mate-netspeed
#
# Packages that really make sense
#
Recommends:     liferea
# As NetworkManager works well on MATE, we should recommend the same packages
Recommends:     NetworkManager-openvpn-gnome
Recommends:     NetworkManager-pptp-gnome
Recommends:     NetworkManager-vpnc-gnome
Recommends:     NetworkManager-openconnect-gnome
# boo#530416
Recommends:     hexchat
Recommends:     transmission-gtk
Suggests:       ekiga
#
# Packages that can make sense
#
Suggests:       gftp
Suggests:       pan
Suggests:       smuxi

%description mate_internet
MATE Internet Applications

%files mate_internet
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/mate_internet.txt

%package mate_laptop
%pattern_matedesktop
Summary:        MATE Laptop
Group:          Metapackages
Provides:       pattern() = mate_laptop
Provides:       pattern-extends() = laptop
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 2260
Supplements:    packageand(patterns-openSUSE-mate:patterns-openSUSE-laptop)
Requires:       pattern() = mate
Recommends:     blueberry
Recommends:     xournal
Suggests:       mate-netbook

%description mate_laptop
MATE Tools designed specifically for use with laptop computers.

%files mate_laptop
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/mate_laptop.txt

%package mate_office
%pattern_graphicalenvironments
Summary:        MATE Office
Group:          Metapackages
Provides:       pattern() = mate_office
Provides:       pattern-extends() = office
Provides:       pattern-icon() = pattern-mate
Provides:       pattern-order() = 2260
Supplements:    packageand(patterns-openSUSE-mate:patterns-openSUSE-office)
Requires:       pattern() = mate_basis
# We provide the same base environment; recommend gnome' one
Recommends:     pattern() = mate_office_opt
Recommends:     libreoffice-gnome
Recommends:     libreoffice-icon-theme-tango
Suggests:       abiword
Suggests:       mupdf
Suggests:       gnumeric
Suggests:       goffice

%description mate_office
MATE Office

%files mate_office
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/mate_office.txt

%package mate_office_opt
%pattern_matedesktop
Summary:        MATE Office
Group:          Metapackages
Provides:       pattern() = mate_office_opt
Provides:       pattern-extends() = office
Provides:       pattern-icon() = pattern-mate
Provides:       pattern-order() = 2261
Supplements:    packageand(patterns-openSUSE-mate:patterns-openSUSE-office)
Requires:       pattern() = mate_basis
Suggests:       grisbi

%description mate_office_opt
MATE Office

%files mate_office_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/mate_office_opt.txt

%package mate_utilities
%pattern_matedesktop
Summary:        MATE Utilities
Group:          Metapackages
Provides:       pattern() = mate_utilities
Provides:       pattern-extends() = mate
Provides:       pattern-icon() = pattern-mate
Provides:       pattern-order() = 2300
Requires:       pattern() = mate_basis
#
# Official upstream
#
Recommends:     mate-disk-usage-analyzer
Recommends:     cheese
Recommends:     engrampa
Recommends:     pluma
Recommends:     galculator
Recommends:     mate-dictionary
Recommends:     gnome-font-viewer
Recommends:     mate-screenshot
Recommends:     gucharmap
Recommends:     caja-sendto
Recommends:     seahorse
# Packages that can make sense
#
Suggests:       conduit
Suggests:       deja-dup
Suggests:       gtg
Suggests:       kerneloops-applet
Suggests:       caja-share
Suggests:       caja-open-terminal
Suggests:       caja-image-converter
Suggests:       pdfmod
Suggests:       synapse
Suggests:       tasque
Suggests:       the-board

%description mate_utilities
MATE Utilities

%files mate_utilities
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/mate_utilities.txt

%package minimal_base
%pattern_basetechnologies
Summary:        Base System
Group:          Metapackages
Provides:       pattern() = minimal_base
Provides:       pattern-icon() = yast-sw_single
Provides:       pattern-order() = 5190
Requires:       pattern() = basesystem
# conflicts with yast2_basis
# Recommends:     pattern() = minimal_base-conflicts
Recommends:     pattern() = yast2_basis
# from data/MINIMAL
Recommends:     aaa_base-extras
Recommends:     bc
Recommends:     cracklib-dict-small
Recommends:     deltarpm
Recommends:     ethtool
Recommends:     glibc-locale
Recommends:     haveged
Recommends:     hdparm
Recommends:     iputils
Recommends:     iproute2
Recommends:     joe
Recommends:     less
Recommends:     lsof
Recommends:     lukemftp
Recommends:     netcat-openbsd
Recommends:     nfs-client
# Recommend NTP at least until boo#936378 is fixed and YaST is not trying to configure a service that's not there
Recommends:     ntp
Recommends:     prctl
Recommends:     rsync
Recommends:     strace
Recommends:     sudo
Recommends:     tcsh
Recommends:     telnet
Recommends:     nscd
# vim is unfortunately too big nowadays
Recommends:     vim
Recommends:     w3m
Recommends:     wget
Recommends:     wol
Requires:       zypper

%description minimal_base
This is the base runtime system.  It contains only a minimal multiuser booting system. For running on real hardware, you need to add additional packages and pattern to make this pattern useful on its own.

%files minimal_base
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/minimal_base.txt

%package minimal_base-conflicts
%pattern_basetechnologies
Summary:        Base System
Group:          Metapackages
Provides:       pattern() = minimal_base-conflicts
Provides:       pattern-icon() = yast-sw_single
Provides:       pattern-order() = 5191
Requires:       pattern() = minimal_base
# from data/MINIMAL-CONFLICTS
Conflicts:      smtp_daemon
Conflicts:      perl-doc
Conflicts:      readline-doc
Conflicts:      bash-doc
Conflicts:      netpbm
# recommended by yast2-printer
Conflicts:      samba-client
Conflicts:      cups-client
Conflicts:      desktop-translations
# supplements into glib
Conflicts:      gsettings-backend-dconf
Conflicts:      glib-networking
Conflicts:      vim-data
# required by gio-branding
Conflicts:      desktop-data-openSUSE
# supplements yast2, not needed for ncurses only
Conflicts:      yast2-branding
# supplements libgio and wget (TODO)
Conflicts:      libproxy1-config-gnome3
# requires python
Conflicts:      zypper-log
# systemd recommends dbus-1-python
Conflicts:      python
# python-base ~ 20MB
Conflicts:      python-base
# perl ~ 40MB ## - we can't conflict with that as perl-Bootloader-YAML needs it
#Conflicts:      perl
# binutils ~ 30MB
#Conflicts:      binutils
# pulls perl
#Conflicts:      zypper-aptitude
# pulls perl
#Conflicts:      perl-gettext
# gtk3
Conflicts:      gtk3-branding
Conflicts:      gtk3-immodule-amharic
Conflicts:      gtk3-immodule-inuktitut
Conflicts:      gtk3-immodule-thai
Conflicts:      gtk3-immodule-tigrigna
Conflicts:      gtk3-immodule-vietnamese
Conflicts:      gvfs
Conflicts:      bundle-lang-gnome-extras-en
# requires X11
Conflicts:      openssh-askpass
# requires all kinds of perl modules
Conflicts:      xdg-utils

%description minimal_base-conflicts
This is the base runtime system.  It contains only a minimal multiuser booting system. For running on real hardware, you need to add additional packages and pattern to make this pattern useful on its own.

%files minimal_base-conflicts
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/minimal_base-conflicts.txt

%package misc_server
%pattern_serverfunctions
Summary:        Miscellaneous Server
Group:          Metapackages
Provides:       pattern() = misc_server
Provides:       pattern-icon() = yast-nfs_server
Provides:       pattern-order() = 2920
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/MISC_SERVER
Recommends:     yast2-nis-server
Recommends:     openslp-server
Recommends:     yast2-instserver
Recommends:     yast2-iscsi-server
Recommends:     yast2-nis-server
Recommends:     yast2-slp-server

%description misc_server
Miscellaneous Server.

%files misc_server
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/misc_server.txt

%package multimedia
%pattern_desktopfunctions
Summary:        Multimedia
Group:          Metapackages
Provides:       pattern() = multimedia
Provides:       pattern-icon() = yast-tv
Provides:       pattern-order() = 1580
Provides:       pattern-visible()
Recommends:     pattern() = multimedia_opt
# from data/MULTIMEDIA
Recommends:     yast2-sound
Recommends:     dvd+rw-tools
Recommends:     vorbis-tools
Suggests:       ripit
# maintained by coolo - must be good
Suggests:       abcde
Suggests:       audacity
Suggests:       timidity
Suggests:       vdr
Suggests:       xawtv
Suggests:       flac

%description multimedia
Multimedia players, sound editing tools , video and image manipulation applications.

%files multimedia
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/multimedia.txt

%package multimedia_opt
%pattern_desktopfunctions
Summary:        Multimedia
Group:          Metapackages
Provides:       pattern() = multimedia_opt
Provides:       pattern-extends() = multimedia
Provides:       pattern-icon() = yast-tv
Provides:       pattern-order() = 1560
# from data/MULTIMEDIA-OPT
Recommends:     ImageMagick
Recommends:     mjpegtools
Suggests:       blender

%description multimedia_opt
Multimedia players, sound editing tools , video and image manipulation applications.

%files multimedia_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/multimedia_opt.txt

%package network_admin
%pattern_serverfunctions
Summary:        Network Administration
Group:          Metapackages
Provides:       pattern() = network_admin
Provides:       pattern-icon() = yast-network
Provides:       pattern-order() = 2940
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/NETWORK-ADMIN
Recommends:     nmap
Recommends:     quagga
Recommends:     tcpdump
Recommends:     whois
Recommends:     wireshark
Recommends:     arpwatch
Recommends:     iftop
Recommends:     nagios
Recommends:     mtr
Suggests:       mrtg
Suggests:       openvpn
Suggests:       opie
Suggests:       kismet
Suggests:       iptraf-ng
Suggests:       privoxy
Suggests:       pptpd
Suggests:       wondershaper
Suggests:       krb5
Suggests:       qinternet

%description network_admin
Tools for administering and debugging networks.

%files network_admin
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/network_admin.txt

%package non_oss
%pattern_proprietarysoftware
Summary:        Misc. Proprietary Packages
Group:          Metapackages
Provides:       pattern() = non_oss
Provides:       pattern-icon() = yast-addon
Provides:       pattern-order() = 3120
Provides:       pattern-visible()
Requires:       pattern() = x11
Recommends:     pattern() = non_oss_opt

%description non_oss
Packages that are proprietary and not under an Open Source license.

%files non_oss
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/non_oss.txt

%package non_oss_opt
%pattern_proprietarysoftware
Summary:        Misc. Proprietary Packages
Group:          Metapackages
Provides:       pattern() = non_oss_opt
Provides:       pattern-extends() = non_oss
Provides:       pattern-icon() = yast-addon
Provides:       pattern-order() = 3121
Requires:       pattern() = non_oss
# from data/NON-OSS-OPT
Recommends:     gst-fluendo-mp3
%ifarch %ix86 x86_64
Recommends:     flash-player
%endif
Recommends:     unrar
Suggests:       poppler-data
%ifarch %ix86
Suggests:       antivir-gui
Suggests:       antivir
%endif
Suggests:       AdobeICCProfiles
Suggests:       acroread
Suggests:       atmel-firmware
Suggests:       ipw-firmware
%ifarch %ix86 x86_64
Suggests:       iscan-firmware
%endif
Suggests:       moneyplex
Suggests:       opera
Suggests:       FZFangSong
Suggests:       FZHeiTi
Suggests:       FZKaiTi
Suggests:       FZKaiTiB
Suggests:       FZMingTiB
# needed for instsys
Suggests:       FZSongTi

%description non_oss_opt
Packages that are proprietary and not under an Open Source license.

%files non_oss_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/non_oss_opt.txt

%package office
%pattern_desktopfunctions
Summary:        Office Software
Group:          Metapackages
Provides:       pattern() = office
Provides:       pattern-icon() = yast-keyboard
Provides:       pattern-order() = 1640
Provides:       pattern-visible()
Recommends:     pattern() = office_opt
# from data/OFFICE
Recommends:     libreoffice
Recommends:     libreoffice-calc
Recommends:     libreoffice-draw
Recommends:     libreoffice-impress
Recommends:     libreoffice-writer

%description office
Office software for your desktop environment including LibreOffice.

%files office
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/office.txt

%package office_opt
%pattern_desktopfunctions
Summary:        Office Software
Group:          Metapackages
Provides:       pattern() = office_opt
Provides:       pattern-extends() = office
Provides:       pattern-icon() = yast-keyboard
Provides:       pattern-order() = 1620
# from data/OFFICE-OPT
# bug 592752
Suggests:       libreoffice-languagetool
Recommends:     libreoffice-math
Recommends:     libreoffice-base-extensions
Recommends:     libreoffice-calc-extensions
Recommends:     libreoffice-draw-extensions
Recommends:     libreoffice-impress-extensions
Recommends:     libreoffice-writer-extensions
Recommends:     libreoffice-converter

%description office_opt
Office software for your desktop environment including LibreOffice.

%files office_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/office_opt.txt

%package print_server
%pattern_serverfunctions
Summary:        Print Server
Group:          Metapackages
Provides:       pattern() = print_server
Provides:       pattern-icon() = yast-printer
Provides:       pattern-order() = 2960
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/PRINT_SERVER
Recommends:     cups
Recommends:     cups-backends
Recommends:     OpenPrintingPPDs
Recommends:     m2300w
Recommends:     splix
Recommends:     foomatic-filters
Recommends:     gutenprint
Recommends:     hplip
Recommends:     manufacturer-PPDs
Recommends:     samba
Suggests:       udev-configure-printer
Suggests:       poster
# print to bluetooth
Suggests:       bluez-cups
Suggests:       pbm2l7k

%description print_server
Software used to host print queues so that they may be accessed by other computers on the same network. LPD, CUPS, and SMB print servers and queues are supported.

%files print_server
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/print_server.txt

%package remote_desktop
%pattern_desktopfunctions
Summary:        Remote Desktop
Group:          Metapackages
Provides:       pattern() = remote_desktop
Provides:       pattern-icon() = yast-x11
Provides:       pattern-order() = 1920
Provides:       pattern-visible()
# from data/REMOTE-DESKTOP
Recommends:     rdesktop
Recommends:     tsclient
Recommends:     tigervnc
Suggests:       krfb
Suggests:       krdc

%description remote_desktop
Tools to access a remote desktop.

%files remote_desktop
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/remote_desktop.txt

%package rest_cd_gnome
%pattern_desktopfunctions
Summary:        Remaining Software
Group:          Metapackages
Provides:       pattern() = rest_cd_gnome
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 1940
Requires:       pattern() = apparmor
Requires:       pattern() = base
Requires:       pattern() = enhanced_base
Requires:       pattern() = fonts
Requires:       pattern() = games
Requires:       pattern() = gnome
Requires:       pattern() = gnome_basis
Requires:       pattern() = gnome_games
Requires:       pattern() = gnome_imaging
Requires:       pattern() = gnome_internet
Requires:       pattern() = gnome_laptop
Requires:       pattern() = gnome_multimedia
Requires:       pattern() = gnome_office
Requires:       pattern() = gnome_utilities
Requires:       pattern() = gnome_yast
Requires:       pattern() = imaging
Requires:       pattern() = multimedia
Requires:       pattern() = office
Requires:       pattern() = sw_management
Requires:       pattern() = sw_management_gnome
Requires:       pattern() = x11
Requires:       pattern() = yast2_basis
Requires:       pattern() = yast2_install_wf
# from data/REST-CD
%ifarch x86_64
Requires:       kernel-desktop
%else
Requires:       kernel-default
%endif
Requires:       kernel-firmware
# #327506
Recommends:     b43-fwcutter
# #304219
Recommends:     memtest86+
# adaptec-firmware (#298726)
Recommends:     adaptec-firmware
Recommends:     mpt-firmware
Recommends:     atmel-firmware
# DELL laptop support
Recommends:     smbios-utils-python
#lvm2 support (#301382)
Recommends:     lvm2
Recommends:     aspell-en
Recommends:     cifs-utils
Recommends:     input-utils
Recommends:     nss_ldap
Recommends:     pam_krb5
Recommends:     pam_ldap
Recommends:     krb5-client
# prefer the full version for installation
Recommends:     cracklib-dict-full
# filesystem(minix)
Recommends:     util-linux
# filesystem(ext2)
Recommends:     e2fsprogs
# filesystem(reiserfs)
Recommends:     reiserfs
# filesystem(jfs)
Recommends:     jfsutils
# filesystem(ntfs-3g)
Recommends:     ntfs-3g
# filesystem(xfs)
Recommends:     xfsprogs
# filesystem(vfat)
Recommends:     dosfstools
# crypto partitions
Recommends:     cryptsetup
# filesystem(btrfs)
Recommends:     btrfsprogs
%ifarch x86_64
# kernel modules
Recommends:     ndiswrapper-kmp-desktop
%else
Recommends:     ndiswrapper-kmp-default
%endif
# network
Recommends:     ndiswrapper
# bnc#548325
Recommends:     ipw-firmware
# supplements by modaliases
Recommends:     bluez-firmware
Recommends:     dvb
Recommends:     lomoco
Recommends:     pcmciautils
Recommends:     pam_fprint
# yast can configure quota - if present on medium (#348336)
Recommends:     quota
# enhances virtualbox speed (#365562)
Recommends:     virtualbox-guest-x11
# Firmware for ZD1211 based WLAN sticks
Recommends:     zd1211-firmware
# rescue
Recommends:     dd_rescue
# #396109
Recommends:     alsa-firmware
Recommends:     awesfx
# needed by yast2-storage for crypt partitions
Recommends:     pam_mount
# adding to LiveCD (bnc#419201)
Recommends:     rsync
Recommends:     smartmontools
# LiveCD accessible? (bnc#391327)
Recommends:     sbl
Recommends:     espeak
# give vim haters an editor
Recommends:     nano
# pull mp3 also on livecd installs
Recommends:     pullin-fluendo-mp3
# #494547 - just testing
Recommends:     manufacturer-PPDs
# needed to detect if a system is the same
Recommends:     dmidecode
# decompression to recover something
Recommends:     xz
Recommends:     zip
Recommends:     unzip
Recommends:     p7zip
# file system stuff
Recommends:     xfsdump
Recommends:     reiserfs
# fate#306643
Recommends:     mc
# laptop stuff
Recommends:     irda
Recommends:     pcmciautils
Recommends:     wpa_supplicant
# bnc#480879
Recommends:     crda
Recommends:     wireless-regdb
Recommends:     iw
# bug#589416
Recommends:     virtualbox-guest-tools
# bug#591085
Recommends:     open-vm-tools
# parted GUI
Recommends:     gparted
# bnc#728529
Recommends:     elilo
%ifarch x86_64
Recommends:     efibootmgr
%endif
# yast2-bootloader still suggests it (bnc#803401)
Recommends:     grub
# Backup and Copying utilites
Recommends:     gnu_ddrescue
Recommends:     lftp
Recommends:     grsync
# all xf86 drivers
Recommends:     xf86-video-ark
Recommends:     xf86-video-ast
Recommends:     xf86-video-ati
Recommends:     xf86-video-chips
Recommends:     xf86-video-cirrus
Recommends:     xf86-video-dummy
Recommends:     xf86-video-fbdev
Recommends:     xf86-video-glint
Recommends:     xf86-video-i128
Recommends:     xf86-video-intel
Recommends:     xf86-video-mach64
Recommends:     xf86-video-mga
Recommends:     xf86-video-modesetting
Recommends:     xf86-video-neomagic
Recommends:     xf86-video-nv
Recommends:     xf86-video-qxl
Recommends:     xf86-video-r128
Recommends:     xf86-video-savage
Recommends:     xf86-video-siliconmotion
Recommends:     xf86-video-sis
Recommends:     xf86-video-sisusb
Recommends:     xf86-video-tdfx
Recommends:     xf86-video-tga
Recommends:     xf86-video-v4l
Recommends:     xf86-video-vesa
Recommends:     xf86-video-vmware
Recommends:     xf86-video-voodoo

# from data/REST-CD-DESKTOP
# minimal set of yast modules
Requires:       yast2-bootloader
Requires:       yast2-country
Requires:       yast2-hardware-detection
Requires:       yast2-network
Requires:       yast2-proxy
Requires:       yast2-storage
Requires:       yast2-trans-stats
Requires:       yast2-x11
Recommends:     bundle-lang-common-en
Recommends:     susehelp_en
Recommends:     yast2-trans-cs
Recommends:     yast2-trans-da
Recommends:     yast2-trans-de
Recommends:     yast2-trans-en_GB
Recommends:     yast2-trans-en_US
Recommends:     yast2-trans-es
Recommends:     yast2-trans-fr
Recommends:     yast2-trans-hu
Recommends:     yast2-trans-it
Recommends:     yast2-trans-ja
Recommends:     yast2-trans-pl
Recommends:     yast2-trans-pt
Recommends:     yast2-trans-pt_BR
Recommends:     yast2-trans-ru
Recommends:     yast2-trans-stats
Recommends:     yast2-trans-sv
Recommends:     yast2-trans-zh_CN
Recommends:     yast2-trans-zh_TW
# required by yast2-dsl (#377472)
Recommends:     smpppd
Recommends:     sssd
%ifarch x86_64
Recommends:     sssd-32bit
# sssd-32bit pulls in some pam-32bit, which results in the need to also have
# systemd-32bit available (or pam-config -a --systemd will fail later on)
Recommends:     systemd-32bit
%endif
Recommends:     gtk2-branding-openSUSE

# from data/REST-CD-GNOME
Recommends:     bundle-lang-gnome-en

%description rest_cd_gnome
Packages that are on CD but not in other patterns.

%files rest_cd_gnome
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/rest_cd_gnome.txt

%package rest_cd_kde
%pattern_desktopfunctions
Summary:        Remaining Software
Group:          Metapackages
Provides:       patterns-openSUSE-rest_cd_kde4 = %{version}
Provides:       pattern() = rest_cd_kde
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 1960
Obsoletes:      patterns-openSUSE-rest_cd_kde4 < %{version}
Requires:       pattern() = apparmor
Requires:       pattern() = base
Requires:       pattern() = enhanced_base
Requires:       pattern() = fonts
Requires:       pattern() = games
Requires:       pattern() = imaging
Requires:       pattern() = kde
Requires:       pattern() = kde_games
Requires:       pattern() = kde_imaging
Requires:       pattern() = kde_internet
Requires:       pattern() = kde_multimedia
Requires:       pattern() = kde_office
Requires:       pattern() = kde_plasma
Requires:       pattern() = kde_utilities
Requires:       pattern() = kde_yast
Requires:       pattern() = multimedia
Requires:       pattern() = office
Requires:       pattern() = sw_management
Requires:       pattern() = sw_management_kde
Requires:       pattern() = x11
Requires:       pattern() = yast2_basis
Requires:       pattern() = yast2_install_wf
# from data/REST-CD
%ifarch x86_64
Requires:       kernel-desktop
%else
Requires:       kernel-default
%endif
Requires:       kernel-firmware
# #327506
Recommends:     b43-fwcutter
# #304219
Recommends:     memtest86+
# adaptec-firmware (#298726)
Recommends:     adaptec-firmware
Recommends:     mpt-firmware
Recommends:     atmel-firmware
# DELL laptop support
Recommends:     smbios-utils-python
#lvm2 support (#301382)
Recommends:     lvm2
Recommends:     aspell-en
Recommends:     cifs-utils
Recommends:     input-utils
Recommends:     nss_ldap
Recommends:     pam_krb5
Recommends:     pam_ldap
Recommends:     krb5-client
# prefer the full version for installation
Recommends:     cracklib-dict-full
# filesystem(minix)
Recommends:     util-linux
# filesystem(ext2)
Recommends:     e2fsprogs
# filesystem(reiserfs)
Recommends:     reiserfs
# filesystem(jfs)
Recommends:     jfsutils
# filesystem(ntfs-3g)
Recommends:     ntfs-3g
# filesystem(xfs)
Recommends:     xfsprogs
# filesystem(vfat)
Recommends:     dosfstools
# crypto partitions
Recommends:     cryptsetup
# filesystem(btrfs)
Recommends:     btrfsprogs
%ifarch x86_64
# kernel modules
Recommends:     ndiswrapper-kmp-desktop
%else
Recommends:     ndiswrapper-kmp-default
%endif
# network
Recommends:     ndiswrapper
# bnc#548325
Recommends:     ipw-firmware
# supplements by modaliases
Recommends:     bluez-firmware
Recommends:     dvb
Recommends:     lomoco
Recommends:     pcmciautils
Recommends:     pam_fprint
# yast can configure quota - if present on medium (#348336)
Recommends:     quota
# enhances virtualbox speed (#365562)
Recommends:     virtualbox-guest-x11
# Firmware for ZD1211 based WLAN sticks
Recommends:     zd1211-firmware
# rescue
Recommends:     dd_rescue
# #396109
Recommends:     alsa-firmware
Recommends:     awesfx
# needed by yast2-storage for crypt partitions
Recommends:     pam_mount
# adding to LiveCD (bnc#419201)
Recommends:     rsync
Recommends:     smartmontools
# LiveCD accessible? (bnc#391327)
Recommends:     sbl
Recommends:     espeak
# give vim hates an editor
Recommends:     nano
# pull flash and mp3 also on livecd installs
Recommends:     pullin-fluendo-mp3
# #494547 - just testing
Recommends:     manufacturer-PPDs
# needed to detect if a system is the same
Recommends:     dmidecode
# decompression to recover something
Recommends:     xz
Recommends:     zip
Recommends:     unzip
Recommends:     p7zip
# file system stuff
Recommends:     xfsdump
Recommends:     reiserfs
# fate#306643
Recommends:     mc
# laptop stuff
Recommends:     irda
Recommends:     pcmciautils
Recommends:     wpa_supplicant
# bnc#480879
Recommends:     crda
Recommends:     wireless-regdb
Recommends:     iw
# bug#589416
Recommends:     virtualbox-guest-tools
# bug#591085
Recommends:     open-vm-tools
# parted GUI
Recommends:     gparted
# bnc#728529
Recommends:     elilo
%ifarch x86_64
Recommends:     efibootmgr
%endif
# yast2-bootloader still suggests it (bnc#803401)
Recommends:     grub
# Backup and Copying utilites
Recommends:     gnu_ddrescue
Recommends:     lftp
Recommends:     grsync
# all xf86 drivers
Recommends:     xf86-video-ark
Recommends:     xf86-video-ast
Recommends:     xf86-video-ati
Recommends:     xf86-video-chips
Recommends:     xf86-video-cirrus
Recommends:     xf86-video-dummy
Recommends:     xf86-video-fbdev
Recommends:     xf86-video-glint
Recommends:     xf86-video-i128
Recommends:     xf86-video-intel
Recommends:     xf86-video-mach64
Recommends:     xf86-video-mga
Recommends:     xf86-video-modesetting
Recommends:     xf86-video-neomagic
Recommends:     xf86-video-nv
Recommends:     xf86-video-qxl
Recommends:     xf86-video-r128
Recommends:     xf86-video-savage
Recommends:     xf86-video-siliconmotion
Recommends:     xf86-video-sis
Recommends:     xf86-video-sisusb
Recommends:     xf86-video-tdfx
Recommends:     xf86-video-tga
Recommends:     xf86-video-v4l
Recommends:     xf86-video-vesa
Recommends:     xf86-video-vmware
Recommends:     xf86-video-voodoo

# from data/REST-CD-DESKTOP
# minimal set of yast modules
Requires:       yast2-bootloader
Requires:       yast2-country
Requires:       yast2-hardware-detection
Requires:       yast2-network
Requires:       yast2-proxy
Requires:       yast2-storage
Requires:       yast2-trans-stats
Requires:       yast2-x11
Recommends:     bundle-lang-common-en
Recommends:     susehelp_en
Recommends:     yast2-trans-cs
Recommends:     yast2-trans-da
Recommends:     yast2-trans-de
Recommends:     yast2-trans-en_GB
Recommends:     yast2-trans-en_US
Recommends:     yast2-trans-es
Recommends:     yast2-trans-fr
Recommends:     yast2-trans-hu
Recommends:     yast2-trans-it
Recommends:     yast2-trans-ja
Recommends:     yast2-trans-pl
Recommends:     yast2-trans-pt
Recommends:     yast2-trans-pt_BR
Recommends:     yast2-trans-ru
Recommends:     yast2-trans-stats
Recommends:     yast2-trans-sv
Recommends:     yast2-trans-zh_CN
Recommends:     yast2-trans-zh_TW
# required by yast2-dsl (#377472)
Recommends:     smpppd
Recommends:     sssd
%ifarch x86_64
Recommends:     sssd-32bit
# sssd-32bit pulls in some pam-32bit, which results in the need to also have
# systemd-32bit available (or pam-config -a --systemd will fail later on)
Recommends:     systemd-32bit
%endif
Recommends:     gtk2-branding-openSUSE

# from data/REST-CD-KDE
Recommends:     bundle-lang-kde-en

%description rest_cd_kde
Packages that are on CD but not in other patterns.

%files rest_cd_kde
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/rest_cd_kde.txt

%package rest_cd_x11
%pattern_desktopfunctions
Summary:        Remaining Software
Group:          Metapackages
Provides:       pattern() = rest_cd_x11
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 1961
Requires:       pattern() = base
Requires:       pattern() = enhanced_base
Requires:       pattern() = fonts
Requires:       pattern() = sw_management
Requires:       pattern() = x11
# from data/REST-CD
%ifarch x86_64
Requires:       kernel-desktop
%else
Requires:       kernel-default
%endif
Requires:       kernel-firmware
# #327506
Recommends:     b43-fwcutter
# #304219
Recommends:     memtest86+
# adaptec-firmware (#298726)
Recommends:     adaptec-firmware
Recommends:     mpt-firmware
Recommends:     atmel-firmware
# DELL laptop support
Recommends:     smbios-utils-python
#lvm2 support (#301382)
Recommends:     lvm2
Recommends:     aspell-en
Recommends:     cifs-utils
Recommends:     input-utils
Recommends:     nss_ldap
Recommends:     pam_krb5
Recommends:     pam_ldap
Recommends:     krb5-client
# prefer the full version for installation
Recommends:     cracklib-dict-full
# filesystem(minix)
Recommends:     util-linux
# filesystem(ext2)
Recommends:     e2fsprogs
# filesystem(reiserfs)
Recommends:     reiserfs
# filesystem(jfs)
Recommends:     jfsutils
# filesystem(ntfs-3g)
Recommends:     ntfs-3g
# filesystem(xfs)
Recommends:     xfsprogs
# filesystem(vfat)
Recommends:     dosfstools
# crypto partitions
Recommends:     cryptsetup
# filesystem(btrfs)
Recommends:     btrfsprogs
%ifarch x86_64
# kernel modules
Recommends:     ndiswrapper-kmp-desktop
%else
Recommends:     ndiswrapper-kmp-default
%endif
# network
Recommends:     ndiswrapper
# bnc#548325
Recommends:     ipw-firmware
# supplements by modaliases
Recommends:     bluez-firmware
Recommends:     dvb
Recommends:     lomoco
Recommends:     pcmciautils
Recommends:     pam_fprint
# yast can configure quota - if present on medium (#348336)
Recommends:     quota
# enhances virtualbox speed (#365562)
Recommends:     virtualbox-guest-x11
# Firmware for ZD1211 based WLAN sticks
Recommends:     zd1211-firmware
# rescue
Recommends:     dd_rescue
# #396109
Recommends:     alsa-firmware
Recommends:     awesfx
# needed by yast2-storage for crypt partitions
Recommends:     pam_mount
# adding to LiveCD (bnc#419201)
Recommends:     rsync
Recommends:     smartmontools
# LiveCD accessible? (bnc#391327)
Recommends:     sbl
Recommends:     espeak
# give vim hates an editor
Recommends:     nano
# pull flash and mp3 also on livecd installs
Recommends:     pullin-fluendo-mp3
# #494547 - just testing
Recommends:     manufacturer-PPDs
# needed to detect if a system is the same
Recommends:     dmidecode
# decompression to recover something
Recommends:     xz
Recommends:     zip
Recommends:     unzip
Recommends:     p7zip
# file system stuff
Recommends:     xfsdump
Recommends:     reiserfs
# fate#306643
Recommends:     mc
# laptop stuff
Recommends:     irda
Recommends:     pcmciautils
Recommends:     wpa_supplicant
# bnc#480879
Recommends:     crda
Recommends:     wireless-regdb
Recommends:     iw
# bug#589416
Recommends:     virtualbox-guest-tools
# bug#591085
Recommends:     open-vm-tools
# parted GUI
Recommends:     gparted
# bnc#728529
Recommends:     elilo
%ifarch x86_64
Recommends:     efibootmgr
%endif
# yast2-bootloader still suggests it (bnc#803401)
Recommends:     grub
# Backup and Copying utilites
Recommends:     gnu_ddrescue
Recommends:     lftp
Recommends:     grsync
# all xf86 drivers
Recommends:     xf86-video-ark
Recommends:     xf86-video-ast
Recommends:     xf86-video-ati
Recommends:     xf86-video-chips
Recommends:     xf86-video-cirrus
Recommends:     xf86-video-dummy
Recommends:     xf86-video-fbdev
Recommends:     xf86-video-glint
Recommends:     xf86-video-i128
Recommends:     xf86-video-intel
Recommends:     xf86-video-mach64
Recommends:     xf86-video-mga
Recommends:     xf86-video-modesetting
Recommends:     xf86-video-neomagic
Recommends:     xf86-video-nv
Recommends:     xf86-video-qxl
Recommends:     xf86-video-r128
Recommends:     xf86-video-savage
Recommends:     xf86-video-siliconmotion
Recommends:     xf86-video-sis
Recommends:     xf86-video-sisusb
Recommends:     xf86-video-tdfx
Recommends:     xf86-video-tga
Recommends:     xf86-video-v4l
Recommends:     xf86-video-vesa
Recommends:     xf86-video-vmware
Recommends:     xf86-video-voodoo

# from data/REST-CD-X11
Requires:       lightdm
Requires:       lightdm-gtk-greeter
Requires:       yast2-bootloader
Requires:       yast2-country
Requires:       yast2-hardware-detection
Requires:       yast2-network
Requires:       yast2-proxy
Requires:       yast2-storage
Requires:       yast2-trans-stats
Requires:       yast2-x11
#
# Additional applications for rescue CD
#
Requires:       file-roller
Requires:       gparted
Requires:       hexchat
Requires:       leafpad
Requires:       midori
Requires:       mupdf
Requires:       photorec
Requires:       ristretto

# from data/XFCE-BASIS
# This defines a bare minimum Xfce desktop used, for example, as
# base for the openSUSE Rescue CD
Requires:       patterns-openSUSE-xfce_basis
Requires:       thunar
Requires:       thunar-volman
Requires:       xfce4-appfinder
Requires:       xfce4-mixer
Requires:       xfce4-notifyd
Requires:       xfce4-panel
Requires:       xfce4-panel-plugin-mixer
Requires:       xfce4-power-manager
Requires:       xfce4-session
Requires:       xfce4-settings
Requires:       xfconf
Requires:       xfdesktop
Requires:       xfwm4
#
# low level functionality
#
Recommends:     avahi
Recommends:     dbus-1-x11
# bnc#540627
Recommends:     xdg-utils
Recommends:     xdg-user-dirs-gtk
Recommends:     desktop-file-utils
Recommends:     shared-mime-info
Recommends:     NetworkManager
Recommends:     NetworkManager-gnome
# use gnomesu as su wrapper
Recommends:     libgnomesu
# bnc#440285
Recommends:     pinentry-gtk2
# For screenlocking to work in xfce
Recommends:     xscreensaver
Recommends:     xfce4-terminal
Recommends:     libxfce4ui-tools
Recommends:     xfce4-panel-plugin-xkb
#
# core desktop functionality
#
Recommends:     libyui-qt-pkg
Recommends:     yast2-control-center-qt
#
# branding
#
Suggests:       exo-branding-openSUSE
Suggests:       gconf2-branding-openSUSE
Suggests:       libgarcon-branding-openSUSE
Suggests:       libxfce4ui-branding-openSUSE
Suggests:       lightdm-gtk-greeter-branding-openSUSE
Suggests:       midori-branding-openSUSE
Suggests:       thunar-volman-branding-openSUSE
Suggests:       wallpaper-branding-openSUSE
Suggests:       xfce4-notifyd-branding-openSUSE
Suggests:       xfce4-panel-branding-openSUSE
Suggests:       xfce4-session-branding-openSUSE
Suggests:       xfce4-settings-branding-openSUSE
Suggests:       xfce4-splash-branding-openSUSE
Suggests:       xfdesktop-branding-openSUSE
Suggests:       xfwm4-branding-openSUSE
Suggests:       desktop-branding

%description rest_cd_x11
Packages that are on CD but not in other patterns.

%files rest_cd_x11
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/rest_cd_x11.txt

%package rest_core_dvd
%pattern_desktopfunctions
Summary:        Remaining Software
Group:          Metapackages
Provides:       pattern() = rest_core_dvd
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 1982
Requires:       pattern() = base
Requires:       pattern() = enhanced_base
Requires:       pattern() = fonts
Requires:       pattern() = sw_management
Requires:       pattern() = x11
Requires:       pattern() = yast2_basis
Requires:       pattern() = yast2_install_wf
Recommends:     pattern() = voip
Recommends:     pattern() = x11_yast
# from data/REST-CORE-CD
%ifarch x86_64
Requires:       kernel-desktop
%else
Requires:       kernel-default
%endif
Requires:       kernel-firmware
#lvm2 support (#301382)
Recommends:     lvm2
# prefer the full version for installation
Recommends:     cracklib-dict-full
# filesystem(minix)
Recommends:     util-linux
# filesystem(ext2)
Recommends:     e2fsprogs
# filesystem(reiserfs)
Recommends:     reiserfs
# filesystem(jfs)
Recommends:     jfsutils
# filesystem(ntfs-3g)
Recommends:     ntfs-3g
# filesystem(xfs)
Recommends:     xfsprogs
# filesystem(vfat)
Recommends:     dosfstools
# crypto partitions
Recommends:     cryptsetup
# filesystem(btrfs)
Recommends:     btrfsprogs
%ifarch x86_64
Recommends:     efibootmgr
%endif
Recommends:     xf86-video-ati
Recommends:     xf86-video-cirrus
Recommends:     xf86-video-fbdev
Recommends:     xf86-video-intel
Recommends:     xf86-video-modesetting
Recommends:     xf86-video-neomagic
Recommends:     xf86-video-nv
Recommends:     xf86-video-qxl
Recommends:     xf86-video-v4l
Recommends:     xf86-video-vesa
Recommends:     xf86-video-vmware
# We need to ensure that systemd-32bit ends up on the DVD
Recommends:     systemd-32bit

%description rest_core_dvd
Packages that are on CD but not in other patterns.

%files rest_core_dvd
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/rest_core_dvd.txt

%package rest_dvd
%pattern_desktopfunctions
Summary:        Remaining Software
Group:          Metapackages
Provides:       pattern() = rest_dvd
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 1980
Requires:       pattern() = apparmor
Requires:       pattern() = apparmor_opt
Requires:       pattern() = base
Requires:       pattern() = console
Requires:       pattern() = devel_C_C++
Requires:       pattern() = devel_basis
Requires:       pattern() = devel_gnome
Requires:       pattern() = devel_ide
Requires:       pattern() = devel_java
Requires:       pattern() = devel_kde
Requires:       pattern() = devel_kde_frameworks
Requires:       pattern() = devel_kernel
Requires:       pattern() = devel_perl
Requires:       pattern() = devel_python
Requires:       pattern() = devel_python3
Requires:       pattern() = devel_qt4
Requires:       pattern() = devel_rpm_build
Requires:       pattern() = devel_ruby
Requires:       pattern() = devel_web
Requires:       pattern() = dhcp_dns_server
Requires:       pattern() = directory_server
Requires:       pattern() = enhanced_base
Requires:       pattern() = enhanced_base_opt
Requires:       pattern() = file_server
Requires:       pattern() = fonts
Requires:       pattern() = fonts_opt
Requires:       pattern() = games
Requires:       pattern() = gateway_server
Requires:       pattern() = generic_server
Requires:       pattern() = gnome
Requires:       pattern() = gnome_admin
Requires:       pattern() = gnome_basis
Requires:       pattern() = gnome_basis_opt
Requires:       pattern() = gnome_games
Requires:       pattern() = gnome_ide
Requires:       pattern() = gnome_imaging
Requires:       pattern() = gnome_imaging_opt
Requires:       pattern() = gnome_internet
Requires:       pattern() = gnome_laptop
Requires:       pattern() = gnome_multimedia
Requires:       pattern() = gnome_multimedia_opt
Requires:       pattern() = gnome_office
Requires:       pattern() = gnome_office_opt
Requires:       pattern() = gnome_utilities
Requires:       pattern() = gnome_yast
Requires:       pattern() = imaging
Requires:       pattern() = imaging_opt
Requires:       pattern() = kde
Requires:       pattern() = kde_edutainment
Requires:       pattern() = kde_games
Requires:       pattern() = kde_ide
Requires:       pattern() = kde_imaging
Requires:       pattern() = kde_internet
Requires:       pattern() = kde_multimedia
Requires:       pattern() = kde_office
Requires:       pattern() = kde_plasma
Requires:       pattern() = kde_telepathy
Requires:       pattern() = kde_utilities
Requires:       pattern() = kde_utilities_opt
Requires:       pattern() = kde_yast
Requires:       pattern() = lamp_server
Requires:       pattern() = laptop
Requires:       pattern() = mail_server
Requires:       pattern() = misc_server
Requires:       pattern() = multimedia
Requires:       pattern() = multimedia_opt
Requires:       pattern() = network_admin
Requires:       pattern() = non_oss
Requires:       pattern() = office
Requires:       pattern() = office_opt
Requires:       pattern() = print_server
Requires:       pattern() = remote_desktop
Requires:       pattern() = sw_management
Requires:       pattern() = sw_management_gnome
Requires:       pattern() = sw_management_kde
Requires:       pattern() = tabletpc
Requires:       pattern() = technical_writing
Requires:       pattern() = x11
Requires:       pattern() = x11_opt
# for now xen_server
Requires:       pattern() = lxde
Requires:       pattern() = lxde_laptop
Requires:       pattern() = xfce
Requires:       pattern() = xfce_basis
Requires:       pattern() = xfce_laptop
Requires:       pattern() = xfce_office
Requires:       pattern() = yast2_basis
Requires:       pattern() = yast2_install_wf
Recommends:     pattern() = x11_yast
Recommends:     pattern() = xen_server
Recommends:     pattern() = kvm_server
Recommends:     pattern() = minimal_base
Recommends:     pattern() = minimal_base-conflicts
Recommends:     pattern() = books
# from data/REST-DVD
# git hype (is a meta package dragging in everything else)
Recommends:     git
# qemu rocks
Recommends:     qemu
# needed for kiwi creation
Recommends:     kiwi-media-requires
Recommends:     squashfs
Recommends:     yast2-live-installer
Recommends:     gfxboot-devel
Recommends:     nbd
Recommends:     nbd-doc
Recommends:     kiwi-config-openSUSE
Recommends:     clicfs
## 306071
Recommends:     virtualbox
Recommends:     virtualbox-guest-kmp-default
Recommends:     vboxgtk
Recommends:     virtualbox-qt
# Internet Storage Name Service
Recommends:     yast2-isns
Recommends:     isns
# hylafax as requested by kkeil
Recommends:     hylafax
Recommends:     hylafax-client
Recommends:     capi4hylafax
# kiwi as requested by ms
Recommends:     kiwi
Recommends:     kiwi-desc-isoboot
Recommends:     kiwi-desc-netboot
Recommends:     kiwi-desc-oemboot
Recommends:     kiwi-desc-vmxboot
Recommends:     kiwi-pxeboot
Recommends:     kiwi-templates
# #301029
Recommends:     yast2-python-bindings
# kdump+tools
Recommends:     kdump
Recommends:     kexec-tools
Recommends:     yast2-kdump
# #296387
Recommends:     xournal
# #297414, #304221
Recommends:     seamonkey
Recommends:     seamonkey-dom-inspector
Recommends:     seamonkey-irc
Recommends:     seamonkey-venkman
# feature 301945
Recommends:     yast2-add-on-creator
Recommends:     yast2-product-creator
Recommends:     createrepo
# kernel modules
Recommends:     omnibook-kmp-default
Recommends:     omnibook-kmp-xen
Recommends:     ndiswrapper-kmp-desktop
Recommends:     omnibook-kmp-desktop
Recommends:     vmware-guest-kmp-desktop
Recommends:     virtualbox-guest-kmp-desktop
# register your hardware
# no sync pattern
Recommends:     bluez-hcidump
Recommends:     libopensync-plugin-google-calendar
Recommends:     libopensync-plugin-moto
Recommends:     libopensync-plugin-python-module
Recommends:     libsyncml-tools
Recommends:     msynctool
Recommends:     unison
# could not find a better pattern
Recommends:     subversion-server
Recommends:     subversion-tools
Recommends:     sshfs
# FAX
Recommends:     capisuite
%ifarch ppc
# #381940
Recommends:     kernel-ppc64
# #387170
Recommends:     ps3-utils
Recommends:     gtkpbbuttons
Recommends:     pbbuttonsd
Recommends:     petitboot
Recommends:     powerprefs
%endif
# minimal korean support (bnc#390099)
Recommends:     unfonts
Recommends:     scim-hangul
# #390825
Recommends:     kvm
# #391434
Recommends:     open-vm-tools
Recommends:     vmware-guest-kmp-default
# all kernel flavors we want to have
Recommends:     kernel-desktop
Recommends:     kernel-default
# bnc#431280 (Japanese fonts)
Recommends:     ttf-arphic-uming
# bnc#697047
Recommends:     siga
%ifarch x86_64 ppc
Recommends:     pam_krb5-32bit
Recommends:     pam_ldap-32bit
Recommends:     nss_ldap-32bit
%endif
%ifarch ppc64
Recommends:     pam_krb5-64bit
Recommends:     pam_ldap-64bit
Recommends:     nss_ldap-64bit
%endif
# bluncks 2nd baby
Recommends:     apport-gtk
Recommends:     apport-qt
# very special case - 442295
# supporting lib for non-oss
Recommends:     libstdc++33
Recommends:     qinternet
# meanwhile plugin (bnc#549711)
Recommends:     libpurple-meanwhile
%ifarch x86_64
# bnc#581144
Recommends:     gtk2-32bit
%endif
# bnc#605888
Recommends:     libvdpau1
# bnc#626952
Recommends:     quota-nfs
# dependencies of skype.rpm
Recommends:     libasound.so.2
Recommends:     libasound.so.2(ALSA_0.9)
Recommends:     libasound.so.2(ALSA_0.9.0rc4)
Recommends:     libc.so.6
Recommends:     libc.so.6(GLIBC_2.0)
Recommends:     libc.so.6(GLIBC_2.1)
Recommends:     libc.so.6(GLIBC_2.1.3)
Recommends:     libc.so.6(GLIBC_2.2)
Recommends:     libc.so.6(GLIBC_2.3)
Recommends:     libc.so.6(GLIBC_2.3.4)
Recommends:     libc.so.6(GLIBC_2.4)
Recommends:     libdbus-1.so.3
Recommends:     libdl.so.2
Recommends:     libdl.so.2(GLIBC_2.0)
Recommends:     libdl.so.2(GLIBC_2.1)
Recommends:     libfontconfig.so.1
Recommends:     libfreetype.so.6
Recommends:     libgcc_s.so.1
Recommends:     libgcc_s.so.1(GCC_3.0)
Recommends:     libgcc_s.so.1(GLIBC_2.0)
Recommends:     libglib-2.0.so.0
Recommends:     libgthread-2.0.so.0
Recommends:     libICE.so.6
Recommends:     libm.so.6
Recommends:     libm.so.6(GLIBC_2.0)
Recommends:     libpng12.so.0
Recommends:     libpthread.so.0
Recommends:     libpthread.so.0(GLIBC_2.0)
Recommends:     libpthread.so.0(GLIBC_2.1)
Recommends:     libpthread.so.0(GLIBC_2.2)
Recommends:     libpthread.so.0(GLIBC_2.3.2)
Recommends:     libQtCore.so.4
Recommends:     libQtDBus.so.4
Recommends:     libQtGui.so.4
Recommends:     libQtNetwork.so.4
Recommends:     libQtXml.so.4
Recommends:     librt.so.1
Recommends:     libSM.so.6
Recommends:     libstdc++.so.6
Recommends:     libstdc++.so.6(CXXABI_1.3)
Recommends:     libstdc++.so.6(GLIBCXX_3.4)
Recommends:     libstdc++.so.6(GLIBCXX_3.4.9)
Recommends:     libX11.so.6
Recommends:     libXcursor.so.1
Recommends:     libXext.so.6
Recommends:     libXfixes.so.3
Recommends:     libXinerama.so.1
Recommends:     libXi.so.6
Recommends:     libXrandr.so.2
Recommends:     libXrender.so.1
Recommends:     libXss.so.1
Recommends:     libXv.so.1
Recommends:     libz.so.1

# from data/REST-CD
%ifarch x86_64
Requires:       kernel-desktop
%else
Requires:       kernel-default
%endif
Requires:       kernel-firmware
# #327506
Recommends:     b43-fwcutter
# #304219
Recommends:     memtest86+
# adaptec-firmware (#298726)
Recommends:     adaptec-firmware
Recommends:     mpt-firmware
Recommends:     atmel-firmware
# DELL laptop support
Recommends:     smbios-utils-python
#lvm2 support (#301382)
Recommends:     lvm2
Recommends:     aspell-en
Recommends:     cifs-utils
Recommends:     input-utils
Recommends:     nss_ldap
Recommends:     pam_krb5
Recommends:     pam_ldap
Recommends:     krb5-client
# prefer the full version for installation
Recommends:     cracklib-dict-full
# filesystem(minix)
Recommends:     util-linux
# filesystem(ext2)
Recommends:     e2fsprogs
# filesystem(reiserfs)
Recommends:     reiserfs
# filesystem(jfs)
Recommends:     jfsutils
# filesystem(ntfs-3g)
Recommends:     ntfs-3g
# filesystem(xfs)
Recommends:     xfsprogs
# filesystem(vfat)
Recommends:     dosfstools
# crypto partitions
Recommends:     cryptsetup
# filesystem(btrfs)
Recommends:     btrfsprogs
%ifarch x86_64
# kernel modules
Recommends:     ndiswrapper-kmp-desktop
%else
Recommends:     ndiswrapper-kmp-default
%endif
# network
Recommends:     ndiswrapper
# bnc#548325
Recommends:     ipw-firmware
# supplements by modaliases
Recommends:     bluez-firmware
Recommends:     dvb
Recommends:     lomoco
Recommends:     pcmciautils
Recommends:     pam_fprint
# yast can configure quota - if present on medium (#348336)
Recommends:     quota
# enhances virtualbox speed (#365562)
Recommends:     virtualbox-guest-x11
# Firmware for ZD1211 based WLAN sticks
Recommends:     zd1211-firmware
# rescue
Recommends:     dd_rescue
# #396109
Recommends:     alsa-firmware
Recommends:     awesfx
# needed by yast2-storage for crypt partitions
Recommends:     pam_mount
# adding to LiveCD (bnc#419201)
Recommends:     rsync
Recommends:     smartmontools
# LiveCD accessible? (bnc#391327)
Recommends:     sbl
Recommends:     espeak
# give vim hates an editor
Recommends:     nano
# pull flash and mp3 also on livecd installs
Recommends:     pullin-fluendo-mp3
# #494547 - just testing
Recommends:     manufacturer-PPDs
# needed to detect if a system is the same
Recommends:     dmidecode
# decompression to recover something
Recommends:     xz
Recommends:     zip
Recommends:     unzip
Recommends:     p7zip
# file system stuff
Recommends:     xfsdump
Recommends:     reiserfs
# fate#306643
Recommends:     mc
# laptop stuff
Recommends:     irda
Recommends:     pcmciautils
Recommends:     wpa_supplicant
# bnc#480879
Recommends:     crda
Recommends:     wireless-regdb
Recommends:     iw
# bug#589416
Recommends:     virtualbox-guest-tools
# bug#591085
Recommends:     open-vm-tools
# parted GUI
Recommends:     gparted
# bnc#728529
Recommends:     elilo
%ifarch x86_64
Recommends:     efibootmgr
%endif
# yast2-bootloader still suggests it (bnc#803401)
Recommends:     grub
# Backup and Copying utilites
Recommends:     gnu_ddrescue
Recommends:     lftp
Recommends:     grsync
# all xf86 drivers
Recommends:     xf86-video-ark
Recommends:     xf86-video-ast
Recommends:     xf86-video-ati
Recommends:     xf86-video-chips
Recommends:     xf86-video-cirrus
Recommends:     xf86-video-dummy
Recommends:     xf86-video-fbdev
Recommends:     xf86-video-glint
Recommends:     xf86-video-i128
Recommends:     xf86-video-intel
Recommends:     xf86-video-mach64
Recommends:     xf86-video-mga
Recommends:     xf86-video-modesetting
Recommends:     xf86-video-neomagic
Recommends:     xf86-video-nv
Recommends:     xf86-video-qxl
Recommends:     xf86-video-r128
Recommends:     xf86-video-savage
Recommends:     xf86-video-siliconmotion
Recommends:     xf86-video-sis
Recommends:     xf86-video-sisusb
Recommends:     xf86-video-tdfx
Recommends:     xf86-video-tga
Recommends:     xf86-video-v4l
Recommends:     xf86-video-vesa
Recommends:     xf86-video-vmware
Recommends:     xf86-video-voodoo

# from data/REST-DVD-SUGGESTS
# generated in the spec file

# from data/REST-DVD-RPMLIST
Requires:       IPAGothic
Requires:       KhmerOS-fonts
Requires:       cracklib-dict-full
Requires:       fonts-arabic
Requires:       fonts-thai
Requires:       indic-fonts
Requires:       lklug
Requires:       ttf-arphic-uming
Requires:       unfonts
Requires:       yast2-trans-af
Requires:       yast2-trans-ar
Requires:       yast2-trans-bg
Requires:       yast2-trans-bn
Requires:       yast2-trans-bs
Requires:       yast2-trans-ca
Requires:       yast2-trans-cs
Requires:       yast2-trans-cy
Requires:       yast2-trans-da
Requires:       yast2-trans-de
Requires:       yast2-trans-el
Requires:       yast2-trans-en_GB
Requires:       yast2-trans-en_US
Requires:       yast2-trans-es
Requires:       yast2-trans-et
Requires:       yast2-trans-fa
Requires:       yast2-trans-fi
Requires:       yast2-trans-fr
Requires:       yast2-trans-gl
Requires:       yast2-trans-gu
Requires:       yast2-trans-hi
Requires:       yast2-trans-hr
Requires:       yast2-trans-hu
Requires:       yast2-trans-id
Requires:       yast2-trans-it
Requires:       yast2-trans-ja
Requires:       yast2-trans-jv
Requires:       yast2-trans-ka
Requires:       yast2-trans-km
Requires:       yast2-trans-ko
Requires:       yast2-trans-lo
Requires:       yast2-trans-lt
Requires:       yast2-trans-mk
Requires:       yast2-trans-mr
Requires:       yast2-trans-nb
Requires:       yast2-trans-nl
Requires:       yast2-trans-pa
Requires:       yast2-trans-pl
Requires:       yast2-trans-pt
Requires:       yast2-trans-pt_BR
Requires:       yast2-trans-ro
Requires:       yast2-trans-ru
Requires:       yast2-trans-si
Requires:       yast2-trans-sk
Requires:       yast2-trans-sl
Requires:       yast2-trans-sr
Requires:       yast2-trans-sv
Requires:       yast2-trans-ta
Requires:       yast2-trans-th
Requires:       yast2-trans-tr
Requires:       yast2-trans-uk
Requires:       yast2-trans-vi
Requires:       yast2-trans-wa
Requires:       yast2-trans-xh
Requires:       yast2-trans-zh_CN
Requires:       yast2-trans-zh_TW
Requires:       yast2-trans-zu

%description rest_dvd
Packages that are on CD but not in other patterns.

%files rest_dvd
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/rest_dvd.txt

%package rest_dvd9
%pattern_desktopfunctions
Summary:        Remaining Software
Group:          Metapackages
Provides:       pattern() = rest_dvd9
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 3500
Requires:       pattern() = rest_dvd
Recommends:     pattern() = x11_yast
Recommends:     pattern() = xen_server
Recommends:     pattern() = kvm_server
Recommends:     pattern() = 32bit
Recommends:     pattern() = 64bit
Recommends:     pattern() = apparmor
Recommends:     pattern() = apparmor_opt
Recommends:     pattern() = base
Recommends:     pattern() = console
Recommends:     pattern() = devel_basis
Recommends:     pattern() = devel_C_C++
Recommends:     pattern() = devel_gnome
Recommends:     pattern() = devel_ide
Recommends:     pattern() = devel_java
Recommends:     pattern() = devel_kde
Recommends:     pattern() = devel_kde_frameworks
Recommends:     pattern() = devel_kernel
Recommends:     pattern() = devel_mono
Recommends:     pattern() = devel_perl
Recommends:     pattern() = devel_python
Recommends:     pattern() = devel_python3
Recommends:     pattern() = devel_qt4
Recommends:     pattern() = devel_qt5
Recommends:     pattern() = devel_rpm_build
Recommends:     pattern() = devel_ruby
Recommends:     pattern() = devel_tcl
Recommends:     pattern() = devel_web
Recommends:     pattern() = devel_yast
Recommends:     pattern() = dhcp_dns_server
Recommends:     pattern() = directory_server
Recommends:     pattern() = enhanced_base
Recommends:     pattern() = enhanced_base_opt
Recommends:     pattern() = file_server
Recommends:     pattern() = fonts
Recommends:     pattern() = fonts_opt
Recommends:     pattern() = games
Recommends:     pattern() = gateway_server
Recommends:     pattern() = gnome
Recommends:     pattern() = gnome_admin
Recommends:     pattern() = gnome_basis
Recommends:     pattern() = gnome_basis_opt
Recommends:     pattern() = gnome_games
Recommends:     pattern() = gnome_ide
Recommends:     pattern() = gnome_imaging
Recommends:     pattern() = gnome_imaging_opt
Recommends:     pattern() = gnome_internet
Recommends:     pattern() = gnome_laptop
Recommends:     pattern() = gnome_multimedia
Recommends:     pattern() = gnome_multimedia_opt
Recommends:     pattern() = gnome_office
Recommends:     pattern() = gnome_office_opt
Recommends:     pattern() = gnome_utilities
Recommends:     pattern() = gnome_yast
Recommends:     pattern() = imaging
Recommends:     pattern() = imaging_opt
Recommends:     pattern() = kde
Recommends:     pattern() = kde_plasma
Recommends:     pattern() = kde_edutainment
Recommends:     pattern() = kde_games
Recommends:     pattern() = kde_ide
Recommends:     pattern() = kde_imaging
Recommends:     pattern() = kde_internet
Recommends:     pattern() = kde_telepathy
Recommends:     pattern() = kde_multimedia
Recommends:     pattern() = kde_office
Recommends:     pattern() = kde_utilities
Recommends:     pattern() = kde_utilities_opt
Recommends:     pattern() = kde_yast
Recommends:     pattern() = lamp_server
Recommends:     pattern() = laptop
Recommends:     pattern() = lxde
Recommends:     pattern() = lxde_laptop
Recommends:     pattern() = lxde_office
Recommends:     pattern() = mail_server
Recommends:     pattern() = misc_server
Recommends:     pattern() = multimedia
Recommends:     pattern() = multimedia_opt
Recommends:     pattern() = network_admin
Recommends:     pattern() = non_oss
Recommends:     pattern() = non_oss_opt
Recommends:     pattern() = office
Recommends:     pattern() = office_opt
Recommends:     pattern() = print_server
Recommends:     pattern() = remote_desktop
Recommends:     pattern() = rest_cd_gnome
Recommends:     pattern() = rest_cd_kde
Recommends:     pattern() = rest_cd_x11
Recommends:     pattern() = rest_dvd
Recommends:     pattern() = rest_dvd9
Recommends:     pattern() = rest_promo_dvd
Recommends:     pattern() = sw_management
Recommends:     pattern() = sw_management_gnome
Recommends:     pattern() = sw_management_kde
Recommends:     pattern() = tabletpc
Recommends:     pattern() = technical_writing
Recommends:     pattern() = voip
Recommends:     pattern() = x11
Recommends:     pattern() = x11_opt
Recommends:     pattern() = x11_yast
Recommends:     pattern() = x86
Recommends:     pattern() = xen_server
Recommends:     pattern() = xfce
Recommends:     pattern() = xfce_basis
Recommends:     pattern() = xfce_laptop
Recommends:     pattern() = xfce_office
Recommends:     pattern() = yast2_basis
Recommends:     pattern() = yast2_install_wf
# from data/REST-DVD9
Recommends:     netbeans
Recommends:     javamail-javadoc
Recommends:     IPAMincho
Recommends:     IPAPGothic
Recommends:     IPAPMincho
Recommends:     bitstream-vera
Recommends:     texlive-cjk
Recommends:     texlive-xetex
Recommends:     texlive-context
Recommends:     desktop-data-openSUSE-extra
Recommends:     xorg-x11-driver-video-radeonhd
Recommends:     netbeans
Recommends:     z88
Recommends:     lilypond-documentation
Recommends:     openclipart-png
Recommends:     libqt4-devel-doc-data

%description rest_dvd9
Packages that are on CD but not in other patterns.

%files rest_dvd9
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/rest_dvd9.txt

%package rest_promo_dvd
%pattern_desktopfunctions
Summary:        Remaining Software
Group:          Metapackages
Provides:       pattern() = rest_promo_dvd
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 1981
Requires:       pattern() = apparmor
Requires:       pattern() = base
Requires:       pattern() = console
Requires:       pattern() = devel_C_C++
Requires:       pattern() = devel_basis
Requires:       pattern() = devel_rpm_build
Requires:       pattern() = dhcp_dns_server
Requires:       pattern() = directory_server
Requires:       pattern() = enhanced_base
Requires:       pattern() = enhanced_base_opt
Requires:       pattern() = file_server
Requires:       pattern() = fonts
Requires:       pattern() = games
Requires:       pattern() = gateway_server
Requires:       pattern() = gnome
Requires:       pattern() = gnome_admin
Requires:       pattern() = gnome_basis
Requires:       pattern() = gnome_games
Requires:       pattern() = gnome_ide
Requires:       pattern() = gnome_imaging
Requires:       pattern() = gnome_internet
Requires:       pattern() = gnome_laptop
Requires:       pattern() = gnome_multimedia
Requires:       pattern() = gnome_office
Requires:       pattern() = gnome_utilities
Requires:       pattern() = gnome_yast
Requires:       pattern() = imaging
Requires:       pattern() = imaging_opt
Requires:       pattern() = kde
Requires:       pattern() = kde_edutainment
Requires:       pattern() = kde_games
Requires:       pattern() = kde_ide
Requires:       pattern() = kde_imaging
Requires:       pattern() = kde_internet
Requires:       pattern() = kde_multimedia
Requires:       pattern() = kde_office
Requires:       pattern() = kde_plasma
Requires:       pattern() = kde_telepathy
Requires:       pattern() = kde_utilities
Requires:       pattern() = kde_utilities_opt
Requires:       pattern() = kde_yast
Requires:       pattern() = lxde
Requires:       pattern() = lxde_laptop
Requires:       pattern() = mail_server
Requires:       pattern() = misc_server
Requires:       pattern() = multimedia
Requires:       pattern() = network_admin
Requires:       pattern() = non_oss
Requires:       pattern() = office
Requires:       pattern() = remote_desktop
Requires:       pattern() = sw_management
Requires:       pattern() = sw_management_gnome
Requires:       pattern() = sw_management_kde
Requires:       pattern() = x11
Requires:       pattern() = x11_opt
Requires:       pattern() = xfce
Requires:       pattern() = xfce_basis
Requires:       pattern() = xfce_laptop
Requires:       pattern() = xfce_office
Requires:       pattern() = yast2_basis
Requires:       pattern() = yast2_install_wf
Recommends:     pattern() = voip
Recommends:     pattern() = x11_yast
# from data/REST-DVD
# git hype (is a meta package dragging in everything else)
Recommends:     git
# qemu rocks
Recommends:     qemu
# needed for kiwi creation
Recommends:     kiwi-media-requires
Recommends:     squashfs
Recommends:     yast2-live-installer
Recommends:     gfxboot-devel
Recommends:     nbd
Recommends:     nbd-doc
Recommends:     kiwi-config-openSUSE
Recommends:     clicfs
## 306071
Recommends:     virtualbox
Recommends:     virtualbox-guest-kmp-default
Recommends:     vboxgtk
Recommends:     virtualbox-qt
# Internet Storage Name Service
Recommends:     yast2-isns
Recommends:     isns
# hylafax as requested by kkeil
Recommends:     hylafax
Recommends:     hylafax-client
Recommends:     capi4hylafax
# kiwi as requested by ms
Recommends:     kiwi
Recommends:     kiwi-desc-isoboot
Recommends:     kiwi-desc-netboot
Recommends:     kiwi-desc-oemboot
Recommends:     kiwi-desc-vmxboot
Recommends:     kiwi-pxeboot
Recommends:     kiwi-templates
# #301029
Recommends:     yast2-python-bindings
# kdump+tools
Recommends:     kdump
Recommends:     kexec-tools
Recommends:     yast2-kdump
# #296387
Recommends:     xournal
# #297414, #304221
Recommends:     seamonkey
Recommends:     seamonkey-dom-inspector
Recommends:     seamonkey-irc
Recommends:     seamonkey-venkman
# feature 301945
Recommends:     yast2-add-on-creator
Recommends:     yast2-product-creator
Recommends:     createrepo
# kernel modules
Recommends:     omnibook-kmp-default
Recommends:     omnibook-kmp-xen
Recommends:     ndiswrapper-kmp-desktop
Recommends:     omnibook-kmp-desktop
Recommends:     vmware-guest-kmp-desktop
Recommends:     virtualbox-guest-kmp-desktop
# register your hardware
# no sync pattern
Recommends:     bluez-hcidump
Recommends:     libopensync-plugin-google-calendar
Recommends:     libopensync-plugin-moto
Recommends:     libopensync-plugin-python-module
Recommends:     libsyncml-tools
Recommends:     msynctool
Recommends:     unison
# could not find a better pattern
Recommends:     subversion-server
Recommends:     subversion-tools
Recommends:     sshfs
# FAX
Recommends:     capisuite
%ifarch ppc
# #381940
Recommends:     kernel-ppc64
# #387170
Recommends:     ps3-utils
Recommends:     gtkpbbuttons
Recommends:     pbbuttonsd
Recommends:     petitboot
Recommends:     powerprefs
%endif
# minimal korean support (bnc#390099)
Recommends:     unfonts
Recommends:     scim-hangul
# #390825
Recommends:     kvm
# #391434
Recommends:     open-vm-tools
Recommends:     vmware-guest-kmp-default
# all kernel flavors we want to have
Recommends:     kernel-desktop
Recommends:     kernel-default
# bnc#431280 (Japanese fonts)
Recommends:     ttf-arphic-uming
# bnc#697047
Recommends:     siga
%ifarch x86_64 ppc
Recommends:     pam_krb5-32bit
Recommends:     pam_ldap-32bit
Recommends:     nss_ldap-32bit
%endif
%ifarch ppc64
Recommends:     pam_krb5-64bit
Recommends:     pam_ldap-64bit
Recommends:     nss_ldap-64bit
%endif
# bluncks 2nd baby
Recommends:     apport-gtk
Recommends:     apport-qt
# very special case - 442295
# supporting lib for non-oss
Recommends:     libstdc++33
Recommends:     qinternet
# meanwhile plugin (bnc#549711)
Recommends:     libpurple-meanwhile
%ifarch x86_64
# bnc#581144
Recommends:     gtk2-32bit
%endif
# bnc#605888
Recommends:     libvdpau1
# bnc#626952
Recommends:     quota-nfs
# dependencies of skype.rpm
Recommends:     libasound.so.2
Recommends:     libasound.so.2(ALSA_0.9)
Recommends:     libasound.so.2(ALSA_0.9.0rc4)
Recommends:     libc.so.6
Recommends:     libc.so.6(GLIBC_2.0)
Recommends:     libc.so.6(GLIBC_2.1)
Recommends:     libc.so.6(GLIBC_2.1.3)
Recommends:     libc.so.6(GLIBC_2.2)
Recommends:     libc.so.6(GLIBC_2.3)
Recommends:     libc.so.6(GLIBC_2.3.4)
Recommends:     libc.so.6(GLIBC_2.4)
Recommends:     libdbus-1.so.3
Recommends:     libdl.so.2
Recommends:     libdl.so.2(GLIBC_2.0)
Recommends:     libdl.so.2(GLIBC_2.1)
Recommends:     libfontconfig.so.1
Recommends:     libfreetype.so.6
Recommends:     libgcc_s.so.1
Recommends:     libgcc_s.so.1(GCC_3.0)
Recommends:     libgcc_s.so.1(GLIBC_2.0)
Recommends:     libglib-2.0.so.0
Recommends:     libgthread-2.0.so.0
Recommends:     libICE.so.6
Recommends:     libm.so.6
Recommends:     libm.so.6(GLIBC_2.0)
Recommends:     libpng12.so.0
Recommends:     libpthread.so.0
Recommends:     libpthread.so.0(GLIBC_2.0)
Recommends:     libpthread.so.0(GLIBC_2.1)
Recommends:     libpthread.so.0(GLIBC_2.2)
Recommends:     libpthread.so.0(GLIBC_2.3.2)
Recommends:     libQtCore.so.4
Recommends:     libQtDBus.so.4
Recommends:     libQtGui.so.4
Recommends:     libQtNetwork.so.4
Recommends:     libQtXml.so.4
Recommends:     librt.so.1
Recommends:     libSM.so.6
Recommends:     libstdc++.so.6
Recommends:     libstdc++.so.6(CXXABI_1.3)
Recommends:     libstdc++.so.6(GLIBCXX_3.4)
Recommends:     libstdc++.so.6(GLIBCXX_3.4.9)
Recommends:     libX11.so.6
Recommends:     libXcursor.so.1
Recommends:     libXext.so.6
Recommends:     libXfixes.so.3
Recommends:     libXinerama.so.1
Recommends:     libXi.so.6
Recommends:     libXrandr.so.2
Recommends:     libXrender.so.1
Recommends:     libXss.so.1
Recommends:     libXv.so.1
Recommends:     libz.so.1

# from data/REST-CD
%ifarch x86_64
Requires:       kernel-desktop
%else
Requires:       kernel-default
%endif
Requires:       kernel-firmware
# #327506
Recommends:     b43-fwcutter
# #304219
Recommends:     memtest86+
# adaptec-firmware (#298726)
Recommends:     adaptec-firmware
Recommends:     mpt-firmware
Recommends:     atmel-firmware
# DELL laptop support
Recommends:     smbios-utils-python
#lvm2 support (#301382)
Recommends:     lvm2
Recommends:     aspell-en
Recommends:     cifs-utils
Recommends:     input-utils
Recommends:     nss_ldap
Recommends:     pam_krb5
Recommends:     pam_ldap
Recommends:     krb5-client
# prefer the full version for installation
Recommends:     cracklib-dict-full
# filesystem(minix)
Recommends:     util-linux
# filesystem(ext2)
Recommends:     e2fsprogs
# filesystem(reiserfs)
Recommends:     reiserfs
# filesystem(jfs)
Recommends:     jfsutils
# filesystem(ntfs-3g)
Recommends:     ntfs-3g
# filesystem(xfs)
Recommends:     xfsprogs
# filesystem(vfat)
Recommends:     dosfstools
# crypto partitions
Recommends:     cryptsetup
# filesystem(btrfs)
Recommends:     btrfsprogs
%ifarch x86_64
# kernel modules
Recommends:     ndiswrapper-kmp-desktop
%else
Recommends:     ndiswrapper-kmp-default
%endif
# network
Recommends:     ndiswrapper
# bnc#548325
Recommends:     ipw-firmware
# supplements by modaliases
Recommends:     bluez-firmware
Recommends:     dvb
Recommends:     lomoco
Recommends:     pcmciautils
Recommends:     pam_fprint
# yast can configure quota - if present on medium (#348336)
Recommends:     quota
# enhances virtualbox speed (#365562)
Recommends:     virtualbox-guest-x11
# Firmware for ZD1211 based WLAN sticks
Recommends:     zd1211-firmware
# rescue
Recommends:     dd_rescue
# #396109
Recommends:     alsa-firmware
Recommends:     awesfx
# needed by yast2-storage for crypt partitions
Recommends:     pam_mount
# adding to LiveCD (bnc#419201)
Recommends:     rsync
Recommends:     smartmontools
# LiveCD accessible? (bnc#391327)
Recommends:     sbl
Recommends:     espeak
# give vim hates an editor
Recommends:     nano
# pull flash and mp3 also on livecd installs
Recommends:     pullin-fluendo-mp3
# #494547 - just testing
Recommends:     manufacturer-PPDs
# needed to detect if a system is the same
Recommends:     dmidecode
# decompression to recover something
Recommends:     xz
Recommends:     zip
Recommends:     unzip
Recommends:     p7zip
# file system stuff
Recommends:     xfsdump
Recommends:     reiserfs
# fate#306643
Recommends:     mc
# laptop stuff
Recommends:     irda
Recommends:     pcmciautils
Recommends:     wpa_supplicant
# bnc#480879
Recommends:     crda
Recommends:     wireless-regdb
Recommends:     iw
# bug#589416
Recommends:     virtualbox-guest-tools
# bug#591085
Recommends:     open-vm-tools
# parted GUI
Recommends:     gparted
# bnc#728529
Recommends:     elilo
%ifarch x86_64
Recommends:     efibootmgr
%endif
# yast2-bootloader still suggests it (bnc#803401)
Recommends:     grub
# Backup and Copying utilites
Recommends:     gnu_ddrescue
Recommends:     lftp
Recommends:     grsync
# all xf86 drivers
Recommends:     xf86-video-ark
Recommends:     xf86-video-ast
Recommends:     xf86-video-ati
Recommends:     xf86-video-chips
Recommends:     xf86-video-cirrus
Recommends:     xf86-video-dummy
Recommends:     xf86-video-fbdev
Recommends:     xf86-video-glint
Recommends:     xf86-video-i128
Recommends:     xf86-video-intel
Recommends:     xf86-video-mach64
Recommends:     xf86-video-mga
Recommends:     xf86-video-modesetting
Recommends:     xf86-video-neomagic
Recommends:     xf86-video-nv
Recommends:     xf86-video-qxl
Recommends:     xf86-video-r128
Recommends:     xf86-video-savage
Recommends:     xf86-video-siliconmotion
Recommends:     xf86-video-sis
Recommends:     xf86-video-sisusb
Recommends:     xf86-video-tdfx
Recommends:     xf86-video-tga
Recommends:     xf86-video-v4l
Recommends:     xf86-video-vesa
Recommends:     xf86-video-vmware
Recommends:     xf86-video-voodoo

# from data/REST-DVD-RPMLIST
Requires:       IPAGothic
Requires:       KhmerOS-fonts
Requires:       cracklib-dict-full
Requires:       fonts-arabic
Requires:       fonts-thai
Requires:       indic-fonts
Requires:       lklug
Requires:       ttf-arphic-uming
Requires:       unfonts
Requires:       yast2-trans-af
Requires:       yast2-trans-ar
Requires:       yast2-trans-bg
Requires:       yast2-trans-bn
Requires:       yast2-trans-bs
Requires:       yast2-trans-ca
Requires:       yast2-trans-cs
Requires:       yast2-trans-cy
Requires:       yast2-trans-da
Requires:       yast2-trans-de
Requires:       yast2-trans-el
Requires:       yast2-trans-en_GB
Requires:       yast2-trans-en_US
Requires:       yast2-trans-es
Requires:       yast2-trans-et
Requires:       yast2-trans-fa
Requires:       yast2-trans-fi
Requires:       yast2-trans-fr
Requires:       yast2-trans-gl
Requires:       yast2-trans-gu
Requires:       yast2-trans-hi
Requires:       yast2-trans-hr
Requires:       yast2-trans-hu
Requires:       yast2-trans-id
Requires:       yast2-trans-it
Requires:       yast2-trans-ja
Requires:       yast2-trans-jv
Requires:       yast2-trans-ka
Requires:       yast2-trans-km
Requires:       yast2-trans-ko
Requires:       yast2-trans-lo
Requires:       yast2-trans-lt
Requires:       yast2-trans-mk
Requires:       yast2-trans-mr
Requires:       yast2-trans-nb
Requires:       yast2-trans-nl
Requires:       yast2-trans-pa
Requires:       yast2-trans-pl
Requires:       yast2-trans-pt
Requires:       yast2-trans-pt_BR
Requires:       yast2-trans-ro
Requires:       yast2-trans-ru
Requires:       yast2-trans-si
Requires:       yast2-trans-sk
Requires:       yast2-trans-sl
Requires:       yast2-trans-sr
Requires:       yast2-trans-sv
Requires:       yast2-trans-ta
Requires:       yast2-trans-th
Requires:       yast2-trans-tr
Requires:       yast2-trans-uk
Requires:       yast2-trans-vi
Requires:       yast2-trans-wa
Requires:       yast2-trans-xh
Requires:       yast2-trans-zh_CN
Requires:       yast2-trans-zh_TW
Requires:       yast2-trans-zu

%description rest_promo_dvd
Packages that are on CD but not in other patterns.

%files rest_promo_dvd
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/rest_promo_dvd.txt

%package sw_management
%pattern_basetechnologies
Summary:        Software Management
Group:          Metapackages
Provides:       pattern() = sw_management
Provides:       pattern-icon() = yast-sw_single
Provides:       pattern-order() = 1360
Provides:       pattern-visible()
Recommends:     pattern() = sw_management_x11
# from data/SW-MANGEMENT
Requires:       zypper
Suggests:       pin

%description sw_management
This pattern provides a graphical application and a command line tool for keeping your system up to date.

%files sw_management
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/sw_management.txt

%package sw_management_gnome
%pattern_basetechnologies
Summary:        Package Management - Graphical Tools for GNOME
Group:          Metapackages
Provides:       pattern() = sw_management_gnome
Provides:       pattern-extends() = sw_management
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 1780
Supplements:    packageand(patterns-openSUSE-gnome_basis:patterns-openSUSE-sw_management)
Requires:       pattern() = sw_management
Requires:       pattern() = x11
# from data/SW-MANGEMENT-GNOME
Recommends:     gnome-packagekit
Recommends:     gnome-software
Suggests:       libyui-gtk-pkg

%description sw_management_gnome
Package Management - Graphical Tools

%files sw_management_gnome
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/sw_management_gnome.txt

%package sw_management_kde
%pattern_basetechnologies
Summary:        Package Management - Graphical Tools for KDE
Group:          Metapackages
Provides:       pattern() = sw_management_kde
Provides:       pattern-extends() = sw_management
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 1820
Supplements:    packageand(patterns-openSUSE-kde_plasma:patterns-openSUSE-sw_management)
Provides:       patterns-openSUSE-sw_management_kde4 = %{version}
Obsoletes:      patterns-openSUSE-sw_management_kde4 < %{version}
Requires:       pattern() = sw_management
Requires:       pattern() = x11
# from data/SW-MANGEMENT-KDE4
Suggests:       libyui-qt-pkg

%description sw_management_kde
Package Management - Graphical Tools

%files sw_management_kde
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/sw_management_kde.txt

%package tabletpc
%pattern_basetechnologies
Summary:        TabletPC
Group:          Metapackages
Provides:       pattern() = tabletpc
Provides:       pattern-icon() = pattern-laptop
Provides:       pattern-order() = 2043
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/TABLETPC
Recommends:     cellwriter
Recommends:     xorg-x11-driver-input
Recommends:     wacom-kmp
Recommends:     xournal
Recommends:     xstroke
Recommends:     eekboard

%description tabletpc
Tools designed specifically for use with TabletPCs.

%files tabletpc
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/tabletpc.txt

%package technical_writing
%pattern_desktopfunctions
Summary:        Technical Writing
Group:          Metapackages
Provides:       pattern() = technical_writing
Provides:       pattern-icon() = yast-messages
Provides:       pattern-order() = 2000
Provides:       pattern-visible()
# from data/TECHNICAL-WRITING
Recommends:     nxml-mode
Recommends:     xmlto
Recommends:     docbook-dsssl-stylesheets
Recommends:     docbook-xsl-stylesheets
Recommends:     psutils
Recommends:     emacs
Recommends:     emacs-x11
Recommends:     xmlgraphics-fop
Recommends:     svg-schema
Recommends:     xslide
# General XML Packages
Recommends:     xmlgraphics-batik
Recommends:     dia
Recommends:     inkscape
Recommends:     mxml
Recommends:     sablot
Recommends:     saxon
#LATER xmlroff
Recommends:     xmlformat
Recommends:     xmlstarlet
# Packages Specific to DocBook
Recommends:     dbsplit-tools
#LATER docbook2odf
Recommends:     docbook_5
Recommends:     docbook5-xsl-stylesheets
Recommends:     docbook-xml-website
#LATER doclifter
Recommends:     susedoc
#LATER texi2db
#LATER wt2db
# Text Encoding Initiative
Recommends:     tei-xsl-stylesheets
Recommends:     tei-roma
Recommends:     texlive-scheme-tetex
Suggests:       lyx
Suggests:       texlive-cjk
Suggests:       texlive-metapost
Suggests:       texlive-omega
Suggests:       texlive-xetex
Suggests:       texlive-context
Suggests:       texlive-omega
Suggests:       texlive-xetex
Suggests:       texlive-tools
Suggests:       texlive-latex-doc
Suggests:       texlive-doc
# 441536
Suggests:       djvulibre

%description technical_writing
Authoring tools and editors for creating technical documentation.

%files technical_writing
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/technical_writing.txt

%package update_test
%pattern_basetechnologies
Summary:        Tests for the Update Stack
Group:          Metapackages
Provides:       pattern() = update_test
Provides:       pattern-icon() = yast-update
Provides:       pattern-order() = 1380
Provides:       pattern-visible()
# from data/UPDATE-TEST
Recommends:     update-test-trival
Recommends:     update-test-affects-package-manager
Recommends:     update-test-security
Recommends:     update-test-interactive
Recommends:     update-test-optional
Recommends:     update-test-reboot-needed
%if %{with betatest}
Recommends:     aaa_base-malloccheck
Supplements:    %{name}-base
%endif

%description update_test
Packages used for testing that the update stack works.  These tiny packages do not have any functionality themselves.

%files update_test
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/update_test.txt

%package voip
%pattern_desktopfunctions
Summary:        Voice Over IP Clients
Group:          Metapackages
Provides:       pattern() = voip
Provides:       pattern-icon() = yast-isdn
Provides:       pattern-order() = 2020
Provides:       pattern-visible()
Requires:       pattern() = x11
# from data/VOIP
Recommends:     ekiga
Suggests:       kiax
Suggests:       linphone
Suggests:       mangler
Suggests:       twinkle

%description voip
Client applications for Internet telephony.

%files voip
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/voip.txt

%package x11
%pattern_graphicalenvironments
Summary:        X Window System
Group:          Metapackages
Provides:       pattern() = x11
Provides:       pattern-icon() = yast-x11
Provides:       pattern-order() = 1800
Provides:       pattern-visible()
Requires:       pattern() = basesystem
Requires:       pattern() = enhanced_base
Requires:       pattern() = fonts
Recommends:     pattern() = x11_opt
Recommends:     pattern() = x11_yast
# from data/X11
Recommends:     xorg-x11-essentials
Recommends:     xkeyboard-config
Recommends:     xorg-x11-server
%ifarch x86_64
Recommends:     nss-mdns-32bit
%endif
# needed e.g. for nvidia drivers
Recommends:     x11-tools
Recommends:     xterm
Recommends:     ghostscript-x11
Recommends:     openssh-askpass
Recommends:     tigervnc
Recommends:     xorg-x11-driver-input
Recommends:     xorg-x11-driver-video
Recommends:     xorg-x11-libX11-ccache
# provides e.g. xdm
Recommends:     xorg-x11-essentials
Recommends:     xorg-x11-Xvnc
# people love having numlock configurable
Recommends:     numlockx
# improve glxinfo output (#301647)
Recommends:     freeglut
# #302566
Recommends:     x11-tools
# #353229 - drag in empty replacements
Recommends:     translation-update
# interesting for workstations too
%ifarch %ix86 x86_64
Recommends:     suspend
%endif
# choose icewm-lite if you have a choice
# icewm-lite is too lightweight in new release
Recommends:     icewm-default
Recommends:     xorg-x11-xauth
# required by others
Suggests:       icewm-gnome
Suggests:       wine
Suggests:       fvwm2
Suggests:       fvwm-themes
Suggests:       wpa_supplicant-gui
Suggests:       hexchat
Suggests:       gv
Suggests:       gvim
Suggests:       mmv
Suggests:       pmidi
Suggests:       xine-ui
Suggests:       xosview
# on security probation
Suggests:       xpdf-poppler
Suggests:       xosd
# #394406
Suggests:       desktop-data-openSUSE-extra
Suggests:       xorg-x11-driver-video-radeonhd
Suggests:       xorg-x11-driver-video-unichrome

%description x11
The X Window System provides the only standard platform-independent networked graphical window system bridging the heterogeneous platforms in today's enterprise: from network servers to desktops, thin clients, laptops, and handhelds, independent of operating system and hardware.

%files x11
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/x11.txt

%package x11_opt
%pattern_graphicalenvironments
Summary:        X Window System
Group:          Metapackages
Provides:       pattern() = x11_opt
Provides:       pattern-extends() = x11
Provides:       pattern-icon() = yast-x11
Provides:       pattern-order() = 1680
Requires:       pattern() = basesystem
Requires:       pattern() = enhanced_base
Requires:       pattern() = fonts
# from data/X11-OPT
Recommends:     freeglut
Recommends:     xdmbgrd
Recommends:     xtermset
Suggests:       tk
Suggests:       unclutter
Suggests:       xlockmore
Suggests:       WindowMaker
Suggests:       WindowMaker-applets
Suggests:       WindowMaker-themes
Suggests:       MozillaThunderbird
# #389816
Suggests:       xorg-x11-server-sdk

%description x11_opt
The X Window System provides the only standard platform-independent networked graphical window system bridging the heterogeneous platforms in today's enterprise: from network servers to desktops, thin clients, laptops, and handhelds, independent of operating system and hardware.

%files x11_opt
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/x11_opt.txt

%package x11_yast
%pattern_basetechnologies
Summary:        YaST User Interfaces
Group:          Metapackages
Provides:       pattern() = x11_yast
Provides:       pattern-extends() = yast2_basis
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 1320
Supplements:    packageand(patterns-openSUSE-x11:patterns-openSUSE-yast2_basis)
Conflicts:      pattern() = gnome
Conflicts:      pattern() = kde
# from data/X11-YaST
Recommends:     libyui-qt-pkg
Recommends:     yast2-control-center-qt
# yast modules for the desktop
Recommends:     yast2-scanner
Recommends:     yast2-tv

%description x11_yast
Graphical YaST user interfaces for minimal X desktop.

%files x11_yast
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/x11_yast.txt

%package x86
%pattern_basetechnologies
Summary:        x86 Runtime Environment
Group:          Metapackages
Provides:       pattern() = x86
Provides:       pattern-icon() = yast-misc
Provides:       pattern-order() = 1180
Provides:       pattern-visible()

%description x86
This will install the 32-bit variant of all selected patterns. This allows to execute 32-bit software.

%files x86
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/x86.txt

%package xen_server
%pattern_serverfunctions
Summary:        Xen Virtual Machine Host Server
Group:          Metapackages
Provides:       pattern() = xen_server
Provides:       pattern-icon() = yast-uml
Provides:       pattern-order() = 3080
Provides:       pattern-visible()
Requires:       pattern() = basesystem
# from data/XEN
Recommends:     bridge-utils
Recommends:     vm-install
Recommends:     xen
Recommends:     xen-libs
Recommends:     xen-tools
%ifarch x86_64 %ix86
Recommends:     kernel-xen
%endif
Recommends:     virt-manager
Recommends:     xen-doc-html
Recommends:     xterm
Recommends:     yast2-vm
Recommends:     virt-viewer
Recommends:     libvirt-daemon-xen
# #382423
Suggests:       install-initrd
Suggests:       libvirt
Suggests:       libvirt-daemon-lxc

%description xen_server
Software to set up a server for configuring, managing, and monitoring virtual machines on a single physical machine.

%files xen_server
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/xen_server.txt

%package xfce
%pattern_graphicalenvironments
Summary:        XFCE Desktop Environment
Group:          Metapackages
Provides:       pattern() = xfce
Provides:       pattern-icon() = pattern-xfce
Provides:       pattern-order() = 1310
Provides:       pattern-visible()
Requires:       pattern() = x11
Requires:       pattern() = xfce_basis
Recommends:     pattern() = xfce_office
Recommends:     pattern() = multimedia
Recommends:     pattern() = imaging
# from data/XFCE
Recommends:     lightdm
Recommends:     lightdm-gtk-greeter
Recommends:     leafpad
Recommends:     gnome-calculator
Recommends:     ristretto
Recommends:     MozillaThunderbird
Recommends:     orage
Recommends:     file-roller
Recommends:     evince
Recommends:     totem
Recommends:     totem-browser-plugin
Recommends:     alacarte
Recommends:     seahorse
Recommends:     thunar-plugin-archive
Recommends:     thunar-plugin-media-tags
Recommends:     xfce4-screenshooter
Recommends:     pidgin
Recommends:     sound-juicer
Recommends:     pragha
Recommends:     simple-scan
Recommends:     shotwell
Recommends:     gucharmap
Recommends:     xfce4-dict
Recommends:     xfce4-panel-plugin-notes
Recommends:     remmina
Recommends:     remmina-plugin-xdmcp
Recommends:     remmina-plugin-rdp
Recommends:     remmina-plugin-vnc
Recommends:     transmission-gtk
Recommends:     gnome-games
# Additional applications
# ease debugging
#
Recommends:     gdb
Recommends:     system-config-printer
Recommends:     system-config-printer-applet
# bnc#537362
Recommends:     gnome-packagekit
Recommends:     pk-update-icon
# bnc#537365
Recommends:     gnome-keyring
Recommends:     gnome-keyring-pam
#
# core desktop functionality
#
Recommends:     xfce4-taskmanager
Recommends:     thunar-volman
Recommends:     tumbler
Suggests:       xfce4-dev-tools
Suggests:       xfce4-panel-plugin-battery
Suggests:       xfce4-panel-plugin-cellmodem
Suggests:       xfce4-panel-plugin-clipman
Suggests:       xfce4-panel-plugin-cpufreq
Suggests:       xfce4-panel-plugin-cpugraph
Suggests:       xfce4-panel-plugin-datetime
Suggests:       xfce4-panel-plugin-dict
Suggests:       xfce4-panel-plugin-diskperf
Suggests:       xfce4-panel-plugin-eyes
Suggests:       xfce4-panel-plugin-fsguard
Suggests:       xfce4-panel-plugin-genmon
Suggests:       xfce4-panel-plugin-mailwatch
Suggests:       xfce4-panel-plugin-mount
Suggests:       xfce4-panel-plugin-mpc
Suggests:       xfce4-panel-plugin-netload
Suggests:       xfce4-panel-plugin-notes
Suggests:       xfce4-panel-plugin-places
Suggests:       xfce4-panel-plugin-quicklauncher
Suggests:       xfce4-panel-plugin-radio
Suggests:       xfce4-panel-plugin-screenshooter
Suggests:       xfce4-panel-plugin-sensors
Suggests:       xfce4-panel-plugin-smartbookmark
Suggests:       xfce4-panel-plugin-systemload
Suggests:       xfce4-panel-plugin-timeout
Suggests:       xfce4-panel-plugin-timer
Suggests:       xfce4-panel-plugin-verve
Suggests:       xfce4-panel-plugin-wavelan
Suggests:       xfce4-panel-plugin-weather
Suggests:       xfwm4-themes
Suggests:       xfce4-vala

# from data/COMMON-DESKTOP-OPT
# packages a GTK application
Recommends:     gutenprint
# MAYBE later lsb-graphics
Recommends:     icedtea-web
# give net shares
Recommends:     samba
# needs python-qt4, see#649280#14
Suggests:       hplip

%description xfce
Xfce is a lightweight desktop environment for various *NIX systems.

%files xfce
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/xfce.txt

%package xfce_basis
%pattern_graphicalenvironments
Summary:        XFCE Base System
Group:          Metapackages
Provides:       pattern() = xfce_basis
Provides:       pattern-extends() = xfce
Provides:       pattern-icon() = pattern-xfce
Provides:       pattern-order() = 1300
Provides:       pattern-visible()
Requires:       pattern() = basesystem
Requires:       pattern() = x11
# from data/XFCE-BASIS
# This defines a bare minimum Xfce desktop used, for example, as
# base for the openSUSE Rescue CD
Requires:       thunar
Requires:       thunar-volman
Requires:       xfce4-appfinder
Requires:       xfce4-mixer
Requires:       xfce4-notifyd
Requires:       xfce4-panel
Requires:       xfce4-panel-plugin-mixer
Requires:       xfce4-power-manager
Requires:       xfce4-session
Requires:       xfce4-settings
Requires:       xfconf
Requires:       xfdesktop
Requires:       xfwm4
#
# low level functionality
#
Recommends:     avahi
Recommends:     dbus-1-x11
# bnc#540627
Recommends:     xdg-utils
Recommends:     xdg-user-dirs-gtk
Recommends:     desktop-file-utils
Recommends:     shared-mime-info
Recommends:     NetworkManager
Recommends:     NetworkManager-gnome
# use gnomesu as su wrapper
Recommends:     libgnomesu
# bnc#440285
Recommends:     pinentry-gtk2
# For screenlocking to work in xfce
Recommends:     xscreensaver
Recommends:     xfce4-terminal
Recommends:     libxfce4ui-tools
Recommends:     xfce4-panel-plugin-xkb
#
# core desktop functionality
#
Recommends:     libyui-qt-pkg
Recommends:     yast2-control-center-qt
#
# branding
#
Suggests:       exo-branding-openSUSE
Suggests:       gconf2-branding-openSUSE
Suggests:       libgarcon-branding-openSUSE
Suggests:       libxfce4ui-branding-openSUSE
Suggests:       lightdm-gtk-greeter-branding-openSUSE
Suggests:       midori-branding-openSUSE
Suggests:       thunar-volman-branding-openSUSE
Suggests:       wallpaper-branding-openSUSE
Suggests:       xfce4-notifyd-branding-openSUSE
Suggests:       xfce4-panel-branding-openSUSE
Suggests:       xfce4-session-branding-openSUSE
Suggests:       xfce4-settings-branding-openSUSE
Suggests:       xfce4-splash-branding-openSUSE
Suggests:       xfdesktop-branding-openSUSE
Suggests:       xfwm4-branding-openSUSE
Suggests:       desktop-branding

# from data/COMMON-DESKTOP
Recommends:     droid-fonts
Recommends:     MozillaFirefox
Recommends:     desktop-data-openSUSE
Recommends:     avahi
# bnc#508120
Recommends:     xdg-user-dirs
# bnc#598884
Suggests:       moonlight-plugin
# metalink downloader
Suggests:       aria2

%description xfce_basis
Base packages for the XFCE Desktop Environment

%files xfce_basis
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/xfce_basis.txt

%package xfce_laptop
%pattern_xfcedesktop
Summary:        XFCE Laptop
Group:          Metapackages
Provides:       pattern() = xfce_laptop
Provides:       pattern-extends() = laptop
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 5180
Supplements:    packageand(patterns-openSUSE-xfce:patterns-openSUSE-laptop)
Requires:       pattern() = xfce
Requires:       pattern() = xfce_basis

%description xfce_laptop
XFCE Laptop

%files xfce_laptop
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/xfce_laptop.txt

%package xfce_office
%pattern_graphicalenvironments
Summary:        XFCE Office
Group:          Metapackages
Provides:       pattern() = xfce_office
Provides:       pattern-extends() = office
Provides:       pattern-icon() = yast-x11
Provides:       pattern-order() = 2241
Supplements:    packageand(patterns-openSUSE-xfce:patterns-openSUSE-office)
Requires:       pattern() = xfce
Requires:       pattern() = xfce_basis
# from data/XFCE-Office
%ifarch %ix86 x86_64
Recommends:     libreoffice-gnome
%endif

%description xfce_office
XFCE Office

%files xfce_office
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/xfce_office.txt

%package yast2_basis
%pattern_basetechnologies
Summary:        YaST System Administration
Group:          Metapackages
Provides:       pattern() = yast2_basis
Provides:       pattern-icon() = yast
Provides:       pattern-order() = 1220
Provides:       pattern-visible()
# from data/YAST_BASIS
Requires:       libyui-ncurses-pkg
Requires:       yast2
Requires:       yast2-country
Requires:       yast2-firewall
Requires:       yast2-hardware-detection
Requires:       yast2-installation
Requires:       yast2-ldap
Requires:       yast2-mail
Requires:       yast2-network
Requires:       yast2-online-update
Requires:       yast2-online-update-frontend
Requires:       yast2-packager
Requires:       yast2-pam
Requires:       yast2-perl-bindings
Requires:       yast2-pkg-bindings
Requires:       yast2-security
Requires:       yast2-services-manager
Requires:       yast2-storage
Requires:       yast2-sysconfig
Requires:       yast2-theme-openSUSE
Requires:       yast2-transfer
Requires:       yast2-tune
Requires:       yast2-update
Requires:       yast2-users
Requires:       yast2-xml
Recommends:     yast2-inetd
Recommends:     yast2-iscsi-client
Recommends:     yast2-kerberos-client
Recommends:     yast2-ldap-client
Recommends:     yast2-metapackage-handler
Recommends:     yast2-nfs-client
Recommends:     yast2-nis-client
Recommends:     yast2-ntp-client
Recommends:     yast2-printer
Recommends:     yast2-slp
Recommends:     yast2-sudo
# see the discussion in #386473
Recommends:     yast2-samba-client
Recommends:     yast2-samba-server
# #388892
Recommends:     yast2-vm
# #542936
Recommends:     yast2-packager-webpin
Recommends:     yast2-auth-client
Recommends:     yast2-fonts
Recommends:     yast2-journal
Recommends:     yast2-vpn
Suggests:       yast2-online-update-configuration
Suggests:       yast2-product-creator
Suggests:       autoyast2
Suggests:       autoyast2-installation
Suggests:       inst-source-utils
Suggests:       libyui-qt-pkg
Suggests:       libyui-gtk-pkg
Suggests:       yast2-autofs
Suggests:       yast2-drbd
Suggests:       yast2-firstboot
Suggests:       yast2-mail-plugins
Suggests:       yast2-multipath
Suggests:       yast2-phone-services
Suggests:       yast2-snapper
# #381365
Suggests:       yast2-squid
# see extra-packages for reasons
Suggests:       star
Suggests:       sbl
Suggests:       Mesa
Suggests:       i4l-isdnlog
Suggests:       ypserv
Suggests:       ntp
Suggests:       ntp-doc
Suggests:       star
Suggests:       alevt
Suggests:       kradio
Suggests:       motv
Suggests:       nxtvepg
Suggests:       v4l-tools
Suggests:       install-initrd
# for yast2-scanner
# mandatory
Suggests:       sane-backends
# optionally
Suggests:       hplip
# optionally, open source, derived from iscan
Suggests:       iscan-free
# themeing for hardcore KDE lovers
Suggests:       yast2-theme-openSUSE-Crystal
Suggests:       yast2-theme-openSUSE-Oxygen
Suggests:       ivtv
Suggests:       ivtv-firmware
# required by yast2-storage
Suggests:       pam_mount
%ifarch x86_64
Suggests:       pam_fp-32bit
%endif
%ifarch ppc64
Suggests:       pam_fp-64bit
%endif
# yast2-sound
Suggests:       alsa-firmware
Suggests:       alsa-tools
# yast2-printer - printing via novell ipx
Suggests:       ncpfs
# yast2-kdump
%ifarch ppc
Suggests:       kernel-kdump
%endif
Suggests:       yast2-fingerprint-reader
Suggests:       sssd
Suggests:       snapper
# FATE 304350
Suggests:       sblim-sfcb
Suggests:       cim-schema

%description yast2_basis
YaST tools for basic system administration.

%files yast2_basis
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/yast2_basis.txt

%package yast2_install_wf
%pattern_basetechnologies
Summary:        YaST Installation Packages
Group:          Metapackages
Provides:       pattern() = yast2_install_wf
Provides:       pattern-icon() = yast
Provides:       pattern-order() = 1240
Provides:       pattern-visible()
# from data/YAST_INSTALL_WF
Requires:       libyui-ncurses-pkg
Requires:       yast2-installation
Requires:       yast2-network
Requires:       yast2-users
# bnc#535101
Requires:       yast2-bootloader
# required to write ntp.conf (bnc#723018)
Requires:       yast2-ntp-client
Suggests:       autoyast2-installation
Suggests:       yast2-firewall
Suggests:       yast2-kerberos-client
Suggests:       yast2-ldap
Suggests:       yast2-ldap-client
Suggests:       yast2-nfs-client
Suggests:       yast2-nis-client
Suggests:       yast2-printer
Suggests:       yast2-samba-client
Suggests:       yast2-slp
Suggests:       yast2-tv
Suggests:       yast2-update
Suggests:       autoyast2
%ifarch x86_64
Suggests:       samba-client-32bit
Suggests:       samba-winbind-32bit
%endif
%ifarch ppc64
Suggests:       pam_fp-64bit
Suggests:       pam_krb5-64bit
Suggests:       nss_ldap-64bit
Suggests:       pam_ldap-64bit
Suggests:       samba-client-64bit
Suggests:       samba-winbind-64bit
%endif
Suggests:       tgt

%description yast2_install_wf
YaST tools for installing your system.

%files yast2_install_wf
%dir /usr/share/doc/packages/patterns-openSUSE
/usr/share/doc/packages/patterns-openSUSE/yast2_install_wf.txt

#END1

%prep

%build

%install
#BEGIN2
mkdir -p $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/
echo 'This file marks the pattern 32bit to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/32bit.txt
echo 'This file marks the pattern 64bit to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/64bit.txt
echo 'This file marks the pattern apparmor to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/apparmor.txt
echo 'This file marks the pattern apparmor_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/apparmor_opt.txt
echo 'This file marks the pattern base to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/base.txt
echo 'This file marks the pattern books to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/books.txt
echo 'This file marks the pattern console to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/console.txt
echo 'This file marks the pattern devel_basis to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_basis.txt
echo 'This file marks the pattern devel_C_C++ to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_C_C++.txt
echo 'This file marks the pattern devel_gnome to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_gnome.txt
echo 'This file marks the pattern devel_ide to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_ide.txt
echo 'This file marks the pattern devel_java to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_java.txt
echo 'This file marks the pattern devel_kde_frameworks to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_kde_frameworks.txt
echo 'This file marks the pattern devel_kde to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_kde.txt
echo 'This file marks the pattern devel_kernel to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_kernel.txt
echo 'This file marks the pattern devel_mono to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_mono.txt
echo 'This file marks the pattern devel_perl to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_perl.txt
echo 'This file marks the pattern devel_python to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_python.txt
echo 'This file marks the pattern devel_python3 to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_python3.txt
echo 'This file marks the pattern devel_qt4 to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_qt4.txt
echo 'This file marks the pattern devel_qt5 to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_qt5.txt
echo 'This file marks the pattern devel_rpm_build to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_rpm_build.txt
echo 'This file marks the pattern devel_ruby to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_ruby.txt
echo 'This file marks the pattern devel_tcl to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_tcl.txt
echo 'This file marks the pattern devel_web to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_web.txt
echo 'This file marks the pattern devel_yast to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/devel_yast.txt
echo 'This file marks the pattern dhcp_dns_server to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/dhcp_dns_server.txt
echo 'This file marks the pattern directory_server to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/directory_server.txt
echo 'This file marks the pattern enlightenment to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/enlightenment.txt
echo 'This file marks the pattern enhanced_base to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/enhanced_base.txt
echo 'This file marks the pattern enhanced_base_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/enhanced_base_opt.txt
echo 'This file marks the pattern file_server to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/file_server.txt
echo 'This file marks the pattern fonts to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/fonts.txt
echo 'This file marks the pattern fonts_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/fonts_opt.txt
echo 'This file marks the pattern games to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/games.txt
echo 'This file marks the pattern gateway_server to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gateway_server.txt
echo 'This file marks the pattern generic_server to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/generic_server.txt
echo 'This file marks the pattern gnome to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome.txt
echo 'This file marks the pattern gnome_admin to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_admin.txt
echo 'This file marks the pattern gnome_basis to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_basis.txt
echo 'This file marks the pattern gnome_basis_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_basis_opt.txt
echo 'This file marks the pattern gnome_games to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_games.txt
echo 'This file marks the pattern gnome_ide to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_ide.txt
echo 'This file marks the pattern gnome_imaging to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_imaging.txt
echo 'This file marks the pattern gnome_imaging_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_imaging_opt.txt
echo 'This file marks the pattern gnome_internet to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_internet.txt
echo 'This file marks the pattern gnome_laptop to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_laptop.txt
echo 'This file marks the pattern gnome_multimedia to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_multimedia.txt
echo 'This file marks the pattern gnome_multimedia_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_multimedia_opt.txt
echo 'This file marks the pattern gnome_office to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_office.txt
echo 'This file marks the pattern gnome_office_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_office_opt.txt
echo 'This file marks the pattern gnome_utilities to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_utilities.txt
echo 'This file marks the pattern gnome_yast to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/gnome_yast.txt
echo 'This file marks the pattern haskell_platform to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/haskell_platform.txt
echo 'This file marks the pattern imaging to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/imaging.txt
echo 'This file marks the pattern imaging_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/imaging_opt.txt
echo 'This file marks the pattern kde to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kde.txt
echo 'This file marks the pattern kde_plasma to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kde_plasma.txt
echo 'This file marks the pattern kde_edutainment to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kde_edutainment.txt
echo 'This file marks the pattern kde_games to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kde_games.txt
echo 'This file marks the pattern kde_ide to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kde_ide.txt
echo 'This file marks the pattern kde_imaging to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kde_imaging.txt
echo 'This file marks the pattern kde_internet to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kde_internet.txt
echo 'This file marks the pattern kde_telepathy to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kde_telepathy.txt
echo 'This file marks the pattern kde_multimedia to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kde_multimedia.txt
echo 'This file marks the pattern kde_office to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kde_office.txt
echo 'This file marks the pattern kde_utilities to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kde_utilities.txt
echo 'This file marks the pattern kde_utilities_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kde_utilities_opt.txt
echo 'This file marks the pattern kde_yast to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kde_yast.txt
echo 'This file marks the pattern kvm_server to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/kvm_server.txt
echo 'This file marks the pattern lamp_server to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/lamp_server.txt
echo 'This file marks the pattern laptop to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/laptop.txt
echo 'This file marks the pattern leechcraft to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/leechcraft.txt
echo 'This file marks the pattern leechcraft_browser to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/leechcraft_browser.txt
echo 'This file marks the pattern leechcraft_media to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/leechcraft_media.txt
echo 'This file marks the pattern leechcraft_messenger to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/leechcraft_messenger.txt
echo 'This file marks the pattern leechcraft_netutils to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/leechcraft_netutils.txt
echo 'This file marks the pattern leechcraft_office to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/leechcraft_office.txt
echo 'This file marks the pattern leechcraft_utilities to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/leechcraft_utilities.txt
echo 'This file marks the pattern lxde to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/lxde.txt
echo 'This file marks the pattern lxqt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/lxqt.txt
echo 'This file marks the pattern lxde_laptop to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/lxde_laptop.txt
echo 'This file marks the pattern lxde_office to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/lxde_office.txt
echo 'This file marks the pattern mail_server to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/mail_server.txt
echo 'This file marks the pattern mate to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/mate.txt
echo 'This file marks the pattern mate_admin to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/mate_admin.txt
echo 'This file marks the pattern mate_basis to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/mate_basis.txt
echo 'This file marks the pattern mate_laptop to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/mate_laptop.txt
echo 'This file marks the pattern mate_internet to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/mate_internet.txt
echo 'This file marks the pattern mate_office to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/mate_office.txt
echo 'This file marks the pattern mate_office_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/mate_office_opt.txt
echo 'This file marks the pattern mate_utilities to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/mate_utilities.txt
echo 'This file marks the pattern minimal_base to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/minimal_base.txt
echo 'This file marks the pattern minimal_base-conflicts to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/minimal_base-conflicts.txt
echo 'This file marks the pattern misc_server to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/misc_server.txt
echo 'This file marks the pattern multimedia to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/multimedia.txt
echo 'This file marks the pattern multimedia_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/multimedia_opt.txt
echo 'This file marks the pattern network_admin to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/network_admin.txt
echo 'This file marks the pattern non_oss to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/non_oss.txt
echo 'This file marks the pattern non_oss_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/non_oss_opt.txt
echo 'This file marks the pattern office to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/office.txt
echo 'This file marks the pattern office_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/office_opt.txt
echo 'This file marks the pattern print_server to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/print_server.txt
echo 'This file marks the pattern remote_desktop to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/remote_desktop.txt
echo 'This file marks the pattern rest_cd_gnome to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/rest_cd_gnome.txt
echo 'This file marks the pattern rest_cd_kde to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/rest_cd_kde.txt
echo 'This file marks the pattern rest_cd_x11 to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/rest_cd_x11.txt
echo 'This file marks the pattern rest_core_dvd to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/rest_core_dvd.txt
echo 'This file marks the pattern rest_dvd to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/rest_dvd.txt
echo 'This file marks the pattern rest_dvd9 to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/rest_dvd9.txt
echo 'This file marks the pattern rest_promo_dvd to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/rest_promo_dvd.txt
echo 'This file marks the pattern sw_management to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/sw_management.txt
echo 'This file marks the pattern sw_management_gnome to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/sw_management_gnome.txt
echo 'This file marks the pattern sw_management_kde to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/sw_management_kde.txt
echo 'This file marks the pattern tabletpc to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/tabletpc.txt
echo 'This file marks the pattern technical_writing to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/technical_writing.txt
echo 'This file marks the pattern update_test to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/update_test.txt
echo 'This file marks the pattern voip to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/voip.txt
echo 'This file marks the pattern x11 to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/x11.txt
echo 'This file marks the pattern x11_opt to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/x11_opt.txt
echo 'This file marks the pattern x11_yast to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/x11_yast.txt
echo 'This file marks the pattern x86 to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/x86.txt
echo 'This file marks the pattern xen_server to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/xen_server.txt
echo 'This file marks the pattern xfce to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/xfce.txt
echo 'This file marks the pattern xfce_basis to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/xfce_basis.txt
echo 'This file marks the pattern xfce_laptop to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/xfce_laptop.txt
echo 'This file marks the pattern xfce_office to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/xfce_office.txt
echo 'This file marks the pattern yast2_basis to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/yast2_basis.txt
echo 'This file marks the pattern yast2_install_wf to be installed.' > $RPM_BUILD_ROOT/usr/share/doc/packages/patterns-openSUSE/yast2_install_wf.txt
#END2

%changelog
* Wed Jan 25 2017 tiwai@suse.de
- Drop gsynaptics Recommends from XFCE and LXDE patterns
  (boo#1010202):
  This drags xf86-input-synaptics and blocks the libinput usage as
  a consequence although we've already wanted to move to libinput.
* Wed Oct 26 2016 lnussel@suse.de
- Add devel_python3 to DVD (boo#1004298)
* Wed Oct 26 2016 alarrosa@suse.com
- Recommend kdeconnect-kde in the kde_plasma pattern. This plasma
  widget adds a lot to the user experience.
* Tue Oct 18 2016 mvetter@suse.com
- boo#1005324: adding pavucontrol-qt without pulseaudio does not
  make sense.
* Wed Oct 12 2016 dimstar@opensuse.org
- Do not recommend tracker, tracker-gui and brasero for the XFCE
  Desktop: Tracker is well integrated into the GNOME Desktop and
  GNOME Applications, but XFCE itself can't do much with its
  database (boo#1002454).
* Mon Oct 10 2016 mvetter@suse.com
- Update LXQt pattern:
  * New core packages: lxqt-l10n, lxqt-sudo
  * Non core packages who still belong to LXQt upstream organization:
  obconf-qt, pavucontrol-qt
  * Replace gwenview by lximage-qt.
* Fri Sep 16 2016 alarrosa@suse.com
- Added kdebase4-workspace-libs Recommend to the kde_plasma pattern
  so qt4 apps use the breeze style instead of depending on indirect
  requirements to install that package.
* Wed Sep  7 2016 davejplater@gmail.com
- Removed wodim from the console pattern
* Mon Aug 15 2016 lnussel@suse.de
- switchto lightdm instead of lxdm
* Thu Aug 11 2016 lnussel@suse.de
- Install gnome-shell-classic by default. Includes SLE-classic which might be
  interesting for conservative desktop users.
* Mon Aug  8 2016 lnussel@suse.de
- remove references to rsh, smpppd, checkinstall. The packages got
  dropped long ago.
* Tue Aug  2 2016 lnussel@suse.de
- replace xchat with hexchat
* Tue Jul 19 2016 lnussel@suse.de
- sync kDE5 changes from Factory
* Fri Jun 17 2016 mvetter@suse.com
- Add LightDM to LXQt pattern
- Require LXQt core components for LXQt pattern instead of only recommending them
* Tue May 31 2016 lnussel@suse.de
- prefer icewm-default over icewm-lite, the latter apparently has no start
  button
* Thu Nov  5 2015 pgajdos@suse.com
- install google-roboto-fonts instead of dejavu-fonts in -fonts
  pattern, add noto-sans to -fonts_opt pattern [bnc#951898]
* Wed Oct 28 2015 coolo@suse.com
- remove update_test from DVD
* Tue Oct 27 2015 coolo@suse.com
- add generic_server to the dvd and make minimal_base use yast
  (210MB, but not worth the pain)
* Mon Oct 26 2015 dimstar@opensuse.org
- Remove alacarte from the gnome pattern: it is reasonably non-
  functional to start with.
- Add pk-update-icon to GNOME pattern: use this as the openSUSE
  supported update notification method.
* Fri Oct 23 2015 coolo@suse.com
- pullin-flash-player is no longer there
* Thu Oct 22 2015 simon@simotek.net
- Enlightenment requires lightdm to make the net install selection
  work fixes (boo#951558)
- Recomend the following efl based apps over there generic counterparts
  in the enlightenment pattern
    mupdf -> lekha
    vlc -> rage
* Wed Oct 21 2015 hrvoje.senjan@gmail.com
- kde_plasma now require plasma5-pk-updates package
- Remove apper recommends in kde pattern
* Tue Oct 20 2015 hrvoje.senjan@gmail.com
- Add recommends for baloo5-tools and baloo5-kioslaves to kde_plasma
  pattern (boo#948810)
- Given that video playback with vlc on Qt 5.5 is broken ATM, default
  to dragonplayer in plasma
* Sun Oct 18 2015 hrvoje.senjan@gmail.com
- Adjust kde plasma pattern to current state of things: require
  plasma5-pa instead of kmix
- Let plasma pattern be more useful: require at least one video
  player (vlc-qt)
* Thu Oct 15 2015 mlatimer@suse.com
- Suggest libvirt-daemon-lxc for both Xen and KVM patterns.
  [bsc#947242]
* Fri Oct  9 2015 schwab@suse.de
- Recommend grub2-arm64-efi on aarch64
- create_macros: use %%global instead of %%define
* Thu Oct  8 2015 coolo@suse.com
- drag in updatetest packages if with_betatest is defined in the project
  (Leap for now)
* Thu Oct  1 2015 bwiedemann@suse.com
- Add generic_server pattern
* Thu Sep 24 2015 dimstar@opensuse.org
- Recommend systemd-32bit in the rest_dvd_core pattern.
* Wed Sep 23 2015 dimstar@opensuse.org
- Also fix the KDE CD: sssd-32bit is recommended there too, so also
  recommend systemd-32bit.
* Wed Sep 23 2015 dimstar@opensuse.org
- When recommending sssd-32bit, also recommend systemd-32bit: the
  systemd-pam modules are needed in this case too (not strictly a
  requirement, but pam-config -a --systemd fails on a 64bit system
  when pam-32bit is installed but the 32bit pam modules are not).
* Tue Sep 22 2015 mvetter@suse.com
- Add basic lxqt pattern
* Fri Sep 18 2015 p.drouand@gmail.com
- create mate_internet and mate_office_opt patterns
- Recommend newly created patterns instead of GNOME's ones; recommending
  GNOME's intall plenty of packages unwanted by regular users
* Tue Sep  8 2015 pgajdos@suse.com
- added stix-fonts and ctan-latinmodern-fonts to fonts_opt
  [bnc#944629]
* Mon Sep  7 2015 hguo@suse.com
- Introduce four recently developed Yast modules into yast2 pattern
* Fri Aug 28 2015 trcs@gmx.com
- Do not recommend lxpanel-plugin-power-manager in %%package lxde:
  dropped upstream.
  https://mail.xfce.org/pipermail/xfce-announce/2015-May/000423.html
* Fri Aug 28 2015 mimi.vx@gmail.com
- tweak haskell_platform pattern
* Thu Aug 27 2015 lnussel@suse.de
- need to allow binutils in minimal
* Tue Aug  4 2015 mimi.vx@gmail.com
- add haskell_platform pattern
* Sun Jul 19 2015 coolo@suse.com
- downgrade broken requires from leechcraft pattern
* Thu Jul 16 2015 mlin@suse.com
- drop out dhcpcd
* Wed Jul 15 2015 sor.alexei@meowr.ru
- Adapt MATE patterns to MATE 1.10+.
* Tue Jul 14 2015 arnaud@versini.eu
- Recommend OpenJDK 8 instead of OpenJDK 7.
* Mon Jun 29 2015 dimstar@opensuse.org
- Recommend NTP at least until boo#936378 is fixed and YaST is not
  trying to configure a service that's not there.
* Thu Jun 25 2015 lnussel@suse.de
- remove minimal conflict with perl, perl-Bootloader-YAML draws it in via
  perl-YAML-LibYAML
- since we have perl now anyways recommending vim is no problem
  anymore either
* Tue Jun 23 2015 dimstar@opensuse.org
- Remove kdebase4-wallpapers from the kde pattern.
* Tue Jun 23 2015 dimstar@opensuse.org
- Remove gnucash and gnucash-docs from the patterns due to space
  constraints on the DVD media.
* Mon Jun 22 2015 dimstar@opensuse.org
- Drop gnome-do and hamster-applet from gnome_utilities pattern.
* Thu Jun 11 2015 lnussel@suse.de
- tweak minimal pattern to make it smaller again:
  * omit kernel. In theory YaST will add it for real installations.
  * don't install yast anymore. Should work in theory
  * remove adjtimex, hopefully not used anymore
  * remove SuSEfirewall2, needs full perl which is huge
  * remove eject, ntfs-3g and ntp, sysfsutils not really needed
  * remove release-notes-openSUSE, pulls in perl
  * remove vim, needs full perl :-(
  * require zypper instead of software stack pattern to avoid additional recommends
  * blacklist perl, python-base and binutils to avoid recommended packages
    pulling them in
* Wed Jun  3 2015 tittiatcoke@gmail.com
- Specifically obsolete the kdebase4-workspace-devel package
  by the kde_plasma pattern to prevent issues during an upgrade
* Tue May  5 2015 simon@simotek.net
- e17 pattern is now the enlightenment pattern and installs the
  latest enlightenment release rather then e17.
- The enlightenment pattern now recommends the following useful
  applications
    Mozzila-Firefox
    desktop-data-openSUSE
    xdg-user-dir
    clementine
    vlc
    leafpad
    mupdf
* Thu Apr 30 2015 tittiatcoke@gmail.com
- Add kdepim apps to the kde patterns.
* Tue Apr 28 2015 tittiatcoke@gmail.com
- Fix some kde4 left over patterns
* Mon Apr 27 2015 tittiatcoke@gmail.com
- The right package name is breeze and not breeze5 :(
* Fri Apr 24 2015 tittiatcoke@gmail.com
- Correction of the KDE related patterns
  * Ensure the right ones are required
  * Renamed devel_frameworks to devel_kde_frameworks
* Thu Apr 23 2015 tittiatcoke@gmail.com
- Update of all KDE related patterns
  * Plasma 5 desktop is the new default
  * _kde4_ patterns renamed to _kde_
  * Dropped the obsolete patterns for plasma5
  * A new devel patterns was added to pull in the KDE Frameworks
    development packages.
* Tue Apr 21 2015 dimstar@opensuse.org
- Drop gstreamer-0_10 dependencies: this has not been maintained
  for a couple years - if packages still rely on it, they are
  required to ensure the presence on their own. No more help from
  the patterns.
* Thu Apr  9 2015 crrodriguez@opensuse.org
- Bump version number.
* Thu Apr  9 2015 crrodriguez@opensuse.org
- Do not make "bootcycle" part of any pattern, it has to
  be either dropped or fixed to work with grub2.
* Sun Mar 29 2015 trcs@gmx.com
- Add some changes in LXDE's pattern to lighten the desktop, reduce
  the dependence on other desktops and improve user experience
  * Removed duplicated Recommends: lxdm line
  * Removed Suggests: moonlight-plugin
  * Removed suggestion of libreoffice-gnome if arch is x86_64
  * Recommend Atril instead of MuPDF
  * Recommend HexChat instead of XChat
  * Recommend lxpanel-plugin-power-manager
  * Recommend Pidgin instead of Empathy
  * Recommend pk-update-icon
* Sat Mar 28 2015 gber@opensuse.org
- Replace rhythmbox with pragha as the default audio player for
  Xfce, see
  http://lists.opensuse.org/opensuse-xfce/2014-08/msg00000.html
* Sat Mar 14 2015 javier@opensuse.org
- Replace tomcat6 with tomcat
* Sat Feb  7 2015 hrvoje.senjan@gmail.com
- Add some new packages to plasma 5 pattern: konsole5, kwrite5,
  kmix5 (boo#907604), kcm-touchpad5
* Mon Jan  5 2015 lslezak@suse.cz
- Replace subversion by git in the devel_yast pattern (bnc#911635)
* Wed Dec 17 2014 dimstar@opensuse.org
- gnome-icon-theme is deprecated in favor of adwaita-icon-theme
  (which we don't need to put in a pattern, as it's a dependency to
  a complete GTK+ 3.0 installation).
* Wed Dec 17 2014 mpluskal@suse.com
- Replace microcode_ctl with ucode-amd and ucode-intel
* Tue Dec  9 2014 dimstar@opensuse.org
- Reorder patterns in the Desktop Environment group: GNOME. KDE4,
  Plasma5, XFCE, LXDE, Enlightment, MATE, Fonts, X Windows System.
* Sun Nov 30 2014 p.drouand@gmail.com
- Prefer gparted to gnome-disk-utility by default in Mate environment
* Wed Nov 26 2014 coolo@suse.com
- let's remove some devel patterns from DVD
* Sat Nov 22 2014 p.drouand@gmail.com
- Add mate-polkit to mate-basis pattern; fix boo#905679
* Sat Nov  8 2014 p.drouand@gmail.com
- Add gnome-main-menu to mate_basis pattern; fix boo#904096
* Wed Nov  5 2014 gber@opensuse.org
- prefer the YaST Qt frontend in Xfce and LXDE as well since
  libyui-gtk and libyui-gtk-pkg are unmaintained and have been
  removed
* Fri Oct 17 2014 dimstar@opensuse.org
- Add adobe-source* fonts to fonts_opt pattern (boo#901756).
* Tue Oct 14 2014 badshah400@gmail.com
- Pattern sw_management_gnome: Add back gnome-software as
  recommended package
- Pattern gnome_internet: Add NetworkManager-openconnect-gnome as
  recommended package (boo#900009).
* Mon Oct 13 2014 badshah400@gmail.com
- Pattern gnome_utilities: Add gnome-weather as recommended
  package.
* Sun Oct 12 2014 badshah400@gmail.com
- Pattern gnome_internet: Replace xchat by polari
- Pattern gnome_multimedia: Remove rhythmbox as a recommended
  application, gnome-music will now be the default music player.
* Wed Oct  8 2014 p.drouand@gmail.com
- Recommends mate-search-tool instead of tracker, as tracker
  is not integrated to Mate applications for the moment
* Tue Oct  7 2014 opensuse@cboltz.de
- add apparmor-abstractions to AppArmor pattern
* Tue Oct  7 2014 coolo@suse.com
- bump the version to 20141007
* Tue Oct  7 2014 dimstar@opensuse.org
- Remove gnome-software for now: it triggers polkit requests for
  passing the proxy between the user session and packagekitd.
* Mon Oct  6 2014 p.drouand@gmail.com
- Add Mate patterns (boo#899665)
- Add translations in create_macros
* Mon Oct  6 2014 badshah400@gmail.com
- Patterns enhanced_base and minimal_base: Drop linux32 as a
  recommended package.
* Sat Oct  4 2014 badshah400@gmail.com
- Pattern sw_management_gnome: Add gnome-software as recommends.
* Thu Oct  2 2014 badshah400@gmail.com
- Pattern gnome_yast: Replace libyui-gtk-pkg and
  yast2-control-center-gnome in gnome_yast pattern with its qt
  version; the gtk bindings have critical bugs (see bnc#897910,
  bnc#891183, bnc#852730) but seem unmaintained for now.
* Sat Sep 27 2014 trcs@gmx.com
- package lxde
  * do not recommend imaging pattern:
    + it triggers the installation of GIMP that is redundant
    because mtPaint is in the pattern, has the same goal and is
    lighter
    + it recommends the installation of the pattern imaging_opt
    which in turn suggests calibre that is a heavyweight
    application that doesn't really fit in LXDE
  * do not recommend neither lxshortcut nor lxsession-edit:
    + lxshortcut is deprecated by LibFM 1.2.0
    + lxsession-edit is now provided by LXSession
  * recommend uGet instead of transmission-gtk and do not suggests
    aria2:
    + uGet can manage both BitTorrent and Metalink protocols (in
    addition to HTTP, HTTPS and FTP)
    + aria2 is required by uGet
* Sat Sep 13 2014 dap.darkness@gmail.com
- Added new leechcraft plugins; deleted p100q (obsoleted).
* Mon Sep  8 2014 coolo@suse.com
- replace pm-profiler with tuned
* Fri Sep  5 2014 dvlaeev@suse.com
- Recommend grub2-powerpc-ieee1275 on PowerPC instead of lilo
- Recommend haveged on ppc64
* Mon Aug 25 2014 lnussel@suse.de
- add iproute2 to minimal pattern
* Thu Aug 21 2014 gber@opensuse.org
- xfce_laptop: remove xfce4-panel-plugin-brightness which has been
  merged into xfce4-panel-plugin-power-manager and is installed
  through xfce4-panel-branding-openSUSE
* Wed Aug 20 2014 trcs@gmx.com
- package lxde
  * recommend gcolor2, currently one have to open a graphics
    program just to pick a color
* Wed Aug 20 2014 msrb@suse.com
- Replace tightvnc with tigervnc as default VNC client.
  (bnc#879917)
* Sat Aug 16 2014 hrvoje.senjan@gmail.com
- Add a Plasma 5 pattern. Mostly a copy of kde4_basis, with exceptions
  where needed
- Update kde_devel pattern: no longer recommend gstreamer_0.10, but
  standard one
* Sun Aug  3 2014 trcs@gmx.com
- package lxde
  * move Leafpad from Suggests to Recommends to replace Beaver because
    Beaver is buggy, isn't translated and this is not going to change
    as it is unmaintained too
  * recommend Geany as advanced text editor, it is light enough to fit
    in LXDE
  * recommend xfce4-screenshooter, mtPaint lacks a lot of features
    in this area
* Wed Jul 23 2014 coolo@suse.com
- translate C++ comments into spec files</brownbag>
* Tue Jun 24 2014 coolo@suse.com
- move ca-certicates-mozilla into base system
- switch to a more generic version scheme
* Thu May 29 2014 hrvoje.senjan@gmail.com
- Add Qt5 devel pattern
* Thu May 15 2014 gber@opensuse.org
- gcalctool has been renamed to gnome-calculator
* Wed Apr 23 2014 hrvoje.senjan@gmail.com
- Adjust kde patterns to current status:
  * Drop no longer necessary libsoprano-devel and strigi-devel
  * Drop plasmoid-quickaccess, no longer in distro
  * Recommend baloo-file and baloo-pim
  * Swap kcm_gtk for kde-gtk-config
  * Swap koffice components to calligra counterparts
  * Swap gstreamer_0.10 backend and plugins for 1.0 versions
* Tue Apr 15 2014 coolo@suse.com
- suggests postfix *and* recommend postfix
* Mon Apr 14 2014 coolo@suse.com
- fix kernel requires for rest patterns
* Fri Mar 21 2014 coolo@suse.com
- kde4 pattern does no longer exist
* Mon Feb 24 2014 dimstar@opensuse.org
- gnome-games: recommend gnuchess instead of phalanx (bnc#864907).
* Wed Feb 19 2014 coolo@suse.com
- rename kde4 pattern kde - that is visible
* Mon Feb  3 2014 coolo@suse.com
- make visible patterns visible
* Fri Jan 31 2014 coolo@suse.com
- patterns are no longer maintained in git (well, they are for
  now but that's just till I'm certain the rpm only way works)
  fate#309385 (internal)
* Tue Jan 28 2014 coolo@suse.com
- Dinar Valeev (1):
    Don't require libspe and pdisk on ppc64le
  Ludwig Nussel (4):
    port to libsolv, part 1
    implement explain again
    remove yast2-x11 from default install again
    remove debug output
  Stephan Kulow (1):
    Merge pull request #62 from k0da/master
  Commit: 334f1f9b
* Tue Jan 14 2014 coolo@suse.com
- Stephan Kulow (1):
    switch to generic names of libyui
  Commit: 174890fa
* Fri Dec 20 2013 coolo@suse.com
- Cristian Rodríguez (1):
    prefer kmod-compat instead of module-init-tools
  Lukas Ocilka (1):
    Dropped yast2-backup and yast2-restore from YAST_BASIS (FATE#308682)
  Raymond Wooninck (2):
    Plasma-nm replaces NetworkManager-kde4
    plasma-nm replaces NetworkManager-kde4 and arora no longer exists
  Stephan Kulow (1):
    use the right texlive package (bnc#854509)
  Tomáš Chvátal (1):
    Preffer the systemd-logger (journald) instead of rsyslog. Future here we go.
  Commit: 2251e2ad
* Tue Dec 10 2013 werner@suse.de
- Package texlive is nearly empty as it includes only the required
  TeX File System, therefore require texlive-scheme-tetex as this
  package cause the installation of more than medium, but nowhere
  near full TeXLive packages (bnc#854509)
* Mon Nov  4 2013 coolo@suse.com
- Stephan Kulow (1):
    remove test updates and malloccheck
  Tomáš Chvátal (1):
    Use mlocate in patterns over findutils-locate
  Commit: 46d3ece3
* Mon Oct 28 2013 coolo@suse.com
- Stephan Kulow (1):
    libvirt should only be a suggested package to the patterns
  Commit: d6fb2bf6
* Wed Oct 16 2013 coolo@suse.com
- Commit: d94d126e
* Mon Oct  7 2013 coolo@suse.com
- Jim Fehlig (1):
    Add libvirt to KVM and Xen patterns
  Stephan Kulow (1):
    put the apparmor pattern on the cds too - default is default
  Commit: d94d126e
* Fri Sep 27 2013 coolo@suse.com
- Atri Bhattacharya (1):
    GNOME-Utilities: Replace tomboy by bijiben.
  Stephan Kulow (6):
    remove 32bit pattern (bnc#821978)
    recommend apparmor (bnc#724829)
    move udev-configure-printer to live isos (bnc#808014)
    no longer install xorg-x11 unless it's an update
  Vincent Untz (1):
    GNOME: Remove several old packages and add gnome-photos to suggests
  Commit: 4d1ad2eb
* Tue Sep 24 2013 coolo@suse.com
- update url - pointing to github
* Tue Sep 24 2013 coolo@suse.com
- Dominique Leuenberger (1):
    GNOME: Update patterns
  Juergen Weigert (1):
    Preliminary removal according to bnc#840026
  Commit: 02f72072
* Fri Sep  6 2013 coolo@suse.com
- Michael Catanzaro (7):
    gnome games: remove gbrainy
    gnome-desktop: replace Tomboy with Bijiben
    gnome-desktop: remove alternative-status-menu
    gnome-internet: drop epiphany-extensions
    gnome-multimedia: explicitly add missing gstreamer plugins
    gnome-desktop: add deja-dup
    devel c(++): move ddd to suggests
  plusky (1):
    Replace runlevel editor with service-manager
  Commit: 12199b5e
* Wed Sep  4 2013 coolo@suse.com
- Stephan Kulow (1):
    recommend desktop-branding for every desktop
  Commit: 7dc182ab
* Wed Aug 28 2013 coolo@suse.com
- Jim Fehlig (1):
    Add kvm_server pattern to DVD recommends
  Lukas Ocilka (1):
    Removed yast2-mouse from yast_basis pattern
  Stephan Kulow (2):
    remove yast2-irda from yast2
    make sure we can ignore some things for some live cds
  Commit: 6bed7f31
* Thu Aug  8 2013 coolo@suse.com
- Stephan Kulow (1):
    readd xorg-x11 to the default install (for now)
  Commit: e531eee7
* Tue Aug  6 2013 coolo@suse.com
- Stephan Kulow (1):
    also require some yast2* for kde and gnome livecd
  Atri (1):
    [REST-CD-X11] Add yast2-x11 to required packages.
  Commit: 8f1e89ab
* Fri Aug  2 2013 coolo@suse.com
- Stephan Kulow (1):
    switch to xorg-x11-essentials
  Commit: 5df80cef
* Fri Jul 26 2013 coolo@suse.com
- Christian Boltz (1):
    AppArmor pattern - don't install pam_apparmor when selecting the pattern
  Jim Fehlig (2):
    Remove xen-doc-pdf
    Add kvm_server pattern
  Stephan Kulow (3):
    replace old db-4_5 with db-devel
    trying to create a core set of installation medium
    add systemd-analysis to the enhanced base suggests
  Commit: 3a4da77c
* Sun Jun 16 2013 coolo@suse.com
- Stephan Kulow (1):
    remove limal-perl from required packages
  Commit: 9e30f6d5
* Sat Jun  8 2013 coolo@suse.com
- Jim Fehlig (1):
    Add libvirt-daemon-xen to the xen_server pattern
  Stephan Kulow (1):
    readd update-test pattern and aaa_base-malloccheck
  Commit: 27a398e5
* Wed May 15 2013 coolo@suse.com
- Commit: 029692f4
* Tue May 14 2013 coolo@suse.com
- Stephan Kulow (1):
    e17 does not recommend xfce :)
  Commit: 029692f4
* Tue May 14 2013 coolo@suse.com
- Stephan Kulow (5):
    add a e17 pattern
    do not put webyast on DVD, it's too often broken
    remove XGL patterns, compiz is pretty much dead
    add all xf86-video-* (picked by supplements)
    put scribus off the DVD, I need to save space ;(
  Commit: 6d7f28b9
* Tue May 14 2013 coolo@suse.com
- Atri Bhattacharya (2):
    Replace unmaintained epdfview by mupdf
    [LXDE-Office] Replace unmaintained epdfview by mupdf.
  Stephan Kulow (1):
    replaced libyui4 with libyui5
  Commit: e5df4756
* Mon Apr  8 2013 coolo@suse.com
- Andreas Jaeger (1):
    Add util-linux, adjtimex, time, which to BASIS
  Michael Catanzaro (4):
    gnome: remove hamster-applet
    gnome: update alternative status menu package name
    gnome: gcalctool is now gnome-calculator
    Remove xvkbd from laptop, add eekboard to tablet
  Stephan Kulow (1):
    grub2-efi is no more - replaced by e.g. grub2-i386-pc
  Commit: cd1a5224
* Sun Mar 10 2013 coolo@suse.com
- Atri (1):
    [REST-CD-X11] Add yast2-country for more keyboard layouts.
  Stephan Kulow (1):
    do not install hplip by default any longer (bnc#649280)
  Commit: e2fdb74e
* Wed Feb 27 2013 coolo@suse.com
  Do not rely on preprocessor, set __i386__ explicitly on %%ix86
* Tue Feb 26 2013 coolo@suse.com
- Stephan Kulow (2):
    suggest libyui backends for kde and gnome
    install shim by default
  Commit: b9244511
* Wed Feb 20 2013 coolo@suse.com
- Atri (1):
    Add xchat to REST-CD-X11.
  Raymond Wooninck (1):
    Include kde4-print-manager in the default KDE4-DESKTOP pattern
  Stephan Kulow (1):
    add osc to the patterns (as suggested)
  Commit: 4e9f3fa9
* Thu Feb 14 2013 coolo@suse.com
- Atri (7):
    Add useful packages & xfce pattern to REST-CD-X11.
    Add xfce pattern the right way
    Add file-roller to XFCE-MINIMAL; grsync, lftp, gnu_ddrescue to REST-CD.
    Replace Imagemagick on REST-CD-X11 by ristretto on XFCE-MINIMAL.
    Add xfce4-appfinder to XFCE-MINIMAL pattern.
    Drop XFCE-MINIMAL; XFCE-BASIS is now the minimal XFCE.
    Add ristretto to REST-CD-X11.
  Stephan Kulow (17):
    remove yast from x11 cd
    don't have X11 pattern recommend yast
    split off REST-CD a REST-CD-DESKTOP not to be put on X11 CD
    prefer lightdm over xdm
    add some yast modules for recovery
    move gtk2-branding-openSUSE away from X11 CD
    xfce requires xfce_basis
    remove xfce pattern again
    split xfce-basis into 2, one of them minimal for the rescue cd
    have yast2-control-center-gnome on rescue cd too
    make some space on the promo dvd
    need more space on promo dvd
    readd grub to the cds ;(
  Will Stephenson (1):
    Add kio_mtp
  Commit: c8c69f73
* Mon Feb 11 2013 coolo@suse.com
- Dominique Leuenberger (1):
    Replace banshee with rhythmbox... mono is in a rather odd stage... crashy... bnc#800237
  Commit: 440e44d3
* Thu Feb  7 2013 coolo@suse.com
- Stephan Kulow (2):
    remove some bits from the DVD
    do not recommend ConsoleKit
  Commit: 430571b2
* Mon Feb  4 2013 coolo@suse.com
- Stephan Kulow (2):
  no longer install grub1 by default
  install grub2-efi and syslinux by default
  Commit: aa39420d
* Fri Feb  1 2013 coolo@suse.com
- Stephan Kulow (1):
    we're back to nscd
  Commit: 37d7d67f
* Fri Jan 25 2013 coolo@suse.com
- Guido Berhoerster (1):
    Reduce dependencies on GNOME packages in XFCE
  Michal Hrusecky (1):
    Replacing MySQL with MariaDB in LAMP pattern
  Raymond Wooninck (1):
    Remove ConsoleKit-devel and add the two new kdegames development libraries
  Commit: 485bc121
* Wed Jan  9 2013 coolo@suse.com
- Ludwig Nussel (2):
    update minimal pattern
    add --no-recommends
  Commit: 06838603
* Mon Jan  7 2013 coolo@suse.com
- Guido Berhoerster (1):
    Terminal has been renamed to xfce4-terminal
  Ludwig Nussel (5):
    don't install any smtp daemon in minimal
    add glibc-locale to minimal
    remove xinetd, yp-tools and ypbind from minimal
    ncurses yast also needs ncurses packager
    prefer cracklib-dict-small in minimal
  Michael Catanzaro (1):
    Update openjdk packages
  Commit: 254debd2
* Mon Nov 12 2012 coolo@suse.com
- Stephan Kulow (1):
    ulimit is dropped
  Commit: d8b2c6b4
* Tue Nov  6 2012 coolo@suse.com
- Stephan Kulow (1):
    fix previous commit
  Commit: 982ea6db
* Tue Nov  6 2012 coolo@suse.com
- Stephan Kulow (1):
    with systemd there is no special requirement for syslog
  Commit: 93316782
* Sun Nov  4 2012 coolo@suse.com
- Stephan Kulow (1):
    switch to libpng15
  Commit: 0c70f9f1
* Sun Nov  4 2012 coolo@suse.com
- bump version
* Sun Nov  4 2012 coolo@suse.com
- Cristian Rodríguez (2):
    Move acpid to ENHANCED-BASIS-OPT
    Remove "smolt" from patterns
  Guido Berhoerster (2):
    xfce: Remove gnome-bluetooth which drags in too many GNOME dependencies
    xfce: Include xfce4-panel-plugin-weather again since it has been fixed
  Stephan Kulow (2):
    even make acpid suggested only
    small cleanups
  Commit: 0f4d50b9
* Mon Oct  1 2012 coolo@suse.com
- Stephan Kulow (1):
    yast- frontends are now libyui-*
  Commit: 0dff97c8
* Tue Sep 18 2012 coolo@suse.com
  Vincent Untz (2):
    gnome: Remove evolution-webcal, replace evolution-exchange with evo-ews
    gnome: Remove mention of telepathy-butterfly
  Commit: 8f63ad57
* Tue Sep 18 2012 coolo@suse.com
- Ludwig Nussel (4):
    minimal: add acpid
    stabilize sort by sorting by name if size is equal
    add branding-openSUSE to test case
    minimal: prefer postfix to avoid exim (bnc#778862)
  Stephan Kulow (2):
    do not require texinfo but makeinfo
    remove some packages no longer existant
  Vincent Untz (1):
    gnome, lxde: drop bug-buddy and gnome-pilot from patterns
  Commit: 89e8bf32
* Wed Jul 18 2012 coolo@suse.com
- Richard Brown (1):
    Added grub2-branding-openSUSE to ENHANCED-BASIS
- Stephan Kulow (2):
    Push most books off the DVD - just too large
    removing some things not to be on DVD
  Commit: 8d62c13c
* Thu Jul 12 2012 coolo@suse.com
- Stephan Kulow (1):
    bnc#756777 - xstroke is pretty useless
  Commit: a6fc9972
* Thu Jul 12 2012 coolo@suse.com
- Stephan Kulow (1):
    add hyper-v.rpm to install media
  Commit: 467963c9
* Wed Jul 11 2012 coolo@suse.com
- Stephan Kulow (1):
    adding a books pattern (bnc#703899)
  Commit: 062f8b4f
* Fri Jun 29 2012 coolo@suse.com
- Guido Berhoerster (2):
    add some low-level dependencies to XFCE-BASIS (bnc#768268)
    switch back to xfce4-mixer as the default mixer
  Commit: 5d7e8758
* Mon Jun 18 2012 coolo@suse.com
- Guido Berhoerster (1):
    strip down XFCE_BASIS to a bare-bones Xfce desktop with only core applications
  Marcus Meissner (1):
    added pdisk by default on powerpc
  Commit: c90d295f
* Wed Jun  6 2012 coolo@suse.com
- Stephan Kulow (1):
    fix webyast rename to end on DVD
    add provides and obsoletes to the old webyast patterns
  Commit: 8143bd44
* Mon Jun  4 2012 coolo@suse.com
- Ladislav Slezak (1):
    merged webyast-ws and webyast-ui patterns into one webyast pattern
  Commit: a51b366d
* Tue May 22 2012 coolo@suse.com
- Raymond Wooninck (1):
    Make plymouth the default for the bootsplash
  Commit: 46ac3850
* Fri May 18 2012 coolo@suse.com
  * Changed version and license
* Thu May  3 2012 coolo@suse.com
- Cristian Rodríguez (1):
    move irqbalance to ENHANCED-BASIS-OPT it serves
    no real purpose nowdays on machines without hundred of cpus.
  Guido Berhoerster (13):
    completely remove non-existent package lightdm-branding-openSUSE
    completely remove xfce4-panel-plugin-cddrive and xfce4-panel-plugin-places which are not in Factory
    add back thunar-volman-branding-openSUSE
    make xfce_basis visible again since this is not a problem with patterns
    remove gnome-bluetooth since it requires gnome-control-center (bnc#732689)
    adapt to recent packaging changes
    xfce-utils has been removed upstream
    correct the list of panel plugins
    xfce4-panel-plugin-datetime does not need to be installed by default
    added xfce4-panel-plugin-xkb since xkb layout switching is useful
    install gnome-keyring, it is enabled by default in xfce4-session
    clean up comments
    add tracker-gui, tracker is already dragged in by default
  Stephan Kulow (1):
    grub2 is needed now
  Commit: 772347e1
* Wed Apr  4 2012 coolo@suse.com
- Stephan Kulow (3):
    add more yast languages more to the CDs
    clean up requires of rpm build environment
    drop xgl/compiz from DVD
  Vincent Untz (3):
    gnome: Add nautilus-extension-seahorse and update for gnome-utils split
    gnome: Add gcr-viewer
    gnome: Add gsf-office-thumbnailer
  Commit: dd2a4380
* Tue Nov  8 2011 coolo@suse.com
- Stephan Kulow (2):
    add elilo and efibootmgr to the media (bnc#728529)
    hide xfce_basis for now (bnc#728319)
  Commit: e0f5a60b
* Fri Nov  4 2011 coolo@suse.com
- Stephan Kulow (1):
    revert bootsplash-branding change
  Commit: 76a0a769
* Fri Nov  4 2011 coolo@suse.com
- Stephan Kulow (2):
    any branding will do - openSUSE preferred
    take out update_test from default install
  Commit: c2de877b
* Wed Nov  2 2011 coolo@suse.com
- Stephan Kulow (2):
    we need to save 85mb off the dvd9
    don't install gnome-color-manager by default (bnc#698250)
  Commit: be94d305
* Mon Oct 31 2011 coolo@suse.com
- Richard Brown (1):
    gnome: Install gnome-shell-extension-alt-status-menu by default
  Stephan Kulow (1):
    suggests on promo dvd is just too much
  Commit: d595948d
* Fri Oct 28 2011 coolo@suse.com
- Stephan Kulow (2):
    make sure we require a kernel (bnc#674838)
    switch KDE updater to apper
  Commit: 9f3745a8
* Fri Oct 21 2011 coolo@suse.com
- Stephan Kulow (1):
    remove xstroke from laptop pattern, it's fine in tabletpc only
  Vincent Untz (1):
    gnome: Move simple-scan from GNOME-IMAGE-OPT to GNOME-IMAGE
  Commit: d4b44eba
* Fri Oct 21 2011 coolo@suse.com
- Ludwig Nussel (3):
    better warning if pattern lacks 'sel'
    minimal: suppress python and yast2-branding
    make test runner more generic
  Commit: 98a3c6ca
* Tue Oct 18 2011 coolo@suse.com
- Stephan Kulow (2):
    more renames
    readd ppds (bnc#652292)
  Commit: f6d66dda
* Fri Oct 14 2011 coolo@suse.com
- Stephan Kulow (5):
    remove rpmlib requires, those are really odd
    remove packages dropped for 12.1
    remove more packages not existant (anymore)
    remove some more stuff not present in factory
    follow renames and remerges
  Commit: e8af0ff0
* Fri Oct 14 2011 coolo@suse.com
- fix specfile generation
* Fri Oct 14 2011 coolo@suse.com
- Guido Berhoerster (23):
    drop opensuse-codecs-installer which is gone from Factory
    remove non-existent xfce4-branding-openSUSE and replace it with the real branding packages
    add pk-update-icon which replaces gpk-update-icon
    explicitly depend on system-config-printer-applet
    replace xarchiver with file-roller, xarchiver is dead and squeeze is not ready yet
    add back xfce4-panel-plugin-mixer as a possible alternative to gmixer
    replace xfburn with brasero, xfburn is unmaintained upstream and has numerous bugs
    add with rhythmbox a more sophisticated media player and sound-juicer to allow CD ripping
    add with simple-scan a more simple and usable alternative to xsane
    added a couple of applications for feature parity with the default installs of other desktops
    replace remote_desktop with remmina
    add some games for Xfce
    ease debugging by adding gdb
    no need for explicit xorg-x11 any more since we use lightdm
    add gnome-bluetooth to desktop pattern as well, bluetooth is also useful on desktop systems
    add alacarte, since Xfce 4.8 menus can be edited by it
    replace thunar-thumbnailers with tumbler
    neither the xfce not the murine gtk2 engine are needed since we switched from Sonar to Adwaita
    remove non existent packages
    remove xfce4-dict which is already recommended
    split off xfce_basis pattern in order to allow for more minimal installs
    added shotwell for photo management
    add xfce4-panel-plugin-datetime so it can be used by branding
  Ludwig Nussel (5):
    jarnal doesn't exist since 11.3
    conflict zypper-log in minimal due to python
    add klogd to BASIS
    recommend yast2-ntp-client in yast install pattern (bnc#723018)
    add script that works with perl-satsolver
  Stephan Kulow (2):
    add tons of packages useful when building KDE
    take out some of the largest packages
  Vincent Untz (1):
    gnome: Add gnome-control-center-branding-openSUSE
  Commit: f6407989
* Wed Oct 12 2011 coolo@suse.com
- Stephan Kulow (1):
    switch /sbin/init to systemd (bnc#723041)
  Commit: 7040c30e
* Thu Oct  6 2011 coolo@suse.com
- Stephan Kulow (1):
    flash-player seems to be 64bit now too
  Vincent Untz (4):
    gnome: Add gnome-documents to GNOME-DESKTOP
    gnome: Update for new name of package with dynamic background
    gnome: Pretty sure we don't need cups-backends by default
    gnome: Install gnome-color-manager, drop pulseaudio-esound-compat
  Commit: bc85b9a8
* Thu Sep 29 2011 coolo@suse.com
- Guido Berhoerster (1):
    switch from gdm to lightdm
  Commit: cb7af52a
* Tue Sep 20 2011 coolo@suse.com
- Andrea Florio (1):
    replace gpicview with viewnior
  Commit: 7cac039c
* Wed Sep 14 2011 coolo@suse.com
  Stephan Kulow (3):
    try promo dvd with suggests
    make systemd default on live cds
    do not install xgl on DVD either by default
  Vincent Untz (2):
    gnome: Rework some GNOME patterns
    gnome livecd: Do not install xgl/gnome_xgl patterns
* Mon Sep  5 2011 coolo@suse.com
- Ludwig Nussel (3):
    remomd converter
    better error message
    add yast2 added packages and locale=en
  Stephan Kulow (5):
    libatm1 is the new name (bnc#695303)
    GNOME3DONE define is old
    Ignore files
    put elilo on DVD
    put elilo and grub2 on DVD only so far
* Thu Sep  1 2011 coolo@suse.com
- Stephan Kulow (2):
    add libQtWebKit-devel to qt pattern (bnc#680081)
    adding siga to dvd (bnc#697047)
* Thu Sep  1 2011 coolo@suse.com
- Stephan Kulow (5):
    recommending minimal yast2 installation workflow for mininmal
    adding minimal_base-conflicts to the DVD patterns
    next round of minimal requires
    python-base is required through systemd now
    conflict with more supplements
* Mon Aug 29 2011 coolo@novell.com
  Ludwig Nussel (1):
    add zypper to minimal (bnc#713317)
  Stephan Kulow (1):
    add kiwi-media-requires for ms to track what should be on DVD
* Wed Aug 24 2011 coolo@novell.com
- Andrea Florio (1):
    opensuse-codecs-installer is obsolete
  Sascha Peilicke (1):
    Don't require/recommend AppArmor.
  Stephan Kulow (1):
    remove the default pattern, it has no meaning
* Tue Jul 26 2011 coolo@novell.com
- Andrea Florio (1):
    added simple-scan
  Stephan Kulow (1):
    readd update_test
  Vincent Untz (1):
    gnome: Add libgnomesu Recommends
* Tue Jul 12 2011 coolo@novell.com
- Stephan Kulow (1):
    recommend systemd for easier testing
  Vincent Untz (3):
    Update GNOME patterns for GNOME 3
    Do not require gnome-session-*-session, but recommend them
    gnome: Move tasque from Recommends to Suggests
* Tue Jun 28 2011 coolo@novell.com
- Stephan Kulow (4):
    add snapper to the yast patterns for better btfs support
    bootloaders are not strictly required in today's virtual world
    compiz is back
    webyast fits also on dvd9
* Fri Jun 17 2011 coolo@novell.com
  Stephan Kulow (1):
    fix webyast patterns and put them on dvd
* Wed Jun 15 2011 coolo@novell.com
  Stephan Kulow (2):
    drop ivman
    fix webyast sel files
* Wed Jun 15 2011 coolo@novell.com
- set version to 12.1
* Wed Jun 15 2011 coolo@novell.com
  Ludwig Nussel (2):
    add vim to minimal_base
    create a separate minimal_base-conflicts pattern
  Stefan Schubert (1):
    added webyast
  Stephan Kulow (4):
    libstorage is gone
    promo dvd can live without xgl
* Wed May 25 2011 coolo@novell.com
  16dc760 added missing YaST GTK GUI (bnc#688084)
  53df32b switch back to totem now that parole has dropped its browser plugin
  ab01071 replace mousepad with leafpad since the former will be dropped from Factory
  0e4f41e add perl-doc for devel-perl (bnc#688877)
  568ae31 take out problematic GNOME2 packages to get something rolling
  616567e remove compiz too for GNOME3DONE
* Wed Mar 30 2011 coolo@novell.com
  7cacb80 phonon-backend-xine is unused
  e9fc6d7 add texlive to technical writing (bnc#673657)
  d414e22 fix syntax
  b6cc0c4 we need both frontends
  3fdaf85 add sssd to the media (bnc#679439)
  288aad0 aria2 is not so common anymore
  ef23220 replace ksmolt with smolt-gui
  c295d0a licenses are no more
* Fri Feb 25 2011 coolo@novell.com
  394ae9c revert some empty files
  ce02fc4 add dependencies of skype
  b285e13 move skype deps out of default install
  0286502 add depencies of acroread to the DVD
  7cacb80 phonon-backend-xine is unused
* Mon Feb 14 2011 coolo@novell.com
  4973860 unrar is unfree now
  4f8c55d throw off some patterns from promo
  1a68b1f remove things from the biarch dvd
  6429034 take out update_test from default install
  7c526e2 take out empty files
* Mon Feb  7 2011 coolo@novell.com
- bump version
* Mon Feb  7 2011 coolo@novell.com
  ee7c122 move LanguageTool out of default install
* Mon Feb  7 2011 coolo@novell.com
  8d5e729 rest_dvd can't require two conflicting patterns
  38e535a gfxboot should be installed in !minimal
  0e2b4ef leave the full cracklib dict in minimal
* Tue Feb  1 2011 coolo@novell.com
  20e6ffa Change gtk theme to oxygen-gtk
  42c01f3 Recommend kdevelop4 for IDE pattern, suggest PHP
  4b543b4 Add Krita to Imaging pattern
  75516ab Add Rekonq to recommends for KDE Internet pattern
* Fri Jan 28 2011 coolo@novell.com
  659d680 remove xfce4-volstatus which will be dropped from Factory
  c74c68e hal-devel is no longer part of KDE
  afe82ea testing a minimal pattern
  d2c0b61 rename to minimal_base to avoid conflict with sles
  62592b4 conflict some bad recommends and supplements
  9207be2 a couple more conflicts for minimal
  6a04259 fix the name of the pattern package
  a63758d also conflict with cups-client
  dee5016 remove 2 packages of the top 10 installs
* Mon Jan 17 2011 coolo@novell.com
  8120148 do not recommend too much from base - base is the minimal
* Mon Jan 17 2011 coolo@novell.com
  bfa19cc follow virtualbox rename
  d4c5350 ksame is gone
* Tue Jan 11 2011 coolo@novell.com
  22d4883 removed corefonts from default install (bnc#655760)
* Mon Jan 10 2011 coolo@novell.com
  1a48484 remove no longer existant packages
  de6e0e7 cups-drivers is no more (bnc#652292)
  5ee174c changes from XFCE team
* Mon Dec 13 2010 coolo@novell.com
  220695b add Xfce patterns modifications by gber
* Tue Nov 23 2010 coolo@novell.com
  7c56627 disarm kde4_pure pattern
* Fri Nov 19 2010 coolo@novell.com
  75fd438 change to kpackagekit
  df7297f Use the NetworkManager plasmoid now
  fe73adb Install pulseaudio again by default
  b388743 ksshaskpass is broken and unmaintained
  c29ebd2 Kwebkitpart is a central part of 4.6
  f439f79 Correct Nepomuk requirements and move to Recommended
  4a84f97 BlueDevil replaces KBlueTooth
  a92ffb7 add haveged to optional base packages
  f70d1a1 make it possible to switch to syslog-ng
* Wed Nov  3 2010 coolo@novell.com
  f2a57ea Revert "remove update_test for release"
* Wed Nov  3 2010 coolo@novell.com
  e86af77 GNOME: Remove libraries from GNOME-BASIS
  cc3d493 GNOME: Add/remove some packages, and add many suggestions
  81cb448 BASIS: replace hal Recommends with pm-utils
  8549265 switch to libreoffice
  b6f2cf0 fix package names
  4f6573e tracked in bugzilla
  ee5d98f use cronie by default
* Tue Sep 28 2010 coolo@novell.com
  376de2b use empathy instead of pidgin
  6fb5b3b preload is not strictly required
  b9cc276 moblin pattern is gone as most packages of it are gone too
  e2068ef remove packages gone from the distribution
  3f5cdf7 Remove some obviously unneeded parts in GNOME patterns
  2bc03b8 Update GNOME-IDE to include devhelp and glade3
  19c6c60 Reorder GNOME-BASIS so that low-level bits are easily findable
  c21ed96 Remove yast bits from GNOME-BASIS
  a3141f8 Make packages in GNOME-Games recommended instead of required
  e6a80e0 Move packages around all the GNOME-* patterns
* Mon Aug 30 2010 coolo@novell.com
  02ade03 add some packages
  4ba8669 exim has no maintainer, not good to suggest
  7481311 adding quota-nfs to DVD
* Wed Jun 30 2010 coolo@novell.com
  be2a41e remove moblin-app-installer as the repos dont exist
* Tue Jun 29 2010 coolo@novell.com
  01877c3 add a dependency free GPG gui
  bce5ab3 we need hal's init script for cpufreq to work (bnc#612131)
* Mon Jun 21 2010 coolo@novell.com
  86b748c Do not recommend yast2-qt from GNOME-YaST
  4e0b698 added a touchpad configuration tool
  1c8c7f7 remove packages not installable
  67a91dc more cleanup
  6578467 replace capabilities with real package names
  3c7d755 one more provides
* Thu Jun 17 2010 coolo@novell.com
  c4fd58f complete the switch to yast2-gtk
  e4ee1f1 remove update_test for release
* Wed Jun  2 2010 coolo@novell.com
  a6a23b4 yast2-repair is gone
* Sun May 30 2010 coolo@novell.com
  bd0fb67 removed stuff vuntz thinks are obsolete
  4e20568 add _opt patterns to promo dvd
* Thu May 27 2010 coolo@novell.com
  f9e4ee6 revert fix for bnc#538897
  1f298ac Use tracker instead of beagle
* Thu May 27 2010 coolo@novell.com
  1136323 added a printer config tool
  88cd8e9 do not use PolicyKit anymore
  672566f remove non-building apps from selection
  e81c9ef too late to make it visible
  50d61f0 fixed order
  0f21c40 add libvdpau for bnc#605888
  9d65b15 small cleanup
  838e7a2 Drop outdated HAL from (enahnced) base system.
* Tue May 18 2010 coolo@novell.com
- remove dvd9 rest pattern
* Tue May 18 2010 coolo@novell.com
  b232af0 compcache is disabled
  900dc8f full up the promo dvd
  ec0c5b6 adding dvd9 specific pattern, only dummy "I want it all" for now
  1be5421 add things to the dvd9 that are normally only online
  0ff8f18 some more packages for dvd9
  2a5dfd5 added lxcc and improved lxde user experience
  517a312 added video player to LXDE
  402c6c2 use brasero instead of xfburn
  8e872de use GTK UI for YaST
  fbea081 use network manager by default
  25badf1 adapt to dropped yast modules
  721ffab back to sysvinit (http://lists.opensuse.org/opensuse-factory/2010-05/msg00168.html)
  97976e9 remove tmpwatch again
  a9a6ad9 remove all of Policykit but the -kde and -gnome frontends
  cca5a50 replace okteta with synaptics
  cba9a5f added moonlight-plugin
  61a351f Use empathy instead of pidgin by default for GNOME
* Wed Apr 14 2010 coolo@novell.com
  fc508de recommends office-lxde pattern
  7cf97b9 Default office patter require OO.o  Recommends lxde-office pattern instead
  0ad93d6 Revert "Switch to the new at-spi2 stack by default"
  e4a5bc8 add open-vm-tools (bnc#591085)
  984591e replace gnome-games (bnc#594503)
  4bbb001 add LanguageTool into office pattern (for dvd)
  9d6737e add tmpwatch to default (bnc#594778)
* Thu Apr  1 2010 coolo@novell.com
  4c3c16a moved claws to main LXDE pattern; removed polkit-gnome from pattern
  78a70a5 recommend the openSUSE branding for gnome
* Mon Mar 22 2010 coolo@novell.com
  19bce1a replace sysvinit with sysvinit-tools
* Mon Mar 22 2010 coolo@novell.com
  265bbb6 let's try with upstart for M4
  cf09420 add virtualbox-ose-guest-tools to liveCD
* Mon Mar  1 2010 coolo@novell.com
  87e55e0 add gnome utilities to the live cd
  53de3f2 replacing cscope with ctags in kernel development (bnc#582415)
  eb621b7 adding 32bit gtk to the DVD
* Sun Feb 14 2010 coolo@novell.com
  5bb8c74 improved lxde patterns, created lxde_laptop patter to provide some laptop utilities
  1c1b519 added lxde_laptop patter into dvd (no additional space required)
  0118b3f move sax2-gui from live cd to save space
* Wed Feb 10 2010 coolo@novell.com
- save the original spec file, so that autobuild does not
  remove the important comments ;(
* Mon Feb  8 2010 coolo@novell.com
  505b6b3 moving knode, kcron and ksystemlog out of the default install
  1987df9 add gnome-disk-utility (bnc#554954)
* Thu Jan 28 2010 coolo@novell.com
  26e7f97 put lxde on dvd - let's see how large it is
* Mon Jan 25 2010 coolo@novell.com
  93eff17 added lxde patterns
  1a1ca32 Switch to the new at-spi2 stack by default
* Thu Jan 21 2010 coolo@novell.com
  b9a7c66 add susehelp to the kde basics (bnc#541820)
  fdefc61 do not require but recommend opensuse branding (bnc#564730)
* Wed Jan 20 2010 coolo@novell.com
- update version to 11.3
  34c4417 move samba out of livecd patterns
  e56c82c adding meanwhile plugin (bnc#549711)
  b537a95 add xorg-x11-driver-video-unichrome to X11 suggestion list
  588d38c take out preload for now
  6346418 This reverts commit fb883332c54fbf0e5fc805c0cc779524221c1dda, readding update_test
* Fri Oct 30 2009 coolo@novell.com
  1383d75 no longer recommend xgl pattern for kde - it requires gnome (bnc#550875)
  34c4417 move samba out of livecd patterns
* Fri Oct 23 2009 coolo@novell.com
  fb88333 take down update_tests
  93f469e fix up ipw-firmware
  27aeba0 add kiwi-templates
  e80f252 do not require a flavor (bnc#547900)
  1065957 recommend kernel-syms for kernel development (bnc#548933)
* Tue Oct 13 2009 coolo@novell.com
  989b341 ggreeter is gone (bnc#543759)
  76f825b add samba to the default installation
  7468384 add alacarte to the livecd default too
  65f7a88 yast2-gtk-pkg is no more
* Fri Oct  2 2009 coolo@novell.com
  5c7650e require the patterns packages
  9dc8da1 games_opt is not needed
* Thu Oct  1 2009 coolo@novell.com
  2e37890 bnc#542936 - add webpin yast module
  84eae4d add firefox kde4 integration
  c1cae84 ufraw-gimp was renamed to gimp-ufraw
  b3c3106 cleanup dead and renamed packages
  4b7f5b9 trying with everything required
  63d6898 libusb-devel is now compat-devel
  c2e3b20 removed more dropped packages
  b62dcf9 another round of dropped packages
  16a84a3 done with dropped packages
* Mon Sep 28 2009 coolo@novell.com
  5cb7c95... add gwibber to DVD
  d7f6916... change from lsb to lsb-release by default (bnc#537378)
  e1cf9f1... adding smolt
  9a0bd24... adding btrfsprogs
  356ac46... adding gnome-packagekit to XFCE
  cc964c8... add lsof to live cd
  3da4dae... remove beagle-firefox from GNOME default (bnc#533783)
  846e43a... merge KDE4-BASIS-OPT back into KDE4-BASIS
  d6c64cb... qlogic-firmware is now kernel-firmware
  d96f273... move vpn plugins to the default install (bnc#533580)
  c23700e... leave out file conflicts with kernel-firmware for now
  cdf4380... try texlive on x86_64 again
  102879c... adding polkit-gnome (bnc#538897)
* Mon Sep  7 2009 coolo@novell.com
  d6de7da... xdm is not provided, hardcode xorg-x11
  3d4a20a... add droid fonts to default install
  d7bdcea... add specific icon themes for ooo
  1af1874... fix minimal autoyast installation
  69e0d1b... trying to install the update test by default
* Fri Aug 28 2009 coolo@novell.com
  05f6fb8... merge kde4_office_opt back into kde4_office only suggest the kde3 quickstarter
  87a6457... put the update_test on cds too (bnc#533154)
  36479d4... pull in kdebase4-openSUSE-pulseaudio-conflict
  4ba63a6... take out the pluseaudio block package, may exist better solution
  6699349... live without banshee for the moment
  d939c19... put more vpn on the dvd (bnc#533580)
  c724b4c... cups-autoconf should be replaced by udev-configure-printer (bnc#532838#10)
  b9702b4... xdm for xfce
* Thu Aug 20 2009 coolo@novell.com
  a99362e... patch from Beineri to put more kde apps into default selection
  20064f3... 3 PA tools no longer needed (bnc#529059)
  3c0a04d... monsoon is gone, transmission is default (bnc#530416)
  0d46f55... try compcache on the live cd
  c683570... harmonize the dvd default install with the live cd (patch by Binner)
  ec139ac... tex is too large for x86_64 (at least for now)
  affbf98... list polkit explicitly
* Tue Aug 18 2009 coolo@novell.com
  d4f0912... ksmolt on kde4
  7215e19... move exiftool out of default installation (bnc#529052)
  0fb8e24... move yast2-qt off the gnome live cd (bnc#529046)
  92ae5c0... NM should have much better support for umts now without using umtsmon (bnc#529050)
  06f971f... sumf is not maintained and not ported to qt4
  8414914... extra kernel is no more
  1e08776... sax is no longer required to have a working X
  670269c... put kinternet on the DVD for those that need it (bnc#527549)
  06b0f5a... no need to list kernel-*-base explicitly - especially when it will go away
  a91ceb7... remove some libraries
  4161f12... switch to xine backend for phonon
  96c9f5a... take out pulseaudio for testing
  dc8ff1e... move gstreamer plugins to gnome now that KDE uses xine backend
  4f16b18... recommend esound-daemon for KDE
  d21633f... if only kde4 is selected, it conflicts with pulseaudio
  f89c698... do not put laptop pattern on live cds, but take the network
* Tue Aug  4 2009 coolo@novell.com
  1be4e81... add pavucontrol for bnc#522801
  54f3fbb... removing gsynaptics for bnc#523500
  70bc3a4... make kde3 depdency suggested not required
  b95d000... put xdg-users-dir in default selection
  949873b... drop -pae and take -desktop on all archs
  48380d2... trying something:  switch nscd to unscd  switch syslog-ng to rsyslog
  8881eca... bug509829 - include xdg-user-dirs-gtk in GNOME
  06beee8... add kde internet stuff
  e7ff730... on 64bit require kernel-desktop
  7ecc5b9... only kernel-desktop on x86_64
  de09c63... patch from KDE team (bug#526987)
  2da8d35... take out xen_server for now and hide koffice2
  13bb9fd... kdebase3-devel is not needed anymore
* Tue Jul 21 2009 coolo@novell.com
  593cff4... add mc
  9eb74c6... bootchart is not interesting for most
  a7c9ecb... moving krecord to suggested and going from pinentry-qt ot -qt4
  2269c3a... replacing dropped kde3 apps (bnc#513833)
  d03eb1e... adding qt-creator
  3ddaf3b... moving command-not-found to live cd, fixing krecord
  a4dd766... adding yakuake
  3e8c4e5... bnc#521180
  e3d1df0... don't put libqt4 dependencies into enhanced-basis
  c5f2520... move X11 dependencies out of enhanced-basis
  98d34b9... suseRegister isn't required for suse
  adeeb40... we don't need no registration
* Tue May 26 2009 coolo@novell.com
  7329423... adding video drivers and server
  4009508... not that too many care for s390 opensuse, but it should stay without x11
  3f1da14... give it a requires too
  3573c91... fixing patterns
  57b4822... the package is back
  e541659... give me display
  3df2261... push changes from vuntz
  2c10c7f... ignore amarok for now
  522f40b... replace pae with legacy on the DVD
  0229227... xfce is still broken
  2587e91... readd it
  fe5c487... the patterns conflict, so don't require them
  e977ab1... Revert "- replace pae with legacy on the DVD"
  6c26bfa... readd amarok
* Tue May  5 2009 coolo@suse.de
- follow package names
* Wed Apr 22 2009 coolo@suse.de
- remove manuals pattern
* Tue Apr 21 2009 coolo@suse.de
- fix xfce pattern and clean up some left overs
* Tue Apr 21 2009 coolo@suse.de
- fix name of digikam
* Wed Apr 15 2009 coolo@suse.de
- update XFCE pattern (bnc#493549)
* Thu Apr  9 2009 coolo@suse.de
- remove all KDE3 patterns
- clean up some package names (follow renames)
* Tue Mar 31 2009 coolo@suse.de
  ca0d789... do not install ufraw by default (bnc#298969)
  86242bb... use kde4-konversation
  7e45fe1... hide kde3
  10a7a3b... go for kde4
  b90facf... adding wireless helpers
  2fb5e5f... no beagle on kde4
  bd2b801... leave out more of it for the time being
  47490c5... need these
  dc18426... trying to get new livecds
  1e33bbd... back to real life
  9d63d25... readd office
* Thu Feb  5 2009 coolo@suse.de
- adding python-devel to DEVEL-Python (bnc#456496)
- add more packages to devel-kde to allow building kde from svn
- require gdm for xfce
- checking who complains if zip is no longer installed
- daring something
  * drop compiz from livecd-kdee4
  * replace amarok with kde4-amarok
  * replace digikam with kde4-digikam
  * block OpenOffice-kde
  * adding umtsmon
- some ps3 moves
* Tue Dec  2 2008 coolo@suse.de
- office didn't make it for ppc (bnc#449711)
* Tue Dec  2 2008 coolo@suse.de
- fix typo
* Tue Dec  2 2008 coolo@suse.de
- require more of KDE3 explicitly
* Mon Dec  1 2008 coolo@suse.de
- do not recommend boost-doc - boost-devel eats for two
* Sun Nov 30 2008 coolo@suse.de
- require NM-kde to make the solver pick the "right" NM-client
* Sat Nov 29 2008 coolo@suse.de
- several workarounds for generic provides messing standard
  installs (bnc#450161)
* Fri Nov 28 2008 coolo@suse.de
- put the pullin-flash and pullin-mp3 also on livecd
- put the pullin-mswebfnt on all media
* Fri Nov 28 2008 coolo@suse.de
- vym is kdissert for KDE4 (says Uwe)
  - bnc#446088 - openjdk-plugin (and tons of others) not installed
  with kde 4.1
  - use openjdk-plugin explicitly and not generic "java-plugin"
  - fix syntax in MULTIMEDIA
  - make amarok1 default again (bnc#449422)
  - readding games to x86_64 cds (bnc#449832)
  - disable fbset (bnc#304995)
* Mon Nov 24 2008 coolo@suse.de
- add avahi explicitly to all desktops (bnc#446017)
* Mon Nov 24 2008 coolo@suse.de
- libusb-compat-devel -> libusb-devel (bnc#447572)
- kerneloops not installed by default for now
* Thu Nov 20 2008 coolo@suse.de
- back to NM-kde3
- move biosdevname out of the default install
* Mon Nov 10 2008 coolo@suse.de
- give NM-kde4 another beta
* Mon Nov 10 2008 coolo@suse.de
- do not autorequire the devel-tcl pattern
* Sun Nov  9 2008 coolo@suse.de
- split out the patterns only available on ftp (bnc#432508)
* Sun Nov  9 2008 coolo@suse.de
- require something in tabletpc (bnc#437162)
* Sun Nov  9 2008 coolo@suse.de
- moving some packages out of minimal+x
* Sun Nov  9 2008 coolo@suse.de
- fix build
* Thu Nov  6 2008 coolo@suse.de
- several packages added for bugs
* Sun Nov  2 2008 coolo@suse.de
- split out non_oss pattern as we have a new setup now
* Sun Nov  2 2008 coolo@suse.de
- sort out pam (again)
- adding Policykit-kde to kde3 desktop (bnc#440829)
* Sun Nov  2 2008 coolo@suse.de
- install liberation-fonts
* Tue Oct 28 2008 coolo@suse.de
- fixed long standing bug 388570 - make kerneloops default
* Tue Oct 28 2008 coolo@suse.de
- move java-plugin out of non-oss
- install the pullin packages with non-oss
- make packages required in non-oss-java
* Tue Oct 28 2008 coolo@suse.de
- hopefully sort out the pam-xx packages (only for DVD)
* Tue Oct 28 2008 coolo@suse.de
- remove yast2-wagon
* Mon Oct 27 2008 coolo@suse.de
- install smolt by default for the desktops
* Thu Oct 16 2008 cthiel@suse.de
- back to NetworkManager-kde for KDE4-BASIS
* Thu Oct 16 2008 cthiel@suse.de
- drop gstreamer-0_10-pulse from patterns (bcn#435943)
* Wed Oct 15 2008 cthiel@suse.de
- cleanup for Beta3
- switch from kpowesave to powerdevil on KDE4 (bnc#434753)
- added yast2-wagon to YAST_BASIS
- suggest sblim-sfcb and cim-schema in YAST_BASIS
- created TablePC pattern
- make sure to not have required packages in patterns, that are available
  online-only: DEVEL-CELL, DEVEL-Rails, DEVEL-Ruby, DEVEL-WEB, DEVEL-YaST,
  LAMP and VOIP (bnc#431865, bnc#432508, bnc#427691)
- added createrepo to REST-DVD (bnc#432164)
- added accerciser to DEVEL-GNOME
* Thu Oct  9 2008 cthiel@suse.de
- added sbl and espeak to REST-CD to make LiveCD more accessible
  (bnc#391327)
- ttf-arphic-uming to REST-DVD (bnc#431280)
* Thu Oct  9 2008 cthiel@suse.de
- moving lsb from suggested to recommended in X11-OPT (bnc#423075)
* Thu Oct  9 2008 cthiel@suse.de
- switch to NetworkManager-kde4 in KDE4-BASIS
- cleanup XGL/GNOME-XGL patterns
- added rsync and smartmontools to LiveCD (bnc#419201)
* Mon Oct  6 2008 cthiel@suse.de
- add some cyrus-sasl-* plugins to ENHANCED-BASIS (bnc#430895)
* Mon Oct  6 2008 cthiel@suse.de
- improved KDE patterns (bnc#432365)
- remove unwanted KDE4 apps from "KDE3 Desktop Environment" (bnc#432368)
* Tue Sep 30 2008 cthiel@suse.de
- pre Beta2 cleanup
- added split kernel
- added PolicyKit and polkit-default-privs to BASIS
* Mon Sep 29 2008 cthiel@suse.de
- KDE pattern update from Stephan Binner (bnc#430500)
* Fri Sep 26 2008 cthiel@suse.de
- added xorg-x11-driver-video-radeonhd
* Fri Sep 26 2008 cthiel@suse.de
- added polkit-default-privs to GNOME-BASIS and KDE4-BASIS (bnc#430161)
* Fri Sep 26 2008 cthiel@suse.de
- added atl2-kmp-* to REST-DVD (bnc#420039)
* Fri Sep 26 2008 cthiel@suse.de
- added skanlite to KDE4-IMAGE-OPT (bnc#422555)
* Fri Sep 26 2008 cthiel@suse.de
- added xorg-x11-xauth to X11
* Fri Sep 26 2008 cthiel@suse.de
- added iwl5000-ucode (bnc#426500)
- make sure to use yast2-qt for all installations
* Fri Sep 26 2008 cthiel@suse.de
- replace gnome-cups-manager with system-config-printer in GNOME-BASIS
* Tue Sep 23 2008 cthiel@suse.de
- rpcbind moved from ENHANCED-BASIS to BASIS, to enable minimal NFS
  installation
- pulseaudio added to KDE4-BASIS and KDE3-BASIS
- removed openSUSE-release-dvd from BASIS, only openSUSE-release has to be
  in the patterns
* Thu Sep 18 2008 cthiel@suse.de
- fix typo in BASIS
* Thu Sep 18 2008 cthiel@suse.de
- openSUSE-release got renamed again.
* Thu Sep 18 2008 cthiel@suse.de
- switch to openSUSE-build-key
* Wed Sep 17 2008 cthiel@suse.de
- FATE #304494: System Instrumentation (CIM Enablement), adding
  smis-providers to REST-DVD
* Wed Sep 17 2008 aj@suse.de
- Remove dropped package fast-user-switch-applet.
* Tue Sep 16 2008 cthiel@suse.de
- adding scout and command-not-found to ENHANCED-BASIS (bnc#424707)
- adding XFCE-Office pattern, to always install OpenOffice-gnome in case
  XFCE and OFFICE are selected (bnc#254454)
* Tue Sep 16 2008 cthiel@suse.de
- added simple-ccsm-kde to KDE4-XGL and KDE3-XGL (bnc#426316)
- replace kdebluetooth with kdebluetooth4 in KDE4-Utilities (bnc#422601)
- replace powersave with pm-profiler in ENHANCED-BASIS (bnc#417998)
- move to kde4-amarok on KDE4-Multimedia (bnc#421870)
* Fri Sep 12 2008 cthiel@suse.de
- remove dropped packages: lineak_kde, perl-Spreadsheet-WriteExcel,
  perl-XML-XQL, perl-XML-Generator, python-curl, gspcav-kmp-default,
  gspcav-kmp-pae, resapplet
- made various virtual provides implicit
- take care of package renames
- added man-pages-posix to enhanced_base
- replace portmap with rpcbind
- remove gail-devel, provided by gtk2-devel from DEVEL-GNOME
- remove dropped kyum from KDE3-DESKTOP
* Wed Sep 10 2008 aj@suse.de
- Remove dropped packages resmgr, hal-resmgr and yast2-support.
* Mon Sep  1 2008 aj@suse.de
- Remove agfa-fonts.
* Wed Aug 20 2008 cthiel@suse.de
- add back technical_writing [bnc#418571]
- add desktop-data-openSUSE-extra-gnome to GNOME-BASIS-OPT [bnc#394406]
* Mon Aug  4 2008 cthiel@suse.de
- remove dropped package gail-doc from DEVEL-GNOME
- remove unknown package itk-devel from DEVEL-Tcl
- remove unknown packages java-1_6_0-openjdk-alsa and
  java-1_6_0-openjdk-jdbc from NON-OSS-JAVA
- remove dropped package yast2-storage-evms from YAST_BASIS
- remove unknown package xfce4-dict from XFCE
- remove dropped package php5-ncurses from DEVEL-Web
- remove dropped packages uvcvideo-KMP-* from REST-DVD
- remove packages myldapklient, klipsi and kpsion from KDE3-DESKTOP
- remove dropped package kde4-kmilo from KDE4-LAPTOP
- remove packages kde4-kmobiletools and kde4-korn from KDE4-BASIS
- remove packages kde4-kworldclock and kde4-kpilot from KDE4-Utilities
* Mon Aug  4 2008 cthiel@suse.de
- XFCE pattern fixes (bnc#404447)
- take out the games from the kde x86_64 live
- moving some koffice and NON-OSS stuff to the online repo
- moving some TeX packages to the online repo
- removing duplicate gconf2-branding-openSUSE from GNOME-BASIS (bnc#412442)
- removing xgl from XGL pattern
- switch from sun to openjdk
- removing quite some patterns from the DVD for now
- adding laptop-mode-tools to LAPTOP (fate#303035)
* Fri Aug  1 2008 coolo@suse.de
- install biosdevname by default
* Mon Jun 30 2008 aj@suse.de
- Fix last change to c/c++ devel pattern.
* Mon Jun 30 2008 aj@suse.de
- Add xfce packages (bnc#404447)
* Mon Jun 30 2008 aj@suse.de
- Add dejagnu and expect to c/c++ devel pattern (bnc#403368).
* Thu Jun 26 2008 coolo@suse.de
- share mechanism with sled
- adding biosdevname
* Mon Jun 23 2008 coolo@suse.de
- drop unsupport pattern packages
* Tue Jun 10 2008 coolo@suse.de
- banshee-1 plugins are free of the mono-devel dep again
* Sun Jun  8 2008 coolo@suse.de
- requiring acroread on ppc is not a good idea, reverting
  the last change for non-oss pattern
* Thu Jun  5 2008 coolo@suse.de
- always require something in patterns, otherwise they get
  autoselected and this is suprising (bnc#392989)
* Wed Jun  4 2008 coolo@suse.de
- put alsa firmware on live cd (bnc#396109)
* Wed Jun  4 2008 coolo@suse.de
- make promo dvd an own pattern package
* Wed Jun  4 2008 coolo@suse.de
- don't require thinkreader support
* Tue Jun  3 2008 coolo@suse.de
- do not put update-test on DVD
* Wed May 28 2008 coolo@suse.de
- dropped kst for wallpapers
* Tue May 27 2008 coolo@suse.de
- replace #ifdef with #if defined (bnc#394623)
* Mon May 26 2008 coolo@suse.de
- use gdm for xfce (bnc#393956)
* Mon May 26 2008 coolo@suse.de
- scsi was split
* Thu May 22 2008 aj@suse.de
- Remove perl-MP3-Info from perl-devel since it's non-existing.
* Wed May 21 2008 coolo@suse.de
- adding icons again
* Sun May 18 2008 coolo@suse.de
- rename the internal name of kde cd to kde4
* Tue May 13 2008 coolo@suse.de
- final round of bug fixes for beta3
* Sat May 10 2008 coolo@suse.de
- adding "KDE3 User Guide" to the KDE3 pattern (bnc#388663)
* Sat May 10 2008 coolo@suse.de
- fixing typos
* Thu May  8 2008 coolo@suse.de
- call lint tool to avoid broken factory patterns
* Tue May  6 2008 coolo@suse.de
- fixing typo and adding yast dependencies
* Sun May  4 2008 coolo@suse.de
- use xchat under GNOME
* Sun May  4 2008 coolo@suse.de
- Install banshee-1 by default in GNOME (bnc#384845)
* Sun Apr 27 2008 coolo@suse.de
- fix bug putting yast2-qt on GNOME (bnc#381688)
* Fri Apr 25 2008 coolo@suse.de
- removing gnome2-SuSE, adding kernel-syms,
  renamed control-center2-devel
* Wed Apr 23 2008 coolo@suse.de
- updated icons
* Sat Apr 19 2008 coolo@suse.de
- several bug fixes
* Thu Apr 17 2008 coolo@suse.de
- downgrading apparmor to allow install
* Wed Apr 16 2008 coolo@suse.de
- redoing ordering of patterns
* Tue Apr 15 2008 coolo@suse.de
- removing dropped packages
* Mon Apr 14 2008 coolo@suse.de
- adding Policykit-kde and gnome-packagekit
* Sat Apr 12 2008 coolo@suse.de
- icon changes by Duncan
* Sun Apr  6 2008 coolo@suse.de
- sorting out dropped/renamed packages
- take kde4-opensuse-updater
* Tue Apr  1 2008 coolo@suse.de
- sorting out dropped/renamed packages
* Tue Apr  1 2008 coolo@suse.de
- moving x11 dependencies out of enhanced_base
* Fri Mar 28 2008 coolo@suse.de
- feedback from the KDE team
* Thu Mar 27 2008 coolo@suse.de
- adding tons of packages after feedback on opensuse-factory
* Thu Mar 20 2008 coolo@suse.de
- readding compiz to kde cd
* Thu Mar 20 2008 coolo@suse.de
- rework package, so I can build patterns out of SVN
* Thu Mar 20 2008 coolo@suse.de
- adding PolicyKit-gnome to the GNMOE desktop (bnc#372514)
* Wed Mar 19 2008 coolo@suse.de
- include libcompizconfig in pattern that installs compiz
  (bnc #371550)
* Tue Mar 18 2008 coolo@suse.de
- remove dropped packages, flag i586 only packages
* Tue Mar 18 2008 coolo@suse.de
- wesnoth(-data) is too big for the DVD ;(
* Sun Mar 16 2008 coolo@suse.de
- I almost forgot: non-oss is back on DVD
* Sun Mar 16 2008 coolo@suse.de
- renamed package
* Sat Mar 15 2008 coolo@suse.de
- dropped package removed
* Fri Mar 14 2008 coolo@suse.de
- take gnome branding openSUSE in the patterns
* Thu Mar 13 2008 coolo@suse.de
- another case of permissions
* Wed Mar 12 2008 coolo@suse.de
- check arch specific CD setup
* Tue Mar 11 2008 coolo@suse.de
- updating patterns
* Mon Mar 10 2008 coolo@suse.de
- actually doing svn up before submitpac
* Fri Mar  7 2008 coolo@suse.de
- as a direct consequence of the discussion on the pattern
  concept between software management group: reduce heavily the
  use of requirements to packages
* Thu Mar  6 2008 coolo@suse.de
- only take gnome games on i386
* Sun Mar  2 2008 coolo@suse.de
- do not rely on file permissions
* Fri Feb 29 2008 coolo@suse.de
- remove xgl from kde cd till we have compiz-kde4 in factory
- adding games to gnome and kde cd
* Thu Feb 28 2008 coolo@suse.de
- adding xorg driver for virtualbox speed (#365562)
* Tue Feb 19 2008 coolo@suse.de
- add yast2 requires
* Sun Feb 17 2008 coolo@suse.de
- virtualbox renamed to virtualbox-ose
* Sun Feb 17 2008 coolo@suse.de
- xen_server should bring its kernel (bnc#362028)
* Sun Feb 17 2008 coolo@suse.de
- move more of the unknown packages to suggests
- include not otherwise excluded suggests
* Fri Feb 15 2008 coolo@suse.de
- remove several dropped packages
* Wed Feb  6 2008 coolo@suse.de
- adding yast2-qt to the GNOME CD again (gtk horribly broken)
- removing xsane/gimp from the GNOME CD
* Tue Feb  5 2008 coolo@suse.de
- switch to kde4 for the CD
* Tue Feb  5 2008 coolo@suse.de
- several updates from the KDE team to the KDE4 patterns
* Tue Feb  5 2008 coolo@suse.de
- libzypp-devel is a good candidate for Devel-yast
* Mon Feb  4 2008 coolo@suse.de
- Rodrigo wants pulseaudio in a default GNOME install
* Sun Feb  3 2008 coolo@suse.de
- kde_ patterns should be obsolete
* Sun Feb  3 2008 coolo@suse.de
- make sure kde subpatterns freshen the right version
* Sun Feb  3 2008 coolo@suse.de
- don't include non-oss on the DVD (#357987)
* Fri Feb  1 2008 coolo@suse.de
- don't be too eager in 32bit packages
* Thu Jan 31 2008 coolo@suse.de
- remove more non-existant packages
* Thu Jan 31 2008 coolo@suse.de
- removed dropped packages
- replace renamed packages
- move some more packages to suggests
* Wed Jan 30 2008 coolo@suse.de
- warn about missing packages
* Tue Jan 29 2008 coolo@suse.de
- copy kde patterns into kde3 and kde4
* Sun Jan 27 2008 coolo@suse.de
- also include the KDE yast on the CD
* Fri Jan 25 2008 coolo@suse.de
- move gimp off the CDs
- default to sun java 1.6
- move yast2-qt off the GNOME CD (for installed system)
* Mon Jan 21 2008 coolo@suse.de
- some fixes to get closer to automated kiwi builds
* Mon Jan 21 2008 coolo@suse.de
- list also recommends as required
* Sat Jan 19 2008 coolo@suse.de
- reenable packages that were broken for alpha1
- remove dvd5, dvd9 and cd - they weren't used on 10.3
- let the pattern package require the packages required
  and recommended to make kiwi mbuilds easier
* Tue Jan 15 2008 coolo@suse.de
- several fixes and hot fixes to get alpha1 installable
* Thu Dec 20 2007 coolo@suse.de
- yast2-bluetooth is not provided by anything
* Wed Dec 19 2007 coolo@suse.de
- xml -> technical_writing
* Wed Dec 19 2007 coolo@suse.de
- some fixes for dropped packages
* Wed Dec  5 2007 coolo@suse.de
- include 32bit pam modules
* Wed Dec  5 2007 coolo@suse.de
- slim down default install of both the CDs and the DVD
* Tue Dec  4 2007 coolo@suse.de
- remove some packages without use in the hope to find out if they
  are still in use
* Tue Nov 27 2007 coolo@suse.de
- adding libicu to the pattern, so that zypper will also work
* Mon Nov 26 2007 coolo@suse.de
- /lib/cpp breaks our patterns
* Wed Nov 21 2007 coolo@suse.de
- random cleanup in dropped and split packages
* Mon Nov 12 2007 coolo@suse.de
- rename xml to technical_writing (#332935)
* Fri Nov  9 2007 coolo@suse.de
- adding subversion for yasties (#340575)
* Wed Nov  7 2007 coolo@suse.de
- also add bluez-gnome to gnome default (#226137)
* Thu Oct 11 2007 coolo@suse.de
- install gnome-keyring-pam by default (#332596)
- don't let sw_management_kde and sw_management_gnome conflict (#279644)
- add bluez-gnome to gnome_laptop (#299100)
- remove gtk-engines and gdk-pixbuf from default (#330731)
- add gsynaptics to gnome laptop (#330757)
- not installing autoyast by default (#308684)
- degrade yast2-theme-openSUSE to a recommend (#331549)
- adding 3ddiag to default X11 (#331559)
- adding resapplet to gnome laptop (#328455)
- degrade gimp to a recommend (#331540)
- misc cleanup
* Wed Sep 26 2007 cthiel@suse.de
- fix missing icons (#216557)
* Tue Sep 25 2007 coolo@suse.de
- readding some DEVEL-Perl suggests to the DVD (#327939)
* Tue Sep 25 2007 coolo@suse.de
- move cabextract to the CD set (#327524)
* Mon Sep 24 2007 coolo@suse.de
- really remove update_test pattern
* Mon Sep 24 2007 cthiel@suse.de
- really remove update_test
* Mon Sep 24 2007 cthiel@suse.de
- added bcm43xx-fwcutter to REST-CD (#327506)
* Mon Sep 24 2007 coolo@suse.de
- do not show arcad_eval on x86_64 (#248873)
* Thu Sep 20 2007 coolo@suse.de
- suggest libsmbios-bin on laptops
* Thu Sep 20 2007 coolo@suse.de
- improve KDE Devel pattern after feedback from dirk
* Thu Sep 20 2007 coolo@suse.de
- remove translations from DVD patterns for english only installations
  (#326425)
* Thu Sep 20 2007 coolo@suse.de
- exclude the update_test pattern
* Wed Sep 19 2007 cthiel@suse.de
- only require libspe on power in DEVEL-Cell
* Wed Sep 19 2007 cthiel@suse.de
- fixing problems reported by coolo
* Wed Sep 19 2007 coolo@suse.de
- adding deltarpm to the CDs
* Tue Sep 18 2007 cthiel@suse.de
- added squashfs to REST-DVD, to support kiwi image generation
* Tue Sep 18 2007 coolo@suse.de
- don't install classpath-webplugin (#325912)
* Fri Sep 14 2007 cthiel@suse.de
- added antivir-gui to NON-OSS as requested PM
* Fri Sep 14 2007 cthiel@suse.de
- added missing icons to patterns (#216557)
* Fri Sep 14 2007 cthiel@suse.de
- added more aufs to REST-DVD
- added opera to REST-DVD
* Thu Sep 13 2007 cthiel@suse.de
- added irqbalance to ENHANCED-BASIS
* Thu Sep 13 2007 cthiel@suse.de
- added aufs and aufs-kmps to REST-DVD
- recommended pattern devel-cell in rest_dvd
* Wed Sep 12 2007 cthiel@suse.de
- move numactl from ENHANCED-BASIS-OPT to ENHANCED-BASIS
* Wed Sep 12 2007 cthiel@suse.de
- readded wesnoth to REST-DVD
* Tue Sep 11 2007 cthiel@suse.de
- adding ipw3945d, -kmps and ipw-firmware to REST-CD (#307429)
* Tue Sep 11 2007 coolo@suse.de
- adding fluendo mp3 to NON-OSS pattern
* Mon Sep 10 2007 cthiel@suse.de
- added intlclock to GNOME-BASIS (#304676)
* Wed Sep  5 2007 cthiel@suse.de
- added lukemftp to ENHANCED-BASIS (#307925)
* Tue Sep  4 2007 cthiel@suse.de
- removed gnomebaker from GNOME-BASIS and added brasero instead (#302492)
- removed gnome_games from rest_cd_gnome/requires
* Mon Sep  3 2007 cthiel@suse.de
- added kdebase4-workspace to KDE4-BASIS (#307054)
* Mon Sep  3 2007 cthiel@suse.de
- added mouseemu to ENHANCED-BASIS on power (#303737)
* Mon Sep  3 2007 cthiel@suse.de
- moved resmgr from ENHANCED-BASIS to BASIS (#307095)
* Mon Sep  3 2007 cthiel@suse.de
- added mdadm to ENHANCED-BASIS (#306749)
* Thu Aug 30 2007 cthiel@suse.de
- added virtualbox + virtualbox-kmp to REST-DVD (#306071)
* Tue Aug 28 2007 cthiel@suse.de
- added libgail-gnome to GNOME-BASIS (#302205)
- move yast2-bootloader from YAST2-BASIS to YAST_INSTALL_WF (#292435)
* Mon Aug 27 2007 aj@suse.de
- Add more packages to yast2 devel pattern (#304645).
- suspend is i386/x86-64 only (#304756).
* Mon Aug 27 2007 cthiel@suse.de
- install resmgr by default (#304695)
- install psmisc by default (#304694)
- install gconf-editor by default (#304663)
- readd gnome-games to GNOME CD (#304662)
- install man by default (#304687)
- added yast2-fingerprint-reader to YAST_BASIS (#304686)
- sw_management pattern recommended in base and enhanced_base pattern (#304307)
- install audit by default (#304207)
- kpartx and dmraid to ENHANCED-BASIS (#303857)
- seamonkey* packages to REST-DVD (#304221)
- moved x11-tools from X11-OPT to X11 (#302566)
- added p54-kmp-default to REST-CD (#300798)
- added atmel-firmware to REST-CD (#298726)
- added lessons4lizards_en to REST-DVD (#302465)
- added alsa-plugins to ENHANCED-BASIS (#302569)
- moved memtest86+ from REST-DVD to REST-CD (#304219)
* Thu Aug 23 2007 cthiel@suse.de
- added adaptec-firmware, qlogic-firmware and mpt-firmware to REST-CD
  (#298726)
* Thu Aug 23 2007 cthiel@suse.de
- removed squashfs, since it's moving into the kernel packages
* Wed Aug 22 2007 cthiel@suse.de
- added hylafax, hylafax-client and capi4hylafax to REST-DVD
* Wed Aug 22 2007 cthiel@suse.de
- added iwlwifi-kmp-* to REST-DVD
* Wed Aug 22 2007 cthiel@suse.de
- removed xfce4-panel-plugins from XFCE and readded xfce4-panel-plugin-*
* Wed Aug 22 2007 cthiel@suse.de
- added strace to ENHANCED-BASIS
* Tue Aug 21 2007 cthiel@suse.de
- removed dropped initial from rest-dvd
- moved kio_beagle, beagle-firefox, kdebase3-beagle and kerry to KDE-BASIS
* Tue Aug 21 2007 cthiel@suse.de
- moved lvm2 to REST-CD
* Tue Aug 21 2007 cthiel@suse.de
- added bundle-lang-common-en to REST-CD
* Tue Aug 21 2007 cthiel@suse.de
- moved lvm2 to ENHANCED-BASIS (#301382)
- removed nautilus-cd-burner and added gnomebaker to GNOME-BASIS pattern
  (#269051)
- added ggreeter to GNOME-BASIS (#302026)
- addded gnome-commander to GNOME-BASIS (#301664)
- added freeglut to X11 (#301647)
* Fri Aug 17 2007 cthiel@suse.de
- added opensuse-codecs-installer to KDE & GNOME Multimedia
* Fri Aug 17 2007 cthiel@suse.de
- added yast2-add-on-creator to rest_dvd (#301047)
* Thu Aug 16 2007 cthiel@suse.de
- added yast2-python-bindings to rest_dvd (#301029)
* Thu Aug 16 2007 cthiel@suse.de
- added squashfs + kmp to rest_cd (#300942)
* Thu Aug 16 2007 cthiel@suse.de
- adding kexec-tools, kdump-helpers and yast2-kdump to rest_dvd
* Wed Aug 15 2007 coolo@suse.de
- adding kinternet back to the medium
* Wed Aug 15 2007 coolo@suse.de
- tomcat5 -> tomcat55 in devel_java
- make dvd5 and dvd9 alike
* Wed Aug 15 2007 coolo@suse.de
- don't install manuals by patterns, but by provides on locales
  (#296873)
* Wed Aug 15 2007 coolo@suse.de
- don't install kmilo by default (#298508)
* Tue Aug 14 2007 coolo@suse.de
- move kdegraphics3-scan from CD to DVD only
- adding cups from DVD only to CD
* Tue Aug 14 2007 coolo@suse.de
- adding some packages that are installed by hardware dependencies
* Tue Aug 14 2007 coolo@suse.de
- hostap is dropped
* Mon Aug 13 2007 coolo@suse.de
- include ntfs-3g by default
* Sun Aug 12 2007 coolo@suse.de
- remove dropped packages
* Sat Aug 11 2007 coolo@suse.de
- fix file list
* Fri Aug 10 2007 coolo@suse.de
- move cups-autoconf into DVD enhanced_basis
* Fri Aug 10 2007 coolo@suse.de
- split rest_cd into kde and gnome to simplify configs
* Wed Aug  8 2007 coolo@suse.de
- adding a rest_dvd pattern for dvd5
- dropping yast2-power-management
* Tue Aug  7 2007 coolo@suse.de
- voip-server is no more - asterix is dropped
* Mon Aug  6 2007 coolo@suse.de
- replace kdenetwork3-vnc with kde4-krfb/kde4-krdc (#297684)
* Mon Aug  6 2007 coolo@suse.de
- move latex2html-pngicons, sensors off the GNOME CD
- move ed to be recommended on DVD - let's try what or who needs ed
- remove all games from the GNOME CD
* Sun Aug  5 2007 coolo@suse.de
- move smpppd off the CD
- extend the base patterns
- rename curl-devel and libpurple-devel
- readd nautilus-open-terminal to GNOME
- move exiftool off the CD
- readd numlockx to the CD
- track DVD packages from bug reports
* Wed Aug  1 2007 coolo@suse.de
- hide helix-banshee to avoid a conflict
* Wed Aug  1 2007 coolo@suse.de
- move nautilus-open-terminal and alacarte off the CD
* Tue Jul 31 2007 coolo@suse.de
- shuffle around more GNOME bits
* Tue Jul 31 2007 coolo@suse.de
- split out gtk1 stuff
* Tue Jul 31 2007 coolo@suse.de
- need to split out more GNOME patterns to fit on CD (e.g. inkscape, dia)
* Mon Jul 30 2007 coolo@suse.de
- split GNOME multimedia for OSS medium and replace gaim with pidgin
* Mon Jul 30 2007 coolo@suse.de
- yast2-registration should be on the media in any case
* Mon Jul 30 2007 coolo@suse.de
- adding a rest_cd pattern to track invisible dependencies
  needed on the CD
* Mon Jul 30 2007 coolo@suse.de
- also add recommends to the opt patterns
* Mon Jul 30 2007 coolo@suse.de
- move packages on CD back out of opt
* Fri Jul 27 2007 coolo@suse.de
- split several patterns into the required packages and
  optionals not on CD (now)
* Fri Jul 27 2007 coolo@suse.de
- include apparmor on CDs
* Fri Jul 27 2007 coolo@suse.de
- Add fonts_opt pattern
- Remove obvious dependencies from enhanced_base
- Document some decisions
* Thu Jul 26 2007 aj@suse.de
- Make files in GAMES pattern recommended.
- Add enhanced_base_opt pattern.
- Add GNOME-cd and KDE-cd packages.
* Fri Jul 20 2007 aj@suse.de
- Use amarok-yaup instead of amarok-xine (#293531).
* Tue Jul 17 2007 aj@suse.de
- Add libgcc42 to basis.
* Tue Jul 10 2007 aj@suse.de
- Adjust KDE4 patterns as suggested by Stephan Binner.
* Tue Jul 10 2007 aj@suse.de
- Add atftp to File Server (#288154).
* Thu Jul  5 2007 aj@suse.de
- Remove dmraid, multipath-tools from default install.
* Wed Jul  4 2007 aj@suse.de
- Remove limal-bootloater.
* Mon Jul  2 2007 aj@suse.de
- Remove freetype from fonts pattern (#283827).
- Add perl-TermReadLine-Gnu to Enhance-Basis (#285827).
* Mon Jul  2 2007 aj@suse.de
- Move some packages from required to recommended as suggested by
  Lars Vogdt for the 1 CD installs.
* Sat Jun 30 2007 aj@suse.de
- Remove lvm2, mdadm from install, YaST will install if needed.
- Add office pattern, add splitted OpenOffice_org packages.
* Fri Jun 29 2007 aj@suse.de
- Add xournal to GNOME-LAPTOP (#288160).
* Thu Jun 28 2007 aj@suse.de
- Add vm-install and virt-manager to XEN pattern (#286987).
- Require xkeyboard-config in X11 (#285001).
- Require hal-resmgr in enhanced basis (#285057), add setserial
  as recommended.
- Make some packages only recommended in GNOME Imaging (#285251).
* Thu Jun 14 2007 aj@suse.de
- Add KDE4 Basis pattern (#283896).
- Cleanup devel-qt4 pattern (#283889).
* Mon Jun 11 2007 aj@suse.de
- nfs-utils -> nfs-client for basis.
- nfs-utils -> nfs-kernel-server for NFS Server pattern.
* Sat Jun  9 2007 aj@suse.de
- Add Cell Development pattern (#273697).
- Remove 915resolution from X11 pattern (#266362).
* Fri Jun  8 2007 aj@suse.de
- Make X11 pattern smaller (#266362).
- Add linux-atm-lib to ENHANCED_BASE (#225781).
- Add banshee-plugins-DAAP for GNOME (#273896).
- Add metacity-devel andlibgnomekbd-devel for DEVEL-GNOME (#278972,
  [#278973]).
- Add xfce4-volstatus to XFCE (#279080).
* Wed May 30 2007 lrupp@suse.de
- remove dropped package kdepim3-networkstatus
* Mon May 28 2007 aj@suse.de
- Add yast2-mcs-manager to XFCE pattern.
* Tue May 15 2007 aj@suse.de
- Remove evms packages from default installs.
* Mon May 14 2007 lrupp@suse.de
- move deleted package yast2-mail-aliases to Prc
* Fri May 11 2007 aj@suse.de
- Add yast2-metapackage-handler to YaST2 pattern.
* Thu May 10 2007 aj@suse.de
- remove evms-gui from X11 pattern (#266362).
- remove mozilla-xulrunner181 from X11 pattern (#266362).
- remove libqt4 from X11 pattern, it should come in via
  dependencies (#266362).
* Thu May 10 2007 aj@suse.de
- Make freetype only recommended (#273170).
* Wed May  2 2007 aj@suse.de
- Add cracklib-dict-large as recommended.
* Wed May  2 2007 aj@suse.de
- Readd initviocons, it's needed elsewhere.
* Wed May  2 2007 aj@suse.de
- Add kde4 games.
- Remove yast2-powertweak.
* Tue May  1 2007 aj@suse.de
- Make jfs and xfs as suggested only.
* Sat Apr 28 2007 aj@suse.de
- Some fixes for bug 269774:
  * Install initviocons on powerpc only.
  * Remove tpctl from laptop, hwinfo should add the require.
* Tue Apr 24 2007 aj@suse.de
- alsa-32bit -> libasound2-32bit.
* Thu Apr 19 2007 aj@suse.de
- Rework opensuse-updater patterns.
* Tue Apr 17 2007 aj@suse.de
- Add finger to default install (#224873).
* Mon Apr 16 2007 aj@suse.de
- Add licenses to BASIS.
* Mon Apr 16 2007 aj@suse.de
- Add mrtg to Network Admin pattern (#264670).
- Obsolete/provide zmd patterns.
* Fri Apr 13 2007 aj@suse.de
- Disable zmd patterns.
* Wed Apr 11 2007 aj@suse.de
- Add dasher, seahorse for GNOME (#262024).
- Add yast2-ftp-server.
- Remove wireless packages that yast should install as needed.
* Tue Apr 10 2007 aj@suse.de
- Add nspluginwrapper for Firefox.
* Thu Apr  5 2007 aj@suse.de
- Add nss-mdns-32bit for Firefox (#249686).
* Fri Mar 30 2007 aj@suse.de
- Add xfce-mcs-plugins to XFCE pattern (#258845).
* Thu Mar 29 2007 aj@suse.de
- Remove packages from RPM development environment that are not
  installed anymore.
* Mon Mar 26 2007 aj@suse.de
- Add filters to default install (#257038).
* Thu Mar 22 2007 aj@suse.de
- Add opensuse-updater-gnome.
* Fri Mar 16 2007 aj@suse.de
- Add yast2-control-center binary modules to desktops (#254137).
* Fri Mar 16 2007 aj@suse.de
- Install multimedia for KDE (#253022).
* Wed Feb 21 2007 aj@suse.de
- Do not install zmd by default.
* Fri Feb 16 2007 aj@suse.de
- Add gnome_yast (#245411, #245988).
* Fri Feb 16 2007 aj@suse.de
- Fix some GNOME and KDE patterns.
* Thu Feb 15 2007 aj@suse.de
- Remove yast2-theme* from minimal install.
- pkgconfig->pkg-config.  Remove duplicates.
* Wed Feb 14 2007 aj@suse.de
- Really install OOo with GNOME (#245408).
- Install banshee with GNOME (#245407).
* Wed Feb 14 2007 aj@suse.de
- Add mtools to CONSOLE (#244591).
* Mon Feb 12 2007 aj@suse.de
- Move create_patterns.sh to patterns package.
* Mon Feb 12 2007 aj@suse.de
- Remove gtk-sharp packages (#244537).
- Remove hal-gnome from gnome_basis (#244417).
* Fri Feb  9 2007 aj@suse.de
- Fix build problem.
* Fri Feb  9 2007 aj@suse.de
- Build patterns package separately.
- Do not build as root.
* Thu Feb  8 2007 aj@suse.de
- Move ia32el to NON-OSS (#243590).
* Thu Feb  8 2007 aj@suse.de
- Localization update.
- Build as root, patterns_utf8 needs to access its mo files.
* Tue Feb  6 2007 aj@suse.de
- Enhance XFCE pattern (#224558).
* Thu Feb  1 2007 aj@suse.de
- Add ncftp to CONSOLE (#224692).
- Add grepmail, links to CONSOLE (#239564).
- Add black-box, WindowMaker to X11 (#212529).
* Wed Jan 31 2007 aj@suse.de
- Version 10.3.
* Fri Jan 26 2007 aj@suse.de
- Remove redundancies.
* Thu Jan 25 2007 aj@suse.de
- Split GNOME into smaller patterns.
* Thu Jan 25 2007 aj@suse.de
- Follow package renames.
* Thu Jan 25 2007 aj@suse.de
- Add separate multimedia pattern (by Lars Vogdt).
* Tue Jan 23 2007 aj@suse.de
- Further minimization of BASIS pattern.
* Fri Jan 19 2007 aj@suse.de
- Use weak dependencies for non-oss pattern.
- Enhance patterns.
* Thu Jan 18 2007 aj@suse.de
- Split base system into minimal base and enhanced base.
- Start providing a YaST pattern for installation workflow.
* Thu Jan 18 2007 aj@suse.de
- Add some python GNOME packages (#235922).
* Wed Jan 17 2007 aj@suse.de
- Use smaller KDE patterns.
- Add compiz-kde, enable KDE XGL pattern.
* Wed Jan 17 2007 aj@suse.de
- Add separate update test pattern (#220798).
* Wed Jan 17 2007 aj@suse.de
- Add vino to GNOME Desktop pattern (#225382).
- Make 32-bit pattern visible (#224863).
- Remove build from kernel pattern, it's in the base devel pattern
  (#227045).
- Do not install ash by default (#222905).
- Fix typo in patterns (#224373).
* Fri Jan 12 2007 aj@suse.de
- Update localization.
- Add SLED pattern names.
* Wed Nov 29 2006 aj@suse.de
- Add xsane for GNOME desktop, sane-frontends for X11 (#224411).
- Fix some pattern dependencies, especially to not install gnome base
  system if XGL is selected under KDE (#224412).
* Tue Nov 28 2006 aj@suse.de
- Install opensuse sw_management tools as well.
- i18n update (km).
- Install xgl pattern for KDE as well.
* Mon Nov 27 2006 aj@suse.de
- i18n update.
* Sun Nov 26 2006 aj@suse.de
- Remove pdfs of manuals.
* Sun Nov 26 2006 aj@suse.de
- Add manuals (#223187).
* Fri Nov 24 2006 aj@suse.de
- Require java-1_4_2-gcj-compat-32bit for OOo (#223440).
- Fix mail server pattern syntax (#223497).
- Fix typo in kde pattern (#220277).
- Add wesnoth to games pattern (#223573).
- Fixes for devel patterns, especially devel-kde (#223594).
* Thu Nov 23 2006 aj@suse.de
- Fix xfce pattern requires (#223438).
- Install pmtools only on supported archs (#223186).
- Add libzypp-zmd-backend to zmd pattern (#223323).
- Translation update.
- Add mozilla-xulrunner181 to X11 pattern (#223437).
* Tue Nov 21 2006 aj@suse.de
- Install fast-user-switch-applet by default on GNOME (#222878).
* Mon Nov 20 2006 aj@suse.de
- Translation update.
* Fri Nov 17 2006 aj@suse.de
- Translation update.
* Fri Nov 17 2006 aj@suse.de
- Fix bugs in patterns (#221824).
- Remove dropped libopensync-plugin-synce package.
* Fri Nov 17 2006 aj@suse.de
- Add deskbar-applet for GNOME (#216067).
- Add pkgconfig to X11 pattern.
- Localization update.
* Wed Nov 15 2006 aj@suse.de
- Localization update.
- Only install asterix-zaptel on i386 and x86-64 (#221288).
- Add some more packages to mail server (#221247).
* Wed Nov 15 2006 aj@suse.de
- Add qtcurve-gtk2-32bit to KDE pattern (#221234).
- Fix XGL patterns.
- Add kdetoys3 to kde desktop pattern (#220892).
- Add yast2-storage-evms to yast2 basis (#220425).
* Tue Nov 14 2006 aj@suse.de
- Fix XGL pattern visibility (#220852).
- Change names of package management patterns (#220741).
- Install yast2-samba-server by default with yast-basis pattern
  (#212388).
* Tue Nov 14 2006 aj@suse.de
- Further rework of software management patterns.
* Tue Nov 14 2006 aj@suse.de
- Add liferea and pan to GNOME desktop pattern (#220275).
* Mon Nov 13 2006 aj@suse.de
- Add tcl devel pattern (#220427).
* Mon Nov 13 2006 aj@suse.de
- Remove/rename some java packages.
- Rework software management patterns.
* Mon Nov 13 2006 aj@suse.de
- Make gnome-media only recommended.
- Remove compiz-gnome from KDE pattern (#220291).
- Add VOIP server and client patterns (#220241).
- Add iftop to Network-Admin.
- Remove electricfence from devel-c.
- Add pin to sw management patterns (#220292).
- Add more packages to console pattern (#220292).
- Readd Desktop Effects pattern.
* Sun Nov 12 2006 aj@suse.de
- Remove gnome-doc-utils from gnome_basis (#220263).
- Move some gnome packages around in the GNOME patterns (#220259).
* Sun Nov 12 2006 aj@suse.de
- Localization update.
- Add gnome-mount to GNOME-BASIS (#215392).
- Recommend NON-OSS, NON-OSS-Java for KDE and GNOME desktops (#219711).
- Add nano to console tools (#215652).
- Enhance imaging patterns.
- Remove libopensync-plugin-kdepim from GNOME-DESKTOP pattern (#220202).
* Thu Nov  9 2006 aj@suse.de
- Move kdeedu3 to KDE-Desktop pattern (#219361).
- Add  manufacturer-PPDs to Base pattern.
* Wed Nov  8 2006 aj@suse.de
- Add RealPlayer to KDE patterns.
- Add some 32-bit patterns for RealPlayer to patterns (#219009).
* Wed Nov  8 2006 aj@suse.de
- Remove banshee-subpackages from patterns, the package itself has
  the recommends now.
- translation update.
* Tue Nov  7 2006 aj@suse.de
- Install java-plugin by default on i586 (#216499).
- Remove kernel-xen again (#217934).
* Tue Nov  7 2006 lrupp@suse.de
- fix missing ":" in DEVEL-Kernel
* Tue Nov  7 2006 aj@suse.de
- Add alsa-32bit for x86-64 (#218739).
* Tue Nov  7 2006 aj@suse.de
- Install compiz-gnome under KDE as well.
- Fix require of software management pattern.
* Tue Nov  7 2006 aj@suse.de
- Handle banshee/helix-banshee better (#206954).
* Tue Nov  7 2006 aj@suse.de
- Further package for kernel-devel (#217999).
* Tue Nov  7 2006 aj@suse.de
- Add packages to kernel-devel (#217999).
- Add yast2-sudo to yast2 basis pattern.
- Add pinentry-qt, pinentry-gtk2 to patterns (#217373).
- Recommend AppArmor instead of using supplements.
* Mon Nov  6 2006 cthiel@suse.de
- Add dockutils to LAPTOP
* Mon Nov  6 2006 aj@suse.de
- Translation update.
* Sun Nov  5 2006 aj@suse.de
- Translation updates.
* Thu Nov  2 2006 cthiel@suse.de
- Add totem-plugin to GNOME-DESKTOP and GNOME-Multimedia (#217457)
- Add cups-drivers and gutenprint to BASIS, gutenprint to PRINT_SERVER (#217321)
* Wed Nov  1 2006 aj@suse.de
- Fix description of misc server pattern (#216556).
* Tue Oct 31 2006 cthiel@suse.de
- Add nautilus-sendto to GNOME-BASE (#216106)
* Tue Oct 31 2006 cthiel@suse.de
- Add gnome-doc-utils-devel to DEVEL-GNOME
* Tue Oct 31 2006 cthiel@suse.de
- Add vte-devel to DEVEL-GNOME
- Add intltool to DEVEL-GNOME (#216592)
* Tue Oct 31 2006 cthiel@suse.de
- Add alacarte to GNOME-DESKTOP (#216065)
* Mon Oct 30 2006 aj@suse.de
- Add nfs-server to fileserver pattern (#215648).
* Mon Oct 30 2006 aj@suse.de
- Fix sw_management patterns.
- Add kernel-xen to XEN pattern (#208380)
- Fix some description.
* Mon Oct 30 2006 aj@suse.de
- Fix enhances of sw_management pattern.
* Mon Oct 30 2006 aj@suse.de
- Add software management patterns.
- Reorder patterns.
* Sat Oct 28 2006 aj@suse.de
- Remove kernel again.
- Add glibc-locale-32bit to BASE pattern (#215910).
* Fri Oct 27 2006 aj@suse.de
- Add kernel to BASIS (#215644).
* Fri Oct 27 2006 aj@suse.de
- Changes to GNOME patterns:
  * Install totem (#215431).
  * Install gstreamer plugins (#215427).
  * Install banshee-plugins-extra (#215426).
- Add hal-resmgr to base pattern (#215396).
- Add defines for s390.
- localisation update.
- Add kpowersave again to KDE pattern.
- Rework Network admin pattern and add to CDs (#215653).
* Thu Oct 26 2006 aj@suse.de
- Replace kdepim3-sync with kitchensync.
- Install sync packages by default for GNOME and KDE (#215252).
- Install compiz and friends by default.
* Wed Oct 25 2006 aj@suse.de
- i18n update.
- Remove some empty lines that confused the parser (Bug #214877).
* Tue Oct 24 2006 aj@suse.de
- One more typo...
- Disable kpowersave for now.
- localization update.
* Tue Oct 24 2006 aj@suse.de
- Add freshens for gnome_games.
* Tue Oct 24 2006 aj@suse.de
- Fix one more typo.
* Tue Oct 24 2006 lrupp@suse.de
- fix typo in remote-desktop pattern
- remove two dropped packages from lamp-pattern
* Tue Oct 24 2006 aj@suse.de
- Better group patterns.
* Tue Oct 24 2006 aj@suse.de
- Cleanup display.
* Tue Oct 24 2006 aj@suse.de
- Fix GNOME pattern.
* Tue Oct 24 2006 aj@suse.de
- Use opensync instead of multisync.
* Mon Oct 23 2006 aj@suse.de
- Rework GNOME and KDE patterns to reduce list of patterns
  significantly.
* Sun Oct 22 2006 aj@suse.de
- Add opensuse-update to kde-basis.
* Fri Oct 20 2006 aj@suse.de
- Make separate zmd pattern.
* Fri Oct 20 2006 aj@suse.de
- Remove / Merge patterns with just one package.
- i18n update.
* Mon Oct 16 2006 aj@suse.de
- Xfce is not on CD media.
* Fri Oct 13 2006 aj@suse.de
- Fix broken requires.
* Fri Oct 13 2006 aj@suse.de
- Fix requires on basis-devel (#212192).
* Thu Oct 12 2006 aj@suse.de
- Remove kpowersave from default install for now.
* Thu Oct 12 2006 aj@suse.de
- Add qtcurve packages.
* Thu Oct 12 2006 aj@suse.de
- Make imaging patterns hidden.
* Wed Oct 11 2006 aj@suse.de
- Add xorg-x11-libXext to X11 pattern.
* Wed Oct 11 2006 aj@suse.de
- Make Evolution recommended (#211175).
* Mon Oct  9 2006 aj@suse.de
- Add hplip to BASIS (#210984).
* Mon Oct  9 2006 aj@suse.de
- Handle some more i386/x86-64 only packages.
- Add hotkey-setup to LAPTOP (#210879).
- Translation update.
* Sun Oct  8 2006 aj@suse.de
- Add xdg-utils to X11 (#210884).
* Fri Oct  6 2006 aj@suse.de
- Add orca, gnopernicus (bug #208686).
- Adjust kde-games.
- localization update.
* Thu Oct  5 2006 aj@suse.de
- Fix GNOME-Multimedia pattern.
* Thu Oct  5 2006 aj@suse.de
- Add synergy to X11 pattern.
* Wed Oct  4 2006 aj@suse.de
- Add gnucash to GNOME-Office (#209719).
* Wed Oct  4 2006 aj@suse.de
- Remove devel-java from CDs.
* Tue Oct  3 2006 lrupp@suse.de
- fix typo in DEVEL-Java pattern
* Tue Oct  3 2006 aj@suse.de
- Update to 1.018 patterns.
- Improve i18n handling.
* Sun Oct  1 2006 aj@suse.de
- Rename BASIS-DEVEL to BASIS-DEVEL.
- Add DEVEL-RPM-Build-Environment Pattern (#209368).
* Sat Sep 30 2006 aj@suse.de
- Add various IDEs.
- Fix various bugreports about missing patterns (207916, 208384,
  208676).
- Merge KDE-HELP to KDE-Basis.
* Sat Sep 30 2006 aj@suse.de
- Add remote_desktop and devel_java patterns.
* Fri Sep 29 2006 aj@suse.de
- Add first support for extends/includes, use it in graphics
  pattern.
* Fri Sep 29 2006 aj@suse.de
- translation updates
- some packages added to patterns.
* Mon Sep 25 2006 aj@suse.de
- Enable subpackages.
* Sun Sep 24 2006 aj@suse.de
- Remove dropped packages.
- Rename packages.
* Sun Sep 24 2006 aj@suse.de
- Fix bugs in patterns.
- Disable subpackages for now.
* Sat Sep 23 2006 aj@suse.de
- Create subpackages for different media.
* Fri Sep 22 2006 aj@suse.de
- Add further development patterns:
  * Ruby
  * Ruby on Rails
  * YaST
  * Web
  * Python
  * Perl
- Rename SDK patterns to devel.
* Fri Sep 22 2006 aj@suse.de
- Update translations.
- Rework various patterns.
* Wed Sep 20 2006 aj@suse.de
- Translation updates.
* Wed Sep 20 2006 aj@suse.de
- Fix typo in kde pattern.
* Tue Sep 19 2006 aj@suse.de
- Adjust for package rename.
* Mon Sep 18 2006 aj@suse.de
- Update et, sv.
- Enhance GAMES, NETWORK-ADMIN patterns.
* Wed Sep 13 2006 aj@suse.de
- Add kdebase3-beagle to KDE-BASIS.
* Tue Sep 12 2006 aj@suse.de
- Fix Non-OSS pattern.
- Add cups to BASIS.
* Mon Sep 11 2006 aj@suse.de
- Add network-admin pattern.
* Mon Sep 11 2006 aj@suse.de
- Add non-OSS pattern.
* Fri Sep  8 2006 aj@suse.de
- Add further GNOME/KDE patterns.
* Fri Sep  8 2006 aj@suse.de
- Update translations, add further languages.
* Thu Sep  7 2006 aj@suse.de
- Further refine KDE and GNOME patterns.
- Refine BASE pattern.
* Wed Sep  6 2006 aj@suse.de
- Add GAMES.
* Wed Sep  6 2006 aj@suse.de
- Splitup new patterns from base.
* Wed Sep  6 2006 aj@suse.de
- Add gnome development.
* Mon Sep  4 2006 aj@suse.de
- Fix order of patterns.
- Make laptop patterns visible.
- Fix some bugs.
* Mon Sep  4 2006 aj@suse.de
- qt->libqt4.
* Fri Sep  1 2006 aj@suse.de
- Abort if errors occur in patterns.
- Split GNOME Patterns - thanks Gary Ekker!
- Add GNOME/KDE Laptop patterns.
* Wed Aug 30 2006 aj@suse.de
- Add xml pattern.
- Add xfce pattern.
- Add console pattern.
* Wed Aug 30 2006 aj@suse.de
- Add fonts pattern.
* Mon Aug 28 2006 aj@suse.de
- Further cleanup of files.
* Mon Aug 28 2006 aj@suse.de
- Fix translations for some languages.  Thanks to Jyri Palokangas
  for noticing.
- Do not emit untranslated strings.
* Mon Aug 28 2006 aj@suse.de
- Fix bash script.
* Mon Aug 28 2006 aj@suse.de
- Move pattern creation logic from spec file to new bash script.
- Fix gettext configure.
* Sat Aug 26 2006 aj@suse.de
- Fix spec file.
* Fri Aug 25 2006 aj@suse.de
- Add pam-config.
* Thu Aug 24 2006 aj@suse.de
- Add icons.
- Fix spec file.
* Thu Aug 24 2006 aj@suse.de
- Enhance patterns, fix imaging patterns.
* Thu Aug 24 2006 aj@suse.de
- Fix description of patterns - thanks Stephan Binner.
* Mon Aug 21 2006 aj@suse.de
- Add role "not yet classified" to clean up.
* Mon Aug 21 2006 aj@suse.de
- Add further patterns.
- Fix KDE patterns.
* Thu Aug 17 2006 aj@suse.de
- Enhance KDE-Office.
* Thu Aug 17 2006 aj@suse.de
- Enhance KDE patterns.
* Wed Aug 16 2006 aj@suse.de
- Add kdenetwork3 packages.
* Wed Aug 16 2006 aj@suse.de
- Add KDE subpatterns for testing.
* Tue Aug 15 2006 aj@suse.de
- Use pattern-openSUSE as packagename for po files.
* Thu Aug 10 2006 aj@suse.de
- Remove suggests apparmor from base to workaround Bug 198095.
* Wed Aug  9 2006 aj@suse.de
- Remove wrong icons for now.
* Tue Aug  8 2006 aj@suse.de
- Remove kdenetwork3-vnc from kde pattern.
- reorder imaging patterns
* Tue Aug  1 2006 aj@suse.de
- Changes for X.Org 7.1
- Add dhcp and dns server pattern.
- fix kde imaging pattern.
- Add first devel patterns.
* Mon Jul 31 2006 aj@suse.de
- Add imaging pattern.
* Sun Jul 30 2006 aj@suse.de
- Add beagle.
* Thu Jul 27 2006 aj@suse.de
- Cleanup theming.
* Wed Jul 26 2006 aj@suse.de
- Add and remove packages.
* Mon Jul 17 2006 aj@suse.de
- suse-release -> openSUSE-release.
* Mon Jul 17 2006 aj@suse.de
- Add NetworkManager packages to KDE/GNOME packages.
* Mon Jul 17 2006 aj@suse.de
- Adjust patterns.
- Change naming for openSUSE.
* Wed Jul 12 2006 aj@suse.de
- Initial Pattern for openSUSE.  This is just a really basic list
  to get us started and test that everything works.
